/* LibraryMonitor.c generated by valac 0.56.17, the Vala compiler
 * generated from LibraryMonitor.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU LGPL (version 2.1 or later).
 * See the COPYING file in this distribution.
 */
/**/
/* LibraryMonitor uses DirectoryMonitor to track assets in the user's library directory and make*/
/* sure they're reflected in the application.*/
/**/
/* NOTE: There appears to be a bug where prior versions of Shotwell (<= 0.6.x) were not*/
/* properly loading the file modification timestamp during import.  This was no issue*/
/* before but becomes imperative now with file monitoring.  A "proper" algorithm is*/
/* to reimport an entire photo if the modification time in the database is different*/
/* than the file's, but that's Real Bad when the user first turns on monitoring, as it*/
/* will cause a lot of reimports (think of a 10,000 photo database) and will blow away*/
/* ALL transformations, as they are now suspect.*/
/**/
/* So: If the modification time is zero and filesize is the same, simply update the*/
/* timestamp in the database and move on.*/
/**/
/* TODO: Although it seems highly unlikely that a file's timestamp could change but the file size*/
/* has not and the file really be "changed", it *is* possible, even in the case of complex little*/
/* animals like photo files.  We could be more liberal and treat this case as a metadata-changed*/
/* situation (since that's a likely case).*/
/**/

#include <glib-object.h>
#include <glib.h>
#include <gobject/gvaluecollector.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>

#define LIBRARY_MONITOR_FLUSH_IMPORT_QUEUE_SEC 3
#define LIBRARY_MONITOR_IMPORT_ROLL_QUIET_SEC (((5 * 60) * 1000) * 1000)
#define LIBRARY_MONITOR_MIN_BLACKLIST_DURATION_MSEC (5 * 1000)
#define LIBRARY_MONITOR_MAX_VERIFY_EXISTING_MEDIA_JOBS 5
#define UTIL_FILE_ATTRIBUTES "standard::*,time::*,id::file,id::filesystem,etag::value"
#define DIRECTORY_MONITOR_SUPPLIED_ATTRIBUTES UTIL_FILE_ATTRIBUTES
#define DIRECTORY_MONITOR_FILE_INFO_FLAGS G_FILE_QUERY_INFO_NONE
#define DIRECTORY_MONITOR_DEFAULT_PRIORITY G_PRIORITY_LOW
#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_LIBRARY_MONITOR_POOL (library_monitor_pool_get_type ())
#define LIBRARY_MONITOR_POOL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_MONITOR_POOL, LibraryMonitorPool))
#define LIBRARY_MONITOR_POOL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_MONITOR_POOL, LibraryMonitorPoolClass))
#define IS_LIBRARY_MONITOR_POOL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_MONITOR_POOL))
#define IS_LIBRARY_MONITOR_POOL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_MONITOR_POOL))
#define LIBRARY_MONITOR_POOL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_MONITOR_POOL, LibraryMonitorPoolClass))

typedef struct _LibraryMonitorPool LibraryMonitorPool;
typedef struct _LibraryMonitorPoolClass LibraryMonitorPoolClass;
typedef struct _LibraryMonitorPoolPrivate LibraryMonitorPoolPrivate;

#define TYPE_DIRECTORY_MONITOR (directory_monitor_get_type ())
#define DIRECTORY_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DIRECTORY_MONITOR, DirectoryMonitor))
#define DIRECTORY_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DIRECTORY_MONITOR, DirectoryMonitorClass))
#define IS_DIRECTORY_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DIRECTORY_MONITOR))
#define IS_DIRECTORY_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DIRECTORY_MONITOR))
#define DIRECTORY_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DIRECTORY_MONITOR, DirectoryMonitorClass))

typedef struct _DirectoryMonitor DirectoryMonitor;
typedef struct _DirectoryMonitorClass DirectoryMonitorClass;

#define TYPE_LIBRARY_MONITOR (library_monitor_get_type ())
#define LIBRARY_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_MONITOR, LibraryMonitor))
#define LIBRARY_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_MONITOR, LibraryMonitorClass))
#define IS_LIBRARY_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_MONITOR))
#define IS_LIBRARY_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_MONITOR))
#define LIBRARY_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_MONITOR, LibraryMonitorClass))

typedef struct _LibraryMonitor LibraryMonitor;
typedef struct _LibraryMonitorClass LibraryMonitorClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _library_monitor_pool_unref0(var) ((var == NULL) ? NULL : (var = (library_monitor_pool_unref (var), NULL)))
typedef struct _ParamSpecLibraryMonitorPool ParamSpecLibraryMonitorPool;
enum  {
	LIBRARY_MONITOR_POOL_MONITOR_INSTALLED_SIGNAL,
	LIBRARY_MONITOR_POOL_MONITOR_DESTROYED_SIGNAL,
	LIBRARY_MONITOR_POOL_NUM_SIGNALS
};
static guint library_monitor_pool_signals[LIBRARY_MONITOR_POOL_NUM_SIGNALS] = {0};
typedef struct _DirectoryMonitorPrivate DirectoryMonitorPrivate;
typedef struct _LibraryMonitorPrivate LibraryMonitorPrivate;

#define TYPE_WORKERS (workers_get_type ())
#define WORKERS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_WORKERS, Workers))
#define WORKERS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_WORKERS, WorkersClass))
#define IS_WORKERS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_WORKERS))
#define IS_WORKERS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_WORKERS))
#define WORKERS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_WORKERS, WorkersClass))

typedef struct _Workers Workers;
typedef struct _WorkersClass WorkersClass;

#define TYPE_MEDIA_MONITOR (media_monitor_get_type ())
#define MEDIA_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_MONITOR, MediaMonitor))
#define MEDIA_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_MONITOR, MediaMonitorClass))
#define IS_MEDIA_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_MONITOR))
#define IS_MEDIA_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_MONITOR))
#define MEDIA_MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_MONITOR, MediaMonitorClass))

typedef struct _MediaMonitor MediaMonitor;
typedef struct _MediaMonitorClass MediaMonitorClass;

#define TYPE_MONITORABLE (monitorable_get_type ())
#define MONITORABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MONITORABLE, Monitorable))
#define IS_MONITORABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MONITORABLE))
#define MONITORABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TYPE_MONITORABLE, MonitorableIface))

typedef struct _Monitorable Monitorable;
typedef struct _MonitorableIface MonitorableIface;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_BATCH_IMPORT (batch_import_get_type ())
#define BATCH_IMPORT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT, BatchImport))
#define BATCH_IMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT, BatchImportClass))
#define IS_BATCH_IMPORT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT))
#define IS_BATCH_IMPORT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT))
#define BATCH_IMPORT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT, BatchImportClass))

typedef struct _BatchImport BatchImport;
typedef struct _BatchImportClass BatchImportClass;

#define TYPE_BATCH_IMPORT_ROLL (batch_import_roll_get_type ())
#define BATCH_IMPORT_ROLL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_ROLL, BatchImportRoll))
#define BATCH_IMPORT_ROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_ROLL, BatchImportRollClass))
#define IS_BATCH_IMPORT_ROLL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_ROLL))
#define IS_BATCH_IMPORT_ROLL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_ROLL))
#define BATCH_IMPORT_ROLL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_ROLL, BatchImportRollClass))

typedef struct _BatchImportRoll BatchImportRoll;
typedef struct _BatchImportRollClass BatchImportRollClass;

#define LIBRARY_MONITOR_TYPE_VERIFY_JOB (library_monitor_verify_job_get_type ())
#define LIBRARY_MONITOR_VERIFY_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_MONITOR_TYPE_VERIFY_JOB, LibraryMonitorVerifyJob))
#define LIBRARY_MONITOR_VERIFY_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_MONITOR_TYPE_VERIFY_JOB, LibraryMonitorVerifyJobClass))
#define LIBRARY_MONITOR_IS_VERIFY_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_MONITOR_TYPE_VERIFY_JOB))
#define LIBRARY_MONITOR_IS_VERIFY_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_MONITOR_TYPE_VERIFY_JOB))
#define LIBRARY_MONITOR_VERIFY_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_MONITOR_TYPE_VERIFY_JOB, LibraryMonitorVerifyJobClass))

typedef struct _LibraryMonitorVerifyJob LibraryMonitorVerifyJob;
typedef struct _LibraryMonitorVerifyJobClass LibraryMonitorVerifyJobClass;
enum  {
	LIBRARY_MONITOR_0_PROPERTY,
	LIBRARY_MONITOR_NUM_PROPERTIES
};
static GParamSpec* library_monitor_properties[LIBRARY_MONITOR_NUM_PROPERTIES];

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;

#define TYPE_HASH_TIMED_QUEUE (hash_timed_queue_get_type ())
#define HASH_TIMED_QUEUE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_HASH_TIMED_QUEUE, HashTimedQueue))
#define HASH_TIMED_QUEUE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_HASH_TIMED_QUEUE, HashTimedQueueClass))
#define IS_HASH_TIMED_QUEUE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_HASH_TIMED_QUEUE))
#define IS_HASH_TIMED_QUEUE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_HASH_TIMED_QUEUE))
#define HASH_TIMED_QUEUE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_HASH_TIMED_QUEUE, HashTimedQueueClass))

typedef struct _HashTimedQueue HashTimedQueue;
typedef struct _HashTimedQueueClass HashTimedQueueClass;
typedef void (*DequeuedCallback) (gconstpointer item, gpointer user_data);
#define _workers_unref0(var) ((var == NULL) ? NULL : (var = (workers_unref (var), NULL)))
#define _batch_import_roll_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_roll_unref (var), NULL)))

#define TYPE_DATA_COLLECTION (data_collection_get_type ())
#define DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_COLLECTION, DataCollection))
#define DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_COLLECTION, DataCollectionClass))
#define IS_DATA_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_COLLECTION))
#define IS_DATA_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_COLLECTION))
#define DATA_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_COLLECTION, DataCollectionClass))

typedef struct _DataCollection DataCollection;
typedef struct _DataCollectionClass DataCollectionClass;

#define TYPE_SOURCE_COLLECTION (source_collection_get_type ())
#define SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_COLLECTION, SourceCollection))
#define SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_COLLECTION, SourceCollectionClass))
#define IS_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_COLLECTION))
#define IS_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_COLLECTION))
#define SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_COLLECTION, SourceCollectionClass))

typedef struct _SourceCollection SourceCollection;
typedef struct _SourceCollectionClass SourceCollectionClass;

#define TYPE_DATABASE_SOURCE_COLLECTION (database_source_collection_get_type ())
#define DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollection))
#define DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))
#define IS_DATABASE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_COLLECTION))
#define IS_DATABASE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_COLLECTION))
#define DATABASE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_COLLECTION, DatabaseSourceCollectionClass))

typedef struct _DatabaseSourceCollection DatabaseSourceCollection;
typedef struct _DatabaseSourceCollectionClass DatabaseSourceCollectionClass;

#define TYPE_MEDIA_SOURCE_COLLECTION (media_source_collection_get_type ())
#define MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollection))
#define MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))
#define IS_MEDIA_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_COLLECTION))
#define IS_MEDIA_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_COLLECTION))
#define MEDIA_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_COLLECTION, MediaSourceCollectionClass))

typedef struct _MediaSourceCollection MediaSourceCollection;
typedef struct _MediaSourceCollectionClass MediaSourceCollectionClass;
#define _data_collection_unref0(var) ((var == NULL) ? NULL : (var = (data_collection_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define TYPE_MEDIA_COLLECTION_REGISTRY (media_collection_registry_get_type ())
#define MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistry))
#define MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))
#define IS_MEDIA_COLLECTION_REGISTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_COLLECTION_REGISTRY))
#define IS_MEDIA_COLLECTION_REGISTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_COLLECTION_REGISTRY))
#define MEDIA_COLLECTION_REGISTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_COLLECTION_REGISTRY, MediaCollectionRegistryClass))

typedef struct _MediaCollectionRegistry MediaCollectionRegistry;
typedef struct _MediaCollectionRegistryClass MediaCollectionRegistryClass;
#define _media_collection_registry_unref0(var) ((var == NULL) ? NULL : (var = (media_collection_registry_unref (var), NULL)))
typedef enum  {
	MEDIA_MONITOR_DISCOVERED_FILE_REPRESENTED,
	MEDIA_MONITOR_DISCOVERED_FILE_IGNORE,
	MEDIA_MONITOR_DISCOVERED_FILE_UNKNOWN
} MediaMonitorDiscoveredFile;

#define MEDIA_MONITOR_TYPE_DISCOVERED_FILE (media_monitor_discovered_file_get_type ())

#define TYPE_TOMBSTONE_SOURCE_COLLECTION (tombstone_source_collection_get_type ())
#define TOMBSTONE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TOMBSTONE_SOURCE_COLLECTION, TombstoneSourceCollection))
#define TOMBSTONE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TOMBSTONE_SOURCE_COLLECTION, TombstoneSourceCollectionClass))
#define IS_TOMBSTONE_SOURCE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TOMBSTONE_SOURCE_COLLECTION))
#define IS_TOMBSTONE_SOURCE_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TOMBSTONE_SOURCE_COLLECTION))
#define TOMBSTONE_SOURCE_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TOMBSTONE_SOURCE_COLLECTION, TombstoneSourceCollectionClass))

typedef struct _TombstoneSourceCollection TombstoneSourceCollection;
typedef struct _TombstoneSourceCollectionClass TombstoneSourceCollectionClass;

#define TYPE_BACKGROUND_JOB (background_job_get_type ())
#define BACKGROUND_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BACKGROUND_JOB, BackgroundJob))
#define BACKGROUND_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BACKGROUND_JOB, BackgroundJobClass))
#define IS_BACKGROUND_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BACKGROUND_JOB))
#define IS_BACKGROUND_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BACKGROUND_JOB))
#define BACKGROUND_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BACKGROUND_JOB, BackgroundJobClass))

typedef struct _BackgroundJob BackgroundJob;
typedef struct _BackgroundJobClass BackgroundJobClass;

#define LIBRARY_MONITOR_TYPE_FIND_MOVE_JOB (library_monitor_find_move_job_get_type ())
#define LIBRARY_MONITOR_FIND_MOVE_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_MONITOR_TYPE_FIND_MOVE_JOB, LibraryMonitorFindMoveJob))
#define LIBRARY_MONITOR_FIND_MOVE_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_MONITOR_TYPE_FIND_MOVE_JOB, LibraryMonitorFindMoveJobClass))
#define LIBRARY_MONITOR_IS_FIND_MOVE_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_MONITOR_TYPE_FIND_MOVE_JOB))
#define LIBRARY_MONITOR_IS_FIND_MOVE_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_MONITOR_TYPE_FIND_MOVE_JOB))
#define LIBRARY_MONITOR_FIND_MOVE_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_MONITOR_TYPE_FIND_MOVE_JOB, LibraryMonitorFindMoveJobClass))

typedef struct _LibraryMonitorFindMoveJob LibraryMonitorFindMoveJob;
typedef struct _LibraryMonitorFindMoveJobClass LibraryMonitorFindMoveJobClass;
#define _background_job_unref0(var) ((var == NULL) ? NULL : (var = (background_job_unref (var), NULL)))
typedef struct _LibraryMonitorAsyncDiscoveryCompletedData LibraryMonitorAsyncDiscoveryCompletedData;
typedef struct _BackgroundJobPrivate BackgroundJobPrivate;
typedef enum  {
	BACKGROUND_JOB_JOB_PRIORITY_HIGHEST = 100,
	BACKGROUND_JOB_JOB_PRIORITY_HIGH = 75,
	BACKGROUND_JOB_JOB_PRIORITY_NORMAL = 50,
	BACKGROUND_JOB_JOB_PRIORITY_LOW = 25,
	BACKGROUND_JOB_JOB_PRIORITY_LOWEST = 0
} BackgroundJobJobPriority;

#define BACKGROUND_JOB_TYPE_JOB_PRIORITY (background_job_job_priority_get_type ())
typedef struct _LibraryMonitorFindMoveJobPrivate LibraryMonitorFindMoveJobPrivate;

#define TYPE_SOURCE_HOLDING_TANK (source_holding_tank_get_type ())
#define SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank))
#define SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SOURCE_HOLDING_TANK, SourceHoldingTankClass))
#define IS_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SOURCE_HOLDING_TANK))
#define IS_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SOURCE_HOLDING_TANK))
#define SOURCE_HOLDING_TANK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SOURCE_HOLDING_TANK, SourceHoldingTankClass))

typedef struct _SourceHoldingTank SourceHoldingTank;
typedef struct _SourceHoldingTankClass SourceHoldingTankClass;

#define TYPE_DATABASE_SOURCE_HOLDING_TANK (database_source_holding_tank_get_type ())
#define DATABASE_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATABASE_SOURCE_HOLDING_TANK, DatabaseSourceHoldingTank))
#define DATABASE_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATABASE_SOURCE_HOLDING_TANK, DatabaseSourceHoldingTankClass))
#define IS_DATABASE_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATABASE_SOURCE_HOLDING_TANK))
#define IS_DATABASE_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATABASE_SOURCE_HOLDING_TANK))
#define DATABASE_SOURCE_HOLDING_TANK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATABASE_SOURCE_HOLDING_TANK, DatabaseSourceHoldingTankClass))

typedef struct _DatabaseSourceHoldingTank DatabaseSourceHoldingTank;
typedef struct _DatabaseSourceHoldingTankClass DatabaseSourceHoldingTankClass;

#define TYPE_MEDIA_SOURCE_HOLDING_TANK (media_source_holding_tank_get_type ())
#define MEDIA_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE_HOLDING_TANK, MediaSourceHoldingTank))
#define MEDIA_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE_HOLDING_TANK, MediaSourceHoldingTankClass))
#define IS_MEDIA_SOURCE_HOLDING_TANK(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE_HOLDING_TANK))
#define IS_MEDIA_SOURCE_HOLDING_TANK_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE_HOLDING_TANK))
#define MEDIA_SOURCE_HOLDING_TANK_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE_HOLDING_TANK, MediaSourceHoldingTankClass))

typedef struct _MediaSourceHoldingTank MediaSourceHoldingTank;
typedef struct _MediaSourceHoldingTankClass MediaSourceHoldingTankClass;
#define _source_holding_tank_unref0(var) ((var == NULL) ? NULL : (var = (source_holding_tank_unref (var), NULL)))
#define _library_monitor_verify_job_unref0(var) ((var == NULL) ? NULL : (var = (library_monitor_verify_job_unref (var), NULL)))
typedef struct _LibraryMonitorVerifyJobPrivate LibraryMonitorVerifyJobPrivate;
typedef struct _LibraryMonitorVerifyMonitorableData LibraryMonitorVerifyMonitorableData;

#define TYPE_BATCH_IMPORT_JOB (batch_import_job_get_type ())
#define BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJob))
#define BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))
#define IS_BATCH_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_JOB))
#define IS_BATCH_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_JOB))
#define BATCH_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_JOB, BatchImportJobClass))

typedef struct _BatchImportJob BatchImportJob;
typedef struct _BatchImportJobClass BatchImportJobClass;

#define TYPE_FILE_IMPORT_JOB (file_import_job_get_type ())
#define FILE_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_FILE_IMPORT_JOB, FileImportJob))
#define FILE_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_FILE_IMPORT_JOB, FileImportJobClass))
#define IS_FILE_IMPORT_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_FILE_IMPORT_JOB))
#define IS_FILE_IMPORT_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_FILE_IMPORT_JOB))
#define FILE_IMPORT_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_FILE_IMPORT_JOB, FileImportJobClass))

typedef struct _FileImportJob FileImportJob;
typedef struct _FileImportJobClass FileImportJobClass;
#define _batch_import_job_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_job_unref (var), NULL)))

#define TYPE_IMPORT_MANIFEST (import_manifest_get_type ())
#define IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_IMPORT_MANIFEST, ImportManifest))
#define IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_IMPORT_MANIFEST, ImportManifestClass))
#define IS_IMPORT_MANIFEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_IMPORT_MANIFEST))
#define IS_IMPORT_MANIFEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_IMPORT_MANIFEST))
#define IMPORT_MANIFEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_IMPORT_MANIFEST, ImportManifestClass))

typedef struct _ImportManifest ImportManifest;
typedef struct _ImportManifestClass ImportManifestClass;
typedef void (*BatchImportImportReporter) (ImportManifest* manifest, BatchImportRoll* import_roll, gpointer user_data);
typedef struct _ImportManifestPrivate ImportManifestPrivate;

#define TYPE_BATCH_IMPORT_RESULT (batch_import_result_get_type ())
#define BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResult))
#define BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))
#define IS_BATCH_IMPORT_RESULT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_BATCH_IMPORT_RESULT))
#define IS_BATCH_IMPORT_RESULT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_BATCH_IMPORT_RESULT))
#define BATCH_IMPORT_RESULT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_BATCH_IMPORT_RESULT, BatchImportResultClass))

typedef struct _BatchImportResult BatchImportResult;
typedef struct _BatchImportResultClass BatchImportResultClass;
typedef struct _BatchImportResultPrivate BatchImportResultPrivate;
typedef enum  {
	IMPORT_RESULT_SUCCESS,
	IMPORT_RESULT_FILE_ERROR,
	IMPORT_RESULT_DECODE_ERROR,
	IMPORT_RESULT_DATABASE_ERROR,
	IMPORT_RESULT_USER_ABORT,
	IMPORT_RESULT_NOT_A_FILE,
	IMPORT_RESULT_PHOTO_EXISTS,
	IMPORT_RESULT_UNSUPPORTED_FORMAT,
	IMPORT_RESULT_NOT_AN_IMAGE,
	IMPORT_RESULT_DISK_FAILURE,
	IMPORT_RESULT_DISK_FULL,
	IMPORT_RESULT_CAMERA_ERROR,
	IMPORT_RESULT_FILE_WRITE_ERROR,
	IMPORT_RESULT_PIXBUF_CORRUPT_IMAGE
} ImportResult;

#define TYPE_IMPORT_RESULT (import_result_get_type ())

#define TYPE_DUPLICATED_FILE (duplicated_file_get_type ())
#define DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DUPLICATED_FILE, DuplicatedFile))
#define DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DUPLICATED_FILE, DuplicatedFileClass))
#define IS_DUPLICATED_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DUPLICATED_FILE))
#define IS_DUPLICATED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DUPLICATED_FILE))
#define DUPLICATED_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DUPLICATED_FILE, DuplicatedFileClass))

typedef struct _DuplicatedFile DuplicatedFile;
typedef struct _DuplicatedFileClass DuplicatedFileClass;
#define _batch_import_result_unref0(var) ((var == NULL) ? NULL : (var = (batch_import_result_unref (var), NULL)))

#define TYPE_TOMBSTONED_FILE (tombstoned_file_get_type ())
#define TOMBSTONED_FILE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TOMBSTONED_FILE, TombstonedFile))
#define TOMBSTONED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TOMBSTONED_FILE, TombstonedFileClass))
#define IS_TOMBSTONED_FILE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TOMBSTONED_FILE))
#define IS_TOMBSTONED_FILE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TOMBSTONED_FILE))
#define TOMBSTONED_FILE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TOMBSTONED_FILE, TombstonedFileClass))

typedef struct _TombstonedFile TombstonedFile;
typedef struct _TombstonedFileClass TombstonedFileClass;
#define _tombstoned_file_unref0(var) ((var == NULL) ? NULL : (var = (tombstoned_file_unref (var), NULL)))
typedef enum  {
	TOMBSTONE_REASON_REMOVED_BY_USER = 0,
	TOMBSTONE_REASON_AUTO_DETECTED_DUPLICATE = 1
} TombstoneReason;

#define TOMBSTONE_TYPE_REASON (tombstone_reason_get_type ())

#define TYPE_DATABASE_ERROR (database_error_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define LIBRARY_MONITOR_TYPE_RUNTIME_FIND_MOVE_JOB (library_monitor_runtime_find_move_job_get_type ())
#define LIBRARY_MONITOR_RUNTIME_FIND_MOVE_JOB(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), LIBRARY_MONITOR_TYPE_RUNTIME_FIND_MOVE_JOB, LibraryMonitorRuntimeFindMoveJob))
#define LIBRARY_MONITOR_RUNTIME_FIND_MOVE_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), LIBRARY_MONITOR_TYPE_RUNTIME_FIND_MOVE_JOB, LibraryMonitorRuntimeFindMoveJobClass))
#define LIBRARY_MONITOR_IS_RUNTIME_FIND_MOVE_JOB(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), LIBRARY_MONITOR_TYPE_RUNTIME_FIND_MOVE_JOB))
#define LIBRARY_MONITOR_IS_RUNTIME_FIND_MOVE_JOB_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LIBRARY_MONITOR_TYPE_RUNTIME_FIND_MOVE_JOB))
#define LIBRARY_MONITOR_RUNTIME_FIND_MOVE_JOB_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), LIBRARY_MONITOR_TYPE_RUNTIME_FIND_MOVE_JOB, LibraryMonitorRuntimeFindMoveJobClass))

typedef struct _LibraryMonitorRuntimeFindMoveJob LibraryMonitorRuntimeFindMoveJob;
typedef struct _LibraryMonitorRuntimeFindMoveJobClass LibraryMonitorRuntimeFindMoveJobClass;
typedef struct _LibraryMonitorRuntimeFindMoveJobPrivate LibraryMonitorRuntimeFindMoveJobPrivate;

#define TYPE_TOMBSTONE (tombstone_get_type ())
#define TOMBSTONE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_TOMBSTONE, Tombstone))
#define TOMBSTONE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_TOMBSTONE, TombstoneClass))
#define IS_TOMBSTONE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_TOMBSTONE))
#define IS_TOMBSTONE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_TOMBSTONE))
#define TOMBSTONE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_TOMBSTONE, TombstoneClass))

typedef struct _Tombstone Tombstone;
typedef struct _TombstoneClass TombstoneClass;
typedef void (*CompletionCallback) (BackgroundJob* job, gpointer user_data);
typedef void (*CancellationCallback) (BackgroundJob* job, gpointer user_data);

#define TYPE_ABSTRACT_SEMAPHORE (abstract_semaphore_get_type ())
#define ABSTRACT_SEMAPHORE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_ABSTRACT_SEMAPHORE, AbstractSemaphore))
#define ABSTRACT_SEMAPHORE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_ABSTRACT_SEMAPHORE, AbstractSemaphoreClass))
#define IS_ABSTRACT_SEMAPHORE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_ABSTRACT_SEMAPHORE))
#define IS_ABSTRACT_SEMAPHORE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_ABSTRACT_SEMAPHORE))
#define ABSTRACT_SEMAPHORE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_ABSTRACT_SEMAPHORE, AbstractSemaphoreClass))

typedef struct _AbstractSemaphore AbstractSemaphore;
typedef struct _AbstractSemaphoreClass AbstractSemaphoreClass;
typedef struct _LibraryMonitorParamSpecVerifyJob LibraryMonitorParamSpecVerifyJob;
enum  {
	LIBRARY_MONITOR_AUTO_UPDATE_PROGRESS_SIGNAL,
	LIBRARY_MONITOR_AUTO_IMPORT_PREPARING_SIGNAL,
	LIBRARY_MONITOR_AUTO_IMPORT_PROGRESS_SIGNAL,
	LIBRARY_MONITOR_NUM_SIGNALS
};
static guint library_monitor_signals[LIBRARY_MONITOR_NUM_SIGNALS] = {0};
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _LibraryMonitorPool {
	GTypeInstance parent_instance;
	volatile int ref_count;
	LibraryMonitorPoolPrivate * priv;
};

struct _LibraryMonitorPoolClass {
	GTypeClass parent_class;
	void (*finalize) (LibraryMonitorPool *self);
};

struct _LibraryMonitorPoolPrivate {
	LibraryMonitor* monitor;
	guint timer_id;
};

struct _ParamSpecLibraryMonitorPool {
	GParamSpec parent_instance;
};

struct _DirectoryMonitor {
	GObject parent_instance;
	DirectoryMonitorPrivate * priv;
};

struct _DirectoryMonitorClass {
	GObjectClass parent_class;
	void (*notify_root_deleted) (DirectoryMonitor* self, GFile* root);
	void (*notify_root_moved) (DirectoryMonitor* self, GFile* old_root, GFile* new_root, GFileInfo* new_root_info);
	void (*notify_discovery_started) (DirectoryMonitor* self);
	void (*internal_notify_file_discovered) (DirectoryMonitor* self, GFile* file, GFileInfo* info);
	void (*notify_file_discovered) (DirectoryMonitor* self, GFile* file, GFileInfo* info);
	void (*internal_notify_directory_discovered) (DirectoryMonitor* self, GFile* dir, GFileInfo* info);
	void (*notify_directory_discovered) (DirectoryMonitor* self, GFile* dir, GFileInfo* info);
	void (*notify_discovery_failed) (DirectoryMonitor* self, const gchar* reason);
	void (*notify_discovery_completed) (DirectoryMonitor* self);
	void (*notify_file_created) (DirectoryMonitor* self, GFile* file, GFileInfo* info);
	void (*notify_file_moved) (DirectoryMonitor* self, GFile* old_file, GFile* new_file, GFileInfo* new_file_info);
	void (*notify_file_altered) (DirectoryMonitor* self, GFile* file);
	void (*notify_file_alteration_completed) (DirectoryMonitor* self, GFile* file, GFileInfo* info);
	void (*notify_file_attributes_altered) (DirectoryMonitor* self, GFile* file);
	void (*notify_file_deleted) (DirectoryMonitor* self, GFile* file);
	void (*notify_directory_created) (DirectoryMonitor* self, GFile* dir, GFileInfo* info);
	void (*notify_directory_moved) (DirectoryMonitor* self, GFile* old_dir, GFile* new_dir, GFileInfo* new_dir_info);
	void (*notify_directory_altered) (DirectoryMonitor* self, GFile* dir);
	void (*notify_directory_alteration_completed) (DirectoryMonitor* self, GFile* dir, GFileInfo* info);
	void (*notify_directory_attributes_altered) (DirectoryMonitor* self, GFile* dir);
	void (*notify_directory_deleted) (DirectoryMonitor* self, GFile* dir);
	void (*notify_closed) (DirectoryMonitor* self);
	void (*close) (DirectoryMonitor* self);
	void (*root_moved) (DirectoryMonitor* self, GFile* old_root, GFile* new_root, GFileInfo* new_root_info);
	void (*root_deleted) (DirectoryMonitor* self, GFile* root);
	void (*discovery_started) (DirectoryMonitor* self);
	void (*file_discovered) (DirectoryMonitor* self, GFile* file, GFileInfo* info);
	void (*directory_discovered) (DirectoryMonitor* self, GFile* file, GFileInfo* info);
	void (*discovery_failed) (DirectoryMonitor* self, const gchar* reason);
	void (*discovery_completed) (DirectoryMonitor* self);
	void (*file_created) (DirectoryMonitor* self, GFile* file, GFileInfo* info);
	void (*file_moved) (DirectoryMonitor* self, GFile* old_file, GFile* new_file, GFileInfo* new_file_info);
	void (*file_altered) (DirectoryMonitor* self, GFile* file);
	void (*file_alteration_completed) (DirectoryMonitor* self, GFile* file, GFileInfo* info);
	void (*file_attributes_altered) (DirectoryMonitor* self, GFile* file);
	void (*file_deleted) (DirectoryMonitor* self, GFile* file);
	void (*directory_created) (DirectoryMonitor* self, GFile* dir, GFileInfo* info);
	void (*directory_moved) (DirectoryMonitor* self, GFile* old_dir, GFile* new_dir, GFileInfo* new_dir_info);
	void (*directory_altered) (DirectoryMonitor* self, GFile* dir);
	void (*directory_alteration_completed) (DirectoryMonitor* self, GFile* dir, GFileInfo* info);
	void (*directory_attributes_altered) (DirectoryMonitor* self, GFile* dir);
	void (*directory_deleted) (DirectoryMonitor* self, GFile* dir);
	void (*closed) (DirectoryMonitor* self);
};

struct _LibraryMonitor {
	DirectoryMonitor parent_instance;
	LibraryMonitorPrivate * priv;
};

struct _LibraryMonitorClass {
	DirectoryMonitorClass parent_class;
};

struct _MonitorableIface {
	GTypeInterface parent_iface;
	gboolean (*is_offline) (Monitorable* self);
	void (*mark_online) (Monitorable* self);
	void (*mark_offline) (Monitorable* self);
	void (*set_master_file) (Monitorable* self, GFile* file);
	void (*set_master_timestamp) (Monitorable* self, GFileInfo* info);
};

struct _LibraryMonitorPrivate {
	Workers* workers;
	GCancellable* cancellable;
	gboolean auto_import;
	GeeHashSet* unknown_files;
	GeeList* monitors;
	GeeHashMap* discovered;
	GeeHashSet* import_queue;
	GeeHashSet* pending_imports;
	GeeArrayList* batch_import_queue;
	BatchImportRoll* current_import_roll;
	gint64 last_import_roll_use;
	BatchImport* current_batch_import;
	gint checksums_completed;
	gint checksums_total;
	guint import_queue_timer_id;
	GeeQueue* verify_queue;
	gint outstanding_verify_jobs;
	gint completed_monitorable_verifies;
	gint total_monitorable_verifies;
};

struct _LibraryMonitorAsyncDiscoveryCompletedData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	LibraryMonitor* self;
	GeeHashSet* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	GeeArrayList* all_candidates;
	GeeArrayList* _tmp3_;
	GeeArrayList* adopted;
	GeeArrayList* _tmp4_;
	GeeIterator* _file_it;
	GeeHashSet* _tmp5_;
	GeeIterator* _tmp6_;
	GeeIterator* _tmp7_;
	GFile* file;
	GeeIterator* _tmp8_;
	gpointer _tmp9_;
	GFileInfo* info;
	GFile* _tmp10_;
	GFileInfo* _tmp11_;
	GFileInfo* _tmp12_;
	GeeArrayList* _tmp13_;
	GeeCollection* candidates;
	gboolean associated;
	GeeList* _monitor_list;
	GeeList* _tmp14_;
	gint _monitor_size;
	GeeList* _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	gint _monitor_index;
	gint _tmp18_;
	gint _tmp19_;
	MediaMonitor* monitor;
	GeeList* _tmp20_;
	gpointer _tmp21_;
	MediaMonitorDiscoveredFile _result_;
	MediaMonitor* _tmp22_;
	GFile* _tmp23_;
	GFileInfo* _tmp24_;
	MediaMonitorDiscoveredFile _tmp25_;
	GeeCollection* _tmp26_;
	gboolean _tmp27_;
	GeeCollection* _tmp28_;
	GeeArrayList* _tmp29_;
	GeeCollection* _tmp30_;
	GeeArrayList* _tmp31_;
	GFile* _tmp32_;
	GeeArrayList* _tmp33_;
	gint _tmp34_;
	gint _tmp35_;
	GeeArrayList* job_candidates;
	GeeArrayList* _tmp36_;
	GeeArrayList* _tmp37_;
	GeeArrayList* _tmp38_;
	gint _tmp39_;
	Workers* _tmp40_;
	GFile* _tmp41_;
	GeeArrayList* _tmp42_;
	LibraryMonitorFindMoveJob* _tmp43_;
	LibraryMonitorFindMoveJob* _tmp44_;
	GeeHashSet* _tmp45_;
	GeeArrayList* _tmp46_;
	gchar* _tmp47_;
	gchar* _tmp48_;
};

struct _BackgroundJob {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BackgroundJobPrivate * priv;
};

struct _BackgroundJobClass {
	GTypeClass parent_class;
	void (*finalize) (BackgroundJob *self);
	void (*execute) (BackgroundJob* self);
	BackgroundJobJobPriority (*get_priority) (BackgroundJob* self);
};

struct _LibraryMonitorFindMoveJob {
	BackgroundJob parent_instance;
	LibraryMonitorFindMoveJobPrivate * priv;
	GFile* file;
	GeeCollection* candidates;
	Monitorable* match;
	GeeArrayList* losers;
	GError* err;
};

struct _LibraryMonitorFindMoveJobClass {
	BackgroundJobClass parent_class;
};

struct _LibraryMonitorVerifyJob {
	GTypeInstance parent_instance;
	volatile int ref_count;
	LibraryMonitorVerifyJobPrivate * priv;
	Monitorable* monitorable;
	MediaMonitor* monitor;
};

struct _LibraryMonitorVerifyJobClass {
	GTypeClass parent_class;
	void (*finalize) (LibraryMonitorVerifyJob *self);
};

struct _LibraryMonitorVerifyMonitorableData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	LibraryMonitor* self;
	Monitorable* monitorable;
	MediaMonitor* monitor;
	GFile** files;
	GFile** _tmp0_;
	gint files_length1;
	gint _files_size_;
	GFile** _tmp1_;
	gint _tmp1__length1;
	GFile* _tmp2_;
	GFile** aux_files;
	gint _tmp3_;
	GFile** _tmp4_;
	gint aux_files_length1;
	gint _aux_files_size_;
	GFile** _tmp5_;
	gint _tmp5__length1;
	GFile** _tmp6_;
	gint _tmp6__length1;
	GFile** aux_file_collection;
	gint aux_file_collection_length1;
	gint _aux_file_collection_size_;
	gint aux_file_it;
	GFile* _tmp7_;
	GFile* aux_file;
	GFile* _tmp8_;
	GFile* _tmp9_;
	gint ctr;
	gboolean _tmp10_;
	gint _tmp11_;
	GFile** _tmp12_;
	gint _tmp12__length1;
	GFile* file;
	GFile** _tmp13_;
	gint _tmp13__length1;
	GFile* _tmp14_;
	GFile* _tmp15_;
	GFileInfo* info;
	GFile* _tmp16_;
	GFileInfo* _tmp17_;
	GFileInfo* _tmp18_;
	GFileInfo* _tmp19_;
	GFile* _tmp20_;
	GCancellable* _tmp21_;
	GFileInfo* _tmp22_;
	GFileInfo* _tmp23_;
	gboolean _tmp24_;
	GFileInfo* _tmp25_;
	gboolean _tmp26_;
	GFileInfo* _tmp27_;
	GFile* _tmp28_;
	GFileInfo* _tmp29_;
	gint _tmp30_;
	gint _tmp31_;
	GError* _inner_error0_;
};

struct _ImportManifest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	ImportManifestPrivate * priv;
	GeeList* imported;
	GeeList* success;
	GeeList* camera_failed;
	GeeList* failed;
	GeeList* write_failed;
	GeeList* skipped_photos;
	GeeList* skipped_files;
	GeeList* aborted;
	GeeList* already_imported;
	GeeList* corrupt_files;
	GeeList* all;
	GTimer* timer;
};

struct _ImportManifestClass {
	GTypeClass parent_class;
	void (*finalize) (ImportManifest *self);
};

struct _BatchImportResult {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BatchImportResultPrivate * priv;
	BatchImportJob* job;
	GFile* file;
	gchar* src_identifier;
	gchar* dest_identifier;
	ImportResult result;
	gchar* errmsg;
	DuplicatedFile* duplicate_of;
};

struct _BatchImportResultClass {
	GTypeClass parent_class;
	void (*finalize) (BatchImportResult *self);
};

typedef enum  {
	DATABASE_ERROR_ERROR,
	DATABASE_ERROR_BACKING,
	DATABASE_ERROR_MEMORY,
	DATABASE_ERROR_ABORT,
	DATABASE_ERROR_LIMITS,
	DATABASE_ERROR_TYPESPEC
} DatabaseError;
#define DATABASE_ERROR database_error_quark ()

struct _LibraryMonitorRuntimeFindMoveJob {
	BackgroundJob parent_instance;
	LibraryMonitorRuntimeFindMoveJobPrivate * priv;
	GFile* file;
	GeeCollection* candidates;
	Monitorable* match;
	GError* err;
};

struct _LibraryMonitorRuntimeFindMoveJobClass {
	BackgroundJobClass parent_class;
};

struct _LibraryMonitorParamSpecVerifyJob {
	GParamSpec parent_instance;
};

static gint LibraryMonitorPool_private_offset;
static gpointer library_monitor_pool_parent_class = NULL;
static LibraryMonitorPool* library_monitor_pool_instance;
static LibraryMonitorPool* library_monitor_pool_instance = NULL;
static gint LibraryMonitor_private_offset;
static gpointer library_monitor_parent_class = NULL;
static GeeHashSet* library_monitor_blacklist;
static GRecMutex __lock_library_monitor_library_monitor_blacklist = {0};
static GeeHashSet* library_monitor_blacklist = NULL;
static HashTimedQueue* library_monitor_to_unblacklist;
static HashTimedQueue* library_monitor_to_unblacklist = NULL;
VALA_EXTERN TombstoneSourceCollection* tombstone_global;
VALA_EXTERN gboolean commandline_options_no_runtime_monitoring;
static gpointer library_monitor_find_move_job_parent_class = NULL;
static gpointer library_monitor_runtime_find_move_job_parent_class = NULL;
static gpointer library_monitor_verify_job_parent_class = NULL;

VALA_EXTERN gpointer library_monitor_pool_ref (gpointer instance);
VALA_EXTERN void library_monitor_pool_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_library_monitor_pool (const gchar* name,
                                             const gchar* nick,
                                             const gchar* blurb,
                                             GType object_type,
                                             GParamFlags flags);
VALA_EXTERN void value_set_library_monitor_pool (GValue* value,
                                     gpointer v_object);
VALA_EXTERN void value_take_library_monitor_pool (GValue* value,
                                      gpointer v_object);
VALA_EXTERN gpointer value_get_library_monitor_pool (const GValue* value);
VALA_EXTERN GType library_monitor_pool_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LibraryMonitorPool, library_monitor_pool_unref)
VALA_EXTERN GType directory_monitor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DirectoryMonitor, g_object_unref)
VALA_EXTERN GType library_monitor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LibraryMonitor, g_object_unref)
static LibraryMonitorPool* library_monitor_pool_new (void);
static LibraryMonitorPool* library_monitor_pool_construct (GType object_type);
VALA_EXTERN void library_monitor_pool_init (void);
VALA_EXTERN void library_monitor_pool_terminate (void);
static void library_monitor_pool_close (LibraryMonitorPool* self);
VALA_EXTERN LibraryMonitorPool* library_monitor_pool_get_instance (void);
VALA_EXTERN LibraryMonitor* library_monitor_pool_get_monitor (LibraryMonitorPool* self);
VALA_EXTERN void library_monitor_pool_replace (LibraryMonitorPool* self,
                                   LibraryMonitor* replacement,
                                   gint start_msec_delay);
static gboolean library_monitor_pool_on_start_monitor (LibraryMonitorPool* self);
static gboolean _library_monitor_pool_on_start_monitor_gsource_func (gpointer self);
VALA_EXTERN void directory_monitor_close (DirectoryMonitor* self);
VALA_EXTERN void directory_monitor_start_discovery (DirectoryMonitor* self);
static void library_monitor_pool_finalize (LibraryMonitorPool * obj);
static GType library_monitor_pool_get_type_once (void);
VALA_EXTERN gpointer workers_ref (gpointer instance);
VALA_EXTERN void workers_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_workers (const gchar* name,
                                const gchar* nick,
                                const gchar* blurb,
                                GType object_type,
                                GParamFlags flags);
VALA_EXTERN void value_set_workers (GValue* value,
                        gpointer v_object);
VALA_EXTERN void value_take_workers (GValue* value,
                         gpointer v_object);
VALA_EXTERN gpointer value_get_workers (const GValue* value);
VALA_EXTERN GType workers_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Workers, workers_unref)
VALA_EXTERN GType media_monitor_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MediaMonitor, g_object_unref)
VALA_EXTERN GType data_object_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DataObject, g_object_unref)
VALA_EXTERN GType data_source_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DataSource, g_object_unref)
VALA_EXTERN GType thumbnail_source_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ThumbnailSource, g_object_unref)
VALA_EXTERN GType media_source_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MediaSource, g_object_unref)
VALA_EXTERN GType monitorable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Monitorable, g_object_unref)
VALA_EXTERN GType batch_import_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BatchImport, g_object_unref)
VALA_EXTERN gpointer batch_import_roll_ref (gpointer instance);
VALA_EXTERN void batch_import_roll_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_batch_import_roll (const gchar* name,
                                          const gchar* nick,
                                          const gchar* blurb,
                                          GType object_type,
                                          GParamFlags flags);
VALA_EXTERN void value_set_batch_import_roll (GValue* value,
                                  gpointer v_object);
VALA_EXTERN void value_take_batch_import_roll (GValue* value,
                                   gpointer v_object);
VALA_EXTERN gpointer value_get_batch_import_roll (const GValue* value);
VALA_EXTERN GType batch_import_roll_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BatchImportRoll, batch_import_roll_unref)
static gpointer library_monitor_verify_job_ref (gpointer instance);
static void library_monitor_verify_job_unref (gpointer instance);
static GParamSpec* library_monitor_param_spec_verify_job (const gchar* name,
                                                   const gchar* nick,
                                                   const gchar* blurb,
                                                   GType object_type,
                                                   GParamFlags flags) G_GNUC_UNUSED ;
static void library_monitor_value_set_verify_job (GValue* value,
                                           gpointer v_object) G_GNUC_UNUSED ;
static void library_monitor_value_take_verify_job (GValue* value,
                                            gpointer v_object) G_GNUC_UNUSED ;
static gpointer library_monitor_value_get_verify_job (const GValue* value) G_GNUC_UNUSED ;
static GType library_monitor_verify_job_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LibraryMonitorVerifyJob, library_monitor_verify_job_unref)
VALA_EXTERN void directory_monitor_discovery_started (DirectoryMonitor* self);
VALA_EXTERN void directory_monitor_file_discovered (DirectoryMonitor* self,
                                        GFile* file,
                                        GFileInfo* info);
VALA_EXTERN void directory_monitor_discovery_completed (DirectoryMonitor* self);
VALA_EXTERN void directory_monitor_notify_file_created (DirectoryMonitor* self,
                                            GFile* file,
                                            GFileInfo* info);
VALA_EXTERN void directory_monitor_notify_file_moved (DirectoryMonitor* self,
                                          GFile* old_file,
                                          GFile* new_file,
                                          GFileInfo* new_file_info);
VALA_EXTERN void directory_monitor_notify_file_altered (DirectoryMonitor* self,
                                            GFile* file);
VALA_EXTERN void directory_monitor_notify_file_attributes_altered (DirectoryMonitor* self,
                                                       GFile* file);
VALA_EXTERN void directory_monitor_notify_file_alteration_completed (DirectoryMonitor* self,
                                                         GFile* file,
                                                         GFileInfo* info);
VALA_EXTERN void directory_monitor_notify_file_deleted (DirectoryMonitor* self,
                                            GFile* file);
VALA_EXTERN GType configuration_facade_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ConfigurationFacade, g_object_unref)
VALA_EXTERN GType config_facade_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ConfigFacade, g_object_unref)
VALA_EXTERN ConfigFacade* config_facade_get_instance (void);
static void library_monitor_on_config_changed (LibraryMonitor* self);
static void _library_monitor_on_config_changed_configuration_facade_auto_import_from_library_changed (ConfigurationFacade* _sender,
                                                                                               gpointer self);
VALA_EXTERN guint file_hash (GFile* file);
static guint _file_hash_gee_hash_data_func (gconstpointer v,
                                     gpointer self);
VALA_EXTERN gboolean file_equal (GFile* a,
                     GFile* b);
static gboolean _file_equal_gee_equal_data_func (gconstpointer a,
                                          gconstpointer b,
                                          gpointer self);
VALA_EXTERN gpointer hash_timed_queue_ref (gpointer instance);
VALA_EXTERN void hash_timed_queue_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_hash_timed_queue (const gchar* name,
                                         const gchar* nick,
                                         const gchar* blurb,
                                         GType object_type,
                                         GParamFlags flags);
VALA_EXTERN void value_set_hash_timed_queue (GValue* value,
                                 gpointer v_object);
VALA_EXTERN void value_take_hash_timed_queue (GValue* value,
                                  gpointer v_object);
VALA_EXTERN gpointer value_get_hash_timed_queue (const GValue* value);
VALA_EXTERN GType hash_timed_queue_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (HashTimedQueue, hash_timed_queue_unref)
static void library_monitor_on_unblacklist_file (GFile* file);
static void _library_monitor_on_unblacklist_file_dequeued_callback (gconstpointer item,
                                                             gpointer self);
VALA_EXTERN HashTimedQueue* hash_timed_queue_new (GType g_type,
                                      GBoxedCopyFunc g_dup_func,
                                      GDestroyNotify g_destroy_func,
                                      guint hold_msec,
                                      DequeuedCallback callback,
                                      gpointer callback_target,
                                      GeeHashDataFunc hash_func,
                                      gpointer hash_func_target,
                                      GDestroyNotify hash_func_target_destroy_notify,
                                      GeeEqualDataFunc equal_func,
                                      gpointer equal_func_target,
                                      GDestroyNotify equal_func_target_destroy_notify,
                                      gint priority);
VALA_EXTERN HashTimedQueue* hash_timed_queue_construct (GType object_type,
                                            GType g_type,
                                            GBoxedCopyFunc g_dup_func,
                                            GDestroyNotify g_destroy_func,
                                            guint hold_msec,
                                            DequeuedCallback callback,
                                            gpointer callback_target,
                                            GeeHashDataFunc hash_func,
                                            gpointer hash_func_target,
                                            GDestroyNotify hash_func_target_destroy_notify,
                                            GeeEqualDataFunc equal_func,
                                            gpointer equal_func_target,
                                            GDestroyNotify equal_func_target_destroy_notify,
                                            gint priority);
VALA_EXTERN guint workers_thread_per_cpu_minus_one (void);
VALA_EXTERN Workers* workers_new (guint max_threads,
                      gboolean exclusive);
VALA_EXTERN Workers* workers_construct (GType object_type,
                            guint max_threads,
                            gboolean exclusive);
VALA_EXTERN LibraryMonitor* library_monitor_new (GFile* root,
                                     gboolean recurse,
                                     gboolean monitoring);
VALA_EXTERN LibraryMonitor* library_monitor_construct (GType object_type,
                                           GFile* root,
                                           gboolean recurse,
                                           gboolean monitoring);
VALA_EXTERN DirectoryMonitor* directory_monitor_new (GFile* root,
                                         gboolean recurse,
                                         gboolean monitoring);
VALA_EXTERN DirectoryMonitor* directory_monitor_construct (GType object_type,
                                               GFile* root,
                                               gboolean recurse,
                                               gboolean monitoring);
VALA_EXTERN gboolean configuration_facade_get_auto_import_from_library (ConfigurationFacade* self);
static gboolean library_monitor_on_flush_import_queue (LibraryMonitor* self);
static gboolean _library_monitor_on_flush_import_queue_gsource_func (gpointer self);
static void library_monitor_real_close (DirectoryMonitor* base);
VALA_EXTERN void media_monitor_close (MediaMonitor* self);
static void library_monitor_add_to_discovered_list (LibraryMonitor* self,
                                             MediaMonitor* monitor,
                                             Monitorable* monitorable);
static MediaMonitor* library_monitor_get_monitor_for_monitorable (LibraryMonitor* self,
                                                           Monitorable* monitorable);
VALA_EXTERN gpointer data_collection_ref (gpointer instance);
VALA_EXTERN void data_collection_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_data_collection (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
VALA_EXTERN void value_set_data_collection (GValue* value,
                                gpointer v_object);
VALA_EXTERN void value_take_data_collection (GValue* value,
                                 gpointer v_object);
VALA_EXTERN gpointer value_get_data_collection (const GValue* value);
VALA_EXTERN GType data_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DataCollection, data_collection_unref)
VALA_EXTERN GType source_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SourceCollection, data_collection_unref)
VALA_EXTERN GType database_source_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DatabaseSourceCollection, data_collection_unref)
VALA_EXTERN GType media_source_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MediaSourceCollection, data_collection_unref)
VALA_EXTERN MediaSourceCollection* media_monitor_get_media_source_collection (MediaMonitor* self);
VALA_EXTERN gboolean source_collection_holds_type_of_source (SourceCollection* self,
                                                 DataSource* source);
VALA_EXTERN gchar* data_object_to_string (DataObject* self);
static void library_monitor_real_discovery_started (DirectoryMonitor* base);
VALA_EXTERN gpointer media_collection_registry_ref (gpointer instance);
VALA_EXTERN void media_collection_registry_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_media_collection_registry (const gchar* name,
                                                  const gchar* nick,
                                                  const gchar* blurb,
                                                  GType object_type,
                                                  GParamFlags flags);
VALA_EXTERN void value_set_media_collection_registry (GValue* value,
                                          gpointer v_object);
VALA_EXTERN void value_take_media_collection_registry (GValue* value,
                                           gpointer v_object);
VALA_EXTERN gpointer value_get_media_collection_registry (const GValue* value);
VALA_EXTERN GType media_collection_registry_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MediaCollectionRegistry, media_collection_registry_unref)
VALA_EXTERN MediaCollectionRegistry* media_collection_registry_get_instance (void);
VALA_EXTERN GeeCollection* media_collection_registry_get_all (MediaCollectionRegistry* self);
VALA_EXTERN MediaMonitor* media_source_collection_create_media_monitor (MediaSourceCollection* self,
                                                            Workers* workers,
                                                            GCancellable* cancellable);
VALA_EXTERN void media_monitor_notify_discovery_started (MediaMonitor* self);
static void library_monitor_real_file_discovered (DirectoryMonitor* base,
                                           GFile* file,
                                           GFileInfo* info);
VALA_EXTERN GType media_monitor_discovered_file_get_type (void) G_GNUC_CONST ;
VALA_EXTERN MediaMonitorDiscoveredFile media_monitor_notify_file_discovered (MediaMonitor* self,
                                                                 GFile* file,
                                                                 GFileInfo* info,
                                                                 Monitorable** monitorable);
VALA_EXTERN GType tombstone_source_collection_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TombstoneSourceCollection, data_collection_unref)
VALA_EXTERN gboolean tombstone_source_collection_matches (TombstoneSourceCollection* self,
                                              GFile* file);
static gboolean library_monitor_is_supported_filetype (LibraryMonitor* self,
                                                GFile* file);
static void library_monitor_real_discovery_completed (DirectoryMonitor* base);
static void library_monitor_async_discovery_completed (LibraryMonitor* self,
                                                GAsyncReadyCallback _callback_,
                                                gpointer _user_data_);
static void library_monitor_async_discovery_completed_finish (LibraryMonitor* self,
                                                       GAsyncResult* _res_);
static void library_monitor_async_discovery_completed_data_free (gpointer _data);
static gboolean library_monitor_async_discovery_completed_co (LibraryMonitorAsyncDiscoveryCompletedData* _data_);
static void library_monitor_discovery_stage_completed (LibraryMonitor* self);
VALA_EXTERN GFileInfo* directory_monitor_get_file_info (DirectoryMonitor* self,
                                            GFile* file);
VALA_EXTERN GeeCollection* media_monitor_candidates_for_unknown_file (MediaMonitor* self,
                                                          GFile* file,
                                                          GFileInfo* info,
                                                          MediaMonitorDiscoveredFile* _result_);
VALA_EXTERN gpointer background_job_ref (gpointer instance);
VALA_EXTERN void background_job_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_background_job (const gchar* name,
                                       const gchar* nick,
                                       const gchar* blurb,
                                       GType object_type,
                                       GParamFlags flags);
VALA_EXTERN void value_set_background_job (GValue* value,
                               gpointer v_object);
VALA_EXTERN void value_take_background_job (GValue* value,
                                gpointer v_object);
VALA_EXTERN gpointer value_get_background_job (const GValue* value);
VALA_EXTERN GType background_job_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BackgroundJob, background_job_unref)
VALA_EXTERN void workers_enqueue (Workers* self,
                      BackgroundJob* job);
static LibraryMonitorFindMoveJob* library_monitor_find_move_job_new (LibraryMonitor* owner,
                                                              GFile* file,
                                                              GeeCollection* candidates);
static LibraryMonitorFindMoveJob* library_monitor_find_move_job_construct (GType object_type,
                                                                    LibraryMonitor* owner,
                                                                    GFile* file,
                                                                    GeeCollection* candidates);
static GType library_monitor_find_move_job_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LibraryMonitorFindMoveJob, background_job_unref)
static gboolean _library_monitor_async_discovery_completed_co_gsource_func (gpointer self);
VALA_EXTERN void directory_monitor_mdbg (const gchar* msg);
static void library_monitor_report_checksum_job_completed (LibraryMonitor* self);
static void library_monitor_on_find_move_completed (LibraryMonitor* self,
                                             BackgroundJob* j);
VALA_EXTERN GType background_job_job_priority_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void media_monitor_update_master_file (MediaMonitor* self,
                                       Monitorable* monitorable,
                                       GFile* file);
static void library_monitor_on_find_move_cancelled (LibraryMonitor* self,
                                             BackgroundJob* j);
static void library_monitor_enqueue_verify_monitorable (LibraryMonitor* self,
                                                 Monitorable* monitorable,
                                                 MediaMonitor* monitor);
VALA_EXTERN GeeCollection* data_collection_get_all (DataCollection* self);
VALA_EXTERN gpointer source_holding_tank_ref (gpointer instance);
VALA_EXTERN void source_holding_tank_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_source_holding_tank (const gchar* name,
                                            const gchar* nick,
                                            const gchar* blurb,
                                            GType object_type,
                                            GParamFlags flags);
VALA_EXTERN void value_set_source_holding_tank (GValue* value,
                                    gpointer v_object);
VALA_EXTERN void value_take_source_holding_tank (GValue* value,
                                     gpointer v_object);
VALA_EXTERN gpointer value_get_source_holding_tank (const GValue* value);
VALA_EXTERN GType source_holding_tank_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SourceHoldingTank, source_holding_tank_unref)
VALA_EXTERN GType database_source_holding_tank_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DatabaseSourceHoldingTank, source_holding_tank_unref)
VALA_EXTERN GType media_source_holding_tank_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (MediaSourceHoldingTank, source_holding_tank_unref)
VALA_EXTERN MediaSourceHoldingTank* media_source_collection_get_offline_bin (MediaSourceCollection* self);
VALA_EXTERN GeeCollection* source_holding_tank_get_all (SourceHoldingTank* self);
static void library_monitor_enqueue_import_many (LibraryMonitor* self,
                                          GeeCollection* files);
VALA_EXTERN void tombstone_source_collection_launch_scan (TombstoneSourceCollection* self,
                                              DirectoryMonitor* monitor,
                                              GCancellable* cancellable);
static LibraryMonitorVerifyJob* library_monitor_verify_job_new (Monitorable* monitorable,
                                                         MediaMonitor* monitor);
static LibraryMonitorVerifyJob* library_monitor_verify_job_construct (GType object_type,
                                                               Monitorable* monitorable,
                                                               MediaMonitor* monitor);
static void library_monitor_execute_next_verify_job (LibraryMonitor* self);
static void library_monitor_verify_monitorable (LibraryMonitor* self,
                                         Monitorable* monitorable,
                                         MediaMonitor* monitor,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
static void library_monitor_verify_monitorable_finish (LibraryMonitor* self,
                                                GAsyncResult* _res_);
static void library_monitor_verify_monitorable_data_free (gpointer _data);
static gboolean library_monitor_verify_monitorable_co (LibraryMonitorVerifyMonitorableData* _data_);
VALA_EXTERN GFile* media_monitor_get_master_file (MediaMonitor* self,
                                      Monitorable* monitorable);
VALA_EXTERN GFile** media_monitor_get_auxilliary_backing_files (MediaMonitor* self,
                                                    Monitorable* monitorable,
                                                    gint* result_length1);
static void _vala_array_add126 (GFile** * array,
                         gint* length,
                         gint* size,
                         GFile* value);
static void library_monitor_verify_monitorable_ready (GObject* source_object,
                                               GAsyncResult* _res_,
                                               gpointer _user_data_);
VALA_EXTERN gboolean media_monitor_is_offline (MediaMonitor* self,
                                   Monitorable* monitorable);
VALA_EXTERN void media_monitor_update_online (MediaMonitor* self,
                                  Monitorable* monitorable);
VALA_EXTERN void media_monitor_update_offline (MediaMonitor* self,
                                   Monitorable* monitorable);
VALA_EXTERN void media_monitor_update_backing_file_info (MediaMonitor* self,
                                             Monitorable* monitorable,
                                             GFile* file,
                                             GFileInfo* info);
static gboolean _library_monitor_verify_monitorable_co_gsource_func (gpointer self);
static void library_monitor_import_unrepresented_files (LibraryMonitor* self);
static void library_monitor_cancel_batch_imports (LibraryMonitor* self);
static void library_monitor_enqueue_import (LibraryMonitor* self,
                                     GFile* file);
VALA_EXTERN gboolean library_monitor_is_blacklisted (GFile* file);
static void library_monitor_remove_queued_import (LibraryMonitor* self,
                                           GFile* file);
VALA_EXTERN BatchImportRoll* batch_import_roll_new (void);
VALA_EXTERN BatchImportRoll* batch_import_roll_construct (GType object_type);
VALA_EXTERN gpointer batch_import_job_ref (gpointer instance);
VALA_EXTERN void batch_import_job_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_batch_import_job (const gchar* name,
                                         const gchar* nick,
                                         const gchar* blurb,
                                         GType object_type,
                                         GParamFlags flags);
VALA_EXTERN void value_set_batch_import_job (GValue* value,
                                 gpointer v_object);
VALA_EXTERN void value_take_batch_import_job (GValue* value,
                                  gpointer v_object);
VALA_EXTERN gpointer value_get_batch_import_job (const GValue* value);
VALA_EXTERN GType batch_import_job_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BatchImportJob, batch_import_job_unref)
VALA_EXTERN FileImportJob* file_import_job_new (GFile* file_or_dir,
                                    gboolean copy_to_library,
                                    gboolean recurse);
VALA_EXTERN FileImportJob* file_import_job_construct (GType object_type,
                                          GFile* file_or_dir,
                                          gboolean copy_to_library,
                                          gboolean recurse);
VALA_EXTERN GType file_import_job_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (FileImportJob, batch_import_job_unref)
VALA_EXTERN gpointer import_manifest_ref (gpointer instance);
VALA_EXTERN void import_manifest_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_import_manifest (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
VALA_EXTERN void value_set_import_manifest (GValue* value,
                                gpointer v_object);
VALA_EXTERN void value_take_import_manifest (GValue* value,
                                 gpointer v_object);
VALA_EXTERN gpointer value_get_import_manifest (const GValue* value);
VALA_EXTERN GType import_manifest_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ImportManifest, import_manifest_unref)
VALA_EXTERN BatchImport* batch_import_new (GeeIterable* jobs,
                               const gchar* name,
                               BatchImportImportReporter reporter,
                               gpointer reporter_target,
                               GeeArrayList* prefailed,
                               GeeArrayList* pre_already_imported,
                               GCancellable* cancellable,
                               BatchImportRoll* import_roll,
                               ImportManifest* skip_manifest);
VALA_EXTERN BatchImport* batch_import_construct (GType object_type,
                                     GeeIterable* jobs,
                                     const gchar* name,
                                     BatchImportImportReporter reporter,
                                     gpointer reporter_target,
                                     GeeArrayList* prefailed,
                                     GeeArrayList* pre_already_imported,
                                     GCancellable* cancellable,
                                     BatchImportRoll* import_roll,
                                     ImportManifest* skip_manifest);
VALA_EXTERN void batch_import_set_untrash_duplicates (BatchImport* self,
                                          gboolean untrash_duplicates);
VALA_EXTERN void batch_import_set_mark_duplicates_online (BatchImport* self,
                                              gboolean mark_duplicates_online);
static void library_monitor_schedule_next_batch_import (LibraryMonitor* self);
static void library_monitor_on_import_preparing (LibraryMonitor* self);
static void _library_monitor_on_import_preparing_batch_import_preparing (BatchImport* _sender,
                                                                  gpointer self);
static void library_monitor_on_import_progress (LibraryMonitor* self,
                                         guint64 completed_bytes,
                                         guint64 total_bytes);
static void _library_monitor_on_import_progress_batch_import_progress (BatchImport* _sender,
                                                                guint64 completed_bytes,
                                                                guint64 total_bytes,
                                                                gpointer self);
static void library_monitor_on_import_complete (LibraryMonitor* self,
                                         BatchImport* batch_import,
                                         ImportManifest* manifest,
                                         BatchImportRoll* import_roll);
static void _library_monitor_on_import_complete_batch_import_import_complete (BatchImport* _sender,
                                                                       ImportManifest* manifest,
                                                                       BatchImportRoll* import_roll,
                                                                       gpointer self);
VALA_EXTERN void batch_import_schedule (BatchImport* self);
static void library_monitor_discard_current_batch_import (LibraryMonitor* self);
VALA_EXTERN void batch_import_user_halt (BatchImport* self);
VALA_EXTERN gpointer batch_import_result_ref (gpointer instance);
VALA_EXTERN void batch_import_result_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_batch_import_result (const gchar* name,
                                            const gchar* nick,
                                            const gchar* blurb,
                                            GType object_type,
                                            GParamFlags flags);
VALA_EXTERN void value_set_batch_import_result (GValue* value,
                                    gpointer v_object);
VALA_EXTERN void value_take_batch_import_result (GValue* value,
                                     gpointer v_object);
VALA_EXTERN gpointer value_get_batch_import_result (const GValue* value);
VALA_EXTERN GType batch_import_result_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (BatchImportResult, batch_import_result_unref)
VALA_EXTERN GType import_result_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GType duplicated_file_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (DuplicatedFile, g_object_unref)
VALA_EXTERN gpointer tombstoned_file_ref (gpointer instance);
VALA_EXTERN void tombstoned_file_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_tombstoned_file (const gchar* name,
                                        const gchar* nick,
                                        const gchar* blurb,
                                        GType object_type,
                                        GParamFlags flags);
VALA_EXTERN void value_set_tombstoned_file (GValue* value,
                                gpointer v_object);
VALA_EXTERN void value_take_tombstoned_file (GValue* value,
                                 gpointer v_object);
VALA_EXTERN gpointer value_get_tombstoned_file (const GValue* value);
VALA_EXTERN GType tombstoned_file_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TombstonedFile, tombstoned_file_unref)
VALA_EXTERN TombstonedFile* tombstoned_file_new (GFile* file,
                                     gint64 filesize,
                                     const gchar* md5);
VALA_EXTERN TombstonedFile* tombstoned_file_construct (GType object_type,
                                           GFile* file,
                                           gint64 filesize,
                                           const gchar* md5);
VALA_EXTERN GType tombstone_reason_get_type (void) G_GNUC_CONST ;
VALA_EXTERN GQuark database_error_quark (void);
VALA_EXTERN GType database_error_get_type (void) G_GNUC_CONST ;
VALA_EXTERN void tombstone_entomb_many_files (GeeCollection* files,
                                  TombstoneReason reason,
                                  GError** error);
VALA_EXTERN void app_window_database_error (GError* err);
VALA_EXTERN void library_monitor_blacklist_file (GFile* file,
                                     const gchar* reason);
VALA_EXTERN void library_monitor_unblacklist_file (GFile* file);
VALA_EXTERN gboolean hash_timed_queue_contains (HashTimedQueue* self,
                                    gconstpointer item);
VALA_EXTERN gboolean hash_timed_queue_enqueue (HashTimedQueue* self,
                                   gconstpointer item);
VALA_EXTERN MediaSourceCollection* media_collection_registry_get_collection_for_file (MediaCollectionRegistry* self,
                                                                          GFile* file);
VALA_EXTERN GeeCollection* directory_monitor_get_files (DirectoryMonitor* self);
VALA_EXTERN gboolean media_monitor_is_file_represented (MediaMonitor* self,
                                            GFile* file);
static void library_monitor_runtime_unknown_file_discovered (LibraryMonitor* self,
                                                      GFile* file);
static void library_monitor_real_notify_file_created (DirectoryMonitor* base,
                                               GFile* file,
                                               GFileInfo* info);
VALA_EXTERN gboolean media_monitor_notify_file_created (MediaMonitor* self,
                                            GFile* file,
                                            GFileInfo* info);
VALA_EXTERN gchar* media_monitor_to_string (MediaMonitor* self);
static LibraryMonitorRuntimeFindMoveJob* library_monitor_runtime_find_move_job_new (LibraryMonitor* owner,
                                                                             GFile* file,
                                                                             GeeCollection* candidates);
static LibraryMonitorRuntimeFindMoveJob* library_monitor_runtime_find_move_job_construct (GType object_type,
                                                                                   LibraryMonitor* owner,
                                                                                   GFile* file,
                                                                                   GeeCollection* candidates);
static GType library_monitor_runtime_find_move_job_get_type (void) G_GNUC_CONST  G_GNUC_UNUSED ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (LibraryMonitorRuntimeFindMoveJob, background_job_unref)
static void library_monitor_on_runtime_find_move_completed (LibraryMonitor* self,
                                                     BackgroundJob* j);
static void library_monitor_real_notify_file_moved (DirectoryMonitor* base,
                                             GFile* old_file,
                                             GFile* new_file,
                                             GFileInfo* new_info);
VALA_EXTERN gboolean media_monitor_notify_file_moved (MediaMonitor* self,
                                          GFile* old_file,
                                          GFile* new_file,
                                          GFileInfo* new_file_info);
static void library_monitor_real_notify_file_altered (DirectoryMonitor* base,
                                               GFile* file);
VALA_EXTERN gboolean media_monitor_notify_file_altered (MediaMonitor* self,
                                            GFile* file);
static void library_monitor_real_notify_file_attributes_altered (DirectoryMonitor* base,
                                                          GFile* file);
VALA_EXTERN gboolean media_monitor_notify_file_attributes_altered (MediaMonitor* self,
                                                       GFile* file);
static void library_monitor_real_notify_file_alteration_completed (DirectoryMonitor* base,
                                                            GFile* file,
                                                            GFileInfo* info);
VALA_EXTERN gboolean media_monitor_notify_file_alteration_completed (MediaMonitor* self,
                                                         GFile* file,
                                                         GFileInfo* info);
static void library_monitor_real_notify_file_deleted (DirectoryMonitor* base,
                                               GFile* file);
VALA_EXTERN gboolean media_monitor_notify_file_deleted (MediaMonitor* self,
                                            GFile* file);
VALA_EXTERN GType tombstone_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (Tombstone, g_object_unref)
VALA_EXTERN Tombstone* tombstone_source_collection_locate (TombstoneSourceCollection* self,
                                               GFile* file);
VALA_EXTERN void tombstone_source_collection_resurrect (TombstoneSourceCollection* self,
                                            Tombstone* tombstone);
static void g_cclosure_user_marshal_VOID__INT_INT (GClosure * closure,
                                            GValue * return_value,
                                            guint n_param_values,
                                            const GValue * param_values,
                                            gpointer invocation_hint,
                                            gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__UINT64_UINT64 (GClosure * closure,
                                                  GValue * return_value,
                                                  guint n_param_values,
                                                  const GValue * param_values,
                                                  gpointer invocation_hint,
                                                  gpointer marshal_data);
VALA_EXTERN void background_job_execute (BackgroundJob* self);
static void _library_monitor_on_find_move_completed_completion_callback (BackgroundJob* job,
                                                                  gpointer self);
static void _library_monitor_on_find_move_cancelled_cancellation_callback (BackgroundJob* job,
                                                                    gpointer self);
VALA_EXTERN gpointer abstract_semaphore_ref (gpointer instance);
VALA_EXTERN void abstract_semaphore_unref (gpointer instance);
VALA_EXTERN GParamSpec* param_spec_abstract_semaphore (const gchar* name,
                                           const gchar* nick,
                                           const gchar* blurb,
                                           GType object_type,
                                           GParamFlags flags);
VALA_EXTERN void value_set_abstract_semaphore (GValue* value,
                                   gpointer v_object);
VALA_EXTERN void value_take_abstract_semaphore (GValue* value,
                                    gpointer v_object);
VALA_EXTERN gpointer value_get_abstract_semaphore (const GValue* value);
VALA_EXTERN GType abstract_semaphore_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (AbstractSemaphore, abstract_semaphore_unref)
VALA_EXTERN BackgroundJob* background_job_construct (GType object_type,
                                         GObject* owner,
                                         CompletionCallback callback,
                                         gpointer callback_target,
                                         GCancellable* cancellable,
                                         CancellationCallback cancellation,
                                         gpointer cancellation_target,
                                         AbstractSemaphore* completion_semaphore);
VALA_EXTERN void background_job_set_completion_priority (BackgroundJob* self,
                                             gint priority);
static void library_monitor_find_move_job_real_execute (BackgroundJob* base);
VALA_EXTERN GFile* media_source_get_master_file (MediaSource* self);
VALA_EXTERN gchar* md5_file (GFile* file,
                 GError** error);
VALA_EXTERN gchar* media_source_get_master_md5 (MediaSource* self);
static void library_monitor_find_move_job_finalize (BackgroundJob * obj);
static GType library_monitor_find_move_job_get_type_once (void);
static void _library_monitor_on_runtime_find_move_completed_completion_callback (BackgroundJob* job,
                                                                          gpointer self);
static void library_monitor_runtime_find_move_job_real_execute (BackgroundJob* base);
static void library_monitor_runtime_find_move_job_finalize (BackgroundJob * obj);
static GType library_monitor_runtime_find_move_job_get_type_once (void);
static void library_monitor_verify_job_finalize (LibraryMonitorVerifyJob * obj);
static GType library_monitor_verify_job_get_type_once (void);
static void library_monitor_finalize (GObject * obj);
static GType library_monitor_get_type_once (void);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);
static inline gpointer _vala_memdup2 (gconstpointer mem,
                        gsize byte_size);

static inline gpointer
library_monitor_pool_get_instance_private (LibraryMonitorPool* self)
{
	return G_STRUCT_MEMBER_P (self, LibraryMonitorPool_private_offset);
}

static LibraryMonitorPool*
library_monitor_pool_construct (GType object_type)
{
	LibraryMonitorPool* self = NULL;
#line 38 "../src/LibraryMonitor.vala"
	self = (LibraryMonitorPool*) g_type_create_instance (object_type);
#line 38 "../src/LibraryMonitor.vala"
	return self;
#line 1545 "LibraryMonitor.c"
}

static LibraryMonitorPool*
library_monitor_pool_new (void)
{
#line 38 "../src/LibraryMonitor.vala"
	return library_monitor_pool_construct (TYPE_LIBRARY_MONITOR_POOL);
#line 1553 "LibraryMonitor.c"
}

void
library_monitor_pool_init (void)
{
}

void
library_monitor_pool_terminate (void)
{
	LibraryMonitorPool* _tmp0_;
#line 45 "../src/LibraryMonitor.vala"
	_tmp0_ = library_monitor_pool_instance;
#line 45 "../src/LibraryMonitor.vala"
	if (_tmp0_ != NULL) {
#line 1569 "LibraryMonitor.c"
		LibraryMonitorPool* _tmp1_;
#line 46 "../src/LibraryMonitor.vala"
		_tmp1_ = library_monitor_pool_instance;
#line 46 "../src/LibraryMonitor.vala"
		library_monitor_pool_close (_tmp1_);
#line 1575 "LibraryMonitor.c"
	}
#line 48 "../src/LibraryMonitor.vala"
	_library_monitor_pool_unref0 (library_monitor_pool_instance);
#line 48 "../src/LibraryMonitor.vala"
	library_monitor_pool_instance = NULL;
#line 1581 "LibraryMonitor.c"
}

static gpointer
_library_monitor_pool_ref0 (gpointer self)
{
#line 55 "../src/LibraryMonitor.vala"
	return self ? library_monitor_pool_ref (self) : NULL;
#line 1589 "LibraryMonitor.c"
}

LibraryMonitorPool*
library_monitor_pool_get_instance (void)
{
	LibraryMonitorPool* _tmp0_;
	LibraryMonitorPool* _tmp2_;
	LibraryMonitorPool* _tmp3_;
	LibraryMonitorPool* result;
#line 52 "../src/LibraryMonitor.vala"
	_tmp0_ = library_monitor_pool_instance;
#line 52 "../src/LibraryMonitor.vala"
	if (_tmp0_ == NULL) {
#line 1603 "LibraryMonitor.c"
		LibraryMonitorPool* _tmp1_;
#line 53 "../src/LibraryMonitor.vala"
		_tmp1_ = library_monitor_pool_new ();
#line 53 "../src/LibraryMonitor.vala"
		_library_monitor_pool_unref0 (library_monitor_pool_instance);
#line 53 "../src/LibraryMonitor.vala"
		library_monitor_pool_instance = _tmp1_;
#line 1611 "LibraryMonitor.c"
	}
#line 55 "../src/LibraryMonitor.vala"
	_tmp2_ = library_monitor_pool_instance;
#line 55 "../src/LibraryMonitor.vala"
	_tmp3_ = _library_monitor_pool_ref0 (_tmp2_);
#line 55 "../src/LibraryMonitor.vala"
	result = _tmp3_;
#line 55 "../src/LibraryMonitor.vala"
	return result;
#line 1621 "LibraryMonitor.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 59 "../src/LibraryMonitor.vala"
	return self ? g_object_ref (self) : NULL;
#line 1629 "LibraryMonitor.c"
}

LibraryMonitor*
library_monitor_pool_get_monitor (LibraryMonitorPool* self)
{
	LibraryMonitor* _tmp0_;
	LibraryMonitor* _tmp1_;
	LibraryMonitor* result;
#line 58 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (IS_LIBRARY_MONITOR_POOL (self), NULL);
#line 59 "../src/LibraryMonitor.vala"
	_tmp0_ = self->priv->monitor;
#line 59 "../src/LibraryMonitor.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 59 "../src/LibraryMonitor.vala"
	result = _tmp1_;
#line 59 "../src/LibraryMonitor.vala"
	return result;
#line 1648 "LibraryMonitor.c"
}

static gboolean
_library_monitor_pool_on_start_monitor_gsource_func (gpointer self)
{
	gboolean result;
	result = library_monitor_pool_on_start_monitor ((LibraryMonitorPool*) self);
#line 68 "../src/LibraryMonitor.vala"
	return result;
#line 1658 "LibraryMonitor.c"
}

void
library_monitor_pool_replace (LibraryMonitorPool* self,
                              LibraryMonitor* replacement,
                              gint start_msec_delay)
{
	LibraryMonitor* _tmp0_;
	gboolean _tmp1_ = FALSE;
	LibraryMonitor* _tmp2_;
#line 63 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR_POOL (self));
#line 63 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (replacement));
#line 64 "../src/LibraryMonitor.vala"
	library_monitor_pool_close (self);
#line 66 "../src/LibraryMonitor.vala"
	_tmp0_ = _g_object_ref0 (replacement);
#line 66 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->monitor);
#line 66 "../src/LibraryMonitor.vala"
	self->priv->monitor = _tmp0_;
#line 67 "../src/LibraryMonitor.vala"
	if (start_msec_delay > 0) {
#line 67 "../src/LibraryMonitor.vala"
		_tmp1_ = self->priv->timer_id == ((guint) 0);
#line 1685 "LibraryMonitor.c"
	} else {
#line 67 "../src/LibraryMonitor.vala"
		_tmp1_ = FALSE;
#line 1689 "LibraryMonitor.c"
	}
#line 67 "../src/LibraryMonitor.vala"
	if (_tmp1_) {
#line 68 "../src/LibraryMonitor.vala"
		self->priv->timer_id = g_timeout_add_full (G_PRIORITY_DEFAULT, (guint) start_msec_delay, _library_monitor_pool_on_start_monitor_gsource_func, library_monitor_pool_ref (self), library_monitor_pool_unref);
#line 1695 "LibraryMonitor.c"
	}
#line 70 "../src/LibraryMonitor.vala"
	_tmp2_ = self->priv->monitor;
#line 70 "../src/LibraryMonitor.vala"
	g_signal_emit (self, library_monitor_pool_signals[LIBRARY_MONITOR_POOL_MONITOR_INSTALLED_SIGNAL], 0, _tmp2_);
#line 1701 "LibraryMonitor.c"
}

static void
library_monitor_pool_close (LibraryMonitorPool* self)
{
	LibraryMonitor* _tmp0_;
	LibraryMonitor* _tmp1_;
	LibraryMonitor* closed = NULL;
	LibraryMonitor* _tmp2_;
	LibraryMonitor* _tmp3_;
	LibraryMonitor* _tmp4_;
#line 73 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR_POOL (self));
#line 74 "../src/LibraryMonitor.vala"
	_tmp0_ = self->priv->monitor;
#line 74 "../src/LibraryMonitor.vala"
	if (_tmp0_ == NULL) {
#line 75 "../src/LibraryMonitor.vala"
		return;
#line 1721 "LibraryMonitor.c"
	}
#line 77 "../src/LibraryMonitor.vala"
	_tmp1_ = self->priv->monitor;
#line 77 "../src/LibraryMonitor.vala"
	directory_monitor_close (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DIRECTORY_MONITOR, DirectoryMonitor));
#line 78 "../src/LibraryMonitor.vala"
	_tmp2_ = self->priv->monitor;
#line 78 "../src/LibraryMonitor.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 78 "../src/LibraryMonitor.vala"
	closed = _tmp3_;
#line 79 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->monitor);
#line 79 "../src/LibraryMonitor.vala"
	self->priv->monitor = NULL;
#line 81 "../src/LibraryMonitor.vala"
	_tmp4_ = closed;
#line 81 "../src/LibraryMonitor.vala"
	g_signal_emit (self, library_monitor_pool_signals[LIBRARY_MONITOR_POOL_MONITOR_DESTROYED_SIGNAL], 0, _tmp4_);
#line 73 "../src/LibraryMonitor.vala"
	_g_object_unref0 (closed);
#line 1743 "LibraryMonitor.c"
}

static gboolean
library_monitor_pool_on_start_monitor (LibraryMonitorPool* self)
{
	LibraryMonitor* _tmp0_;
	LibraryMonitor* _tmp1_;
	gboolean result;
#line 84 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (IS_LIBRARY_MONITOR_POOL (self), FALSE);
#line 86 "../src/LibraryMonitor.vala"
	self->priv->timer_id = (guint) 0;
#line 88 "../src/LibraryMonitor.vala"
	_tmp0_ = self->priv->monitor;
#line 88 "../src/LibraryMonitor.vala"
	if (_tmp0_ == NULL) {
#line 89 "../src/LibraryMonitor.vala"
		result = FALSE;
#line 89 "../src/LibraryMonitor.vala"
		return result;
#line 1764 "LibraryMonitor.c"
	}
#line 91 "../src/LibraryMonitor.vala"
	_tmp1_ = self->priv->monitor;
#line 91 "../src/LibraryMonitor.vala"
	directory_monitor_start_discovery (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_DIRECTORY_MONITOR, DirectoryMonitor));
#line 93 "../src/LibraryMonitor.vala"
	result = FALSE;
#line 93 "../src/LibraryMonitor.vala"
	return result;
#line 1774 "LibraryMonitor.c"
}

static void
value_library_monitor_pool_init (GValue* value)
{
#line 28 "../src/LibraryMonitor.vala"
	value->data[0].v_pointer = NULL;
#line 1782 "LibraryMonitor.c"
}

static void
value_library_monitor_pool_free_value (GValue* value)
{
#line 28 "../src/LibraryMonitor.vala"
	if (value->data[0].v_pointer) {
#line 28 "../src/LibraryMonitor.vala"
		library_monitor_pool_unref (value->data[0].v_pointer);
#line 1792 "LibraryMonitor.c"
	}
}

static void
value_library_monitor_pool_copy_value (const GValue* src_value,
                                       GValue* dest_value)
{
#line 28 "../src/LibraryMonitor.vala"
	if (src_value->data[0].v_pointer) {
#line 28 "../src/LibraryMonitor.vala"
		dest_value->data[0].v_pointer = library_monitor_pool_ref (src_value->data[0].v_pointer);
#line 1804 "LibraryMonitor.c"
	} else {
#line 28 "../src/LibraryMonitor.vala"
		dest_value->data[0].v_pointer = NULL;
#line 1808 "LibraryMonitor.c"
	}
}

static gpointer
value_library_monitor_pool_peek_pointer (const GValue* value)
{
#line 28 "../src/LibraryMonitor.vala"
	return value->data[0].v_pointer;
#line 1817 "LibraryMonitor.c"
}

static gchar*
value_library_monitor_pool_collect_value (GValue* value,
                                          guint n_collect_values,
                                          GTypeCValue* collect_values,
                                          guint collect_flags)
{
#line 28 "../src/LibraryMonitor.vala"
	if (collect_values[0].v_pointer) {
#line 1828 "LibraryMonitor.c"
		LibraryMonitorPool * object;
		object = collect_values[0].v_pointer;
#line 28 "../src/LibraryMonitor.vala"
		if (object->parent_instance.g_class == NULL) {
#line 28 "../src/LibraryMonitor.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1835 "LibraryMonitor.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 28 "../src/LibraryMonitor.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 1839 "LibraryMonitor.c"
		}
#line 28 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = library_monitor_pool_ref (object);
#line 1843 "LibraryMonitor.c"
	} else {
#line 28 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = NULL;
#line 1847 "LibraryMonitor.c"
	}
#line 28 "../src/LibraryMonitor.vala"
	return NULL;
#line 1851 "LibraryMonitor.c"
}

static gchar*
value_library_monitor_pool_lcopy_value (const GValue* value,
                                        guint n_collect_values,
                                        GTypeCValue* collect_values,
                                        guint collect_flags)
{
	LibraryMonitorPool ** object_p;
	object_p = collect_values[0].v_pointer;
#line 28 "../src/LibraryMonitor.vala"
	if (!object_p) {
#line 28 "../src/LibraryMonitor.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 1866 "LibraryMonitor.c"
	}
#line 28 "../src/LibraryMonitor.vala"
	if (!value->data[0].v_pointer) {
#line 28 "../src/LibraryMonitor.vala"
		*object_p = NULL;
#line 1872 "LibraryMonitor.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 28 "../src/LibraryMonitor.vala"
		*object_p = value->data[0].v_pointer;
#line 1876 "LibraryMonitor.c"
	} else {
#line 28 "../src/LibraryMonitor.vala"
		*object_p = library_monitor_pool_ref (value->data[0].v_pointer);
#line 1880 "LibraryMonitor.c"
	}
#line 28 "../src/LibraryMonitor.vala"
	return NULL;
#line 1884 "LibraryMonitor.c"
}

GParamSpec*
param_spec_library_monitor_pool (const gchar* name,
                                 const gchar* nick,
                                 const gchar* blurb,
                                 GType object_type,
                                 GParamFlags flags)
{
	ParamSpecLibraryMonitorPool* spec;
#line 28 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (g_type_is_a (object_type, TYPE_LIBRARY_MONITOR_POOL), NULL);
#line 28 "../src/LibraryMonitor.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 28 "../src/LibraryMonitor.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 28 "../src/LibraryMonitor.vala"
	return G_PARAM_SPEC (spec);
#line 1903 "LibraryMonitor.c"
}

gpointer
value_get_library_monitor_pool (const GValue* value)
{
#line 28 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_LIBRARY_MONITOR_POOL), NULL);
#line 28 "../src/LibraryMonitor.vala"
	return value->data[0].v_pointer;
#line 1913 "LibraryMonitor.c"
}

void
value_set_library_monitor_pool (GValue* value,
                                gpointer v_object)
{
	LibraryMonitorPool * old;
#line 28 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_LIBRARY_MONITOR_POOL));
#line 28 "../src/LibraryMonitor.vala"
	old = value->data[0].v_pointer;
#line 28 "../src/LibraryMonitor.vala"
	if (v_object) {
#line 28 "../src/LibraryMonitor.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_LIBRARY_MONITOR_POOL));
#line 28 "../src/LibraryMonitor.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 28 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = v_object;
#line 28 "../src/LibraryMonitor.vala"
		library_monitor_pool_ref (value->data[0].v_pointer);
#line 1935 "LibraryMonitor.c"
	} else {
#line 28 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = NULL;
#line 1939 "LibraryMonitor.c"
	}
#line 28 "../src/LibraryMonitor.vala"
	if (old) {
#line 28 "../src/LibraryMonitor.vala"
		library_monitor_pool_unref (old);
#line 1945 "LibraryMonitor.c"
	}
}

void
value_take_library_monitor_pool (GValue* value,
                                 gpointer v_object)
{
	LibraryMonitorPool * old;
#line 28 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TYPE_LIBRARY_MONITOR_POOL));
#line 28 "../src/LibraryMonitor.vala"
	old = value->data[0].v_pointer;
#line 28 "../src/LibraryMonitor.vala"
	if (v_object) {
#line 28 "../src/LibraryMonitor.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TYPE_LIBRARY_MONITOR_POOL));
#line 28 "../src/LibraryMonitor.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 28 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = v_object;
#line 1966 "LibraryMonitor.c"
	} else {
#line 28 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = NULL;
#line 1970 "LibraryMonitor.c"
	}
#line 28 "../src/LibraryMonitor.vala"
	if (old) {
#line 28 "../src/LibraryMonitor.vala"
		library_monitor_pool_unref (old);
#line 1976 "LibraryMonitor.c"
	}
}

static void
library_monitor_pool_class_init (LibraryMonitorPoolClass * klass,
                                 gpointer klass_data)
{
#line 28 "../src/LibraryMonitor.vala"
	library_monitor_pool_parent_class = g_type_class_peek_parent (klass);
#line 28 "../src/LibraryMonitor.vala"
	((LibraryMonitorPoolClass *) klass)->finalize = library_monitor_pool_finalize;
#line 28 "../src/LibraryMonitor.vala"
	g_type_class_adjust_private_offset (klass, &LibraryMonitorPool_private_offset);
#line 28 "../src/LibraryMonitor.vala"
	library_monitor_pool_signals[LIBRARY_MONITOR_POOL_MONITOR_INSTALLED_SIGNAL] = g_signal_new ("monitor-installed", TYPE_LIBRARY_MONITOR_POOL, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TYPE_LIBRARY_MONITOR);
#line 28 "../src/LibraryMonitor.vala"
	library_monitor_pool_signals[LIBRARY_MONITOR_POOL_MONITOR_DESTROYED_SIGNAL] = g_signal_new ("monitor-destroyed", TYPE_LIBRARY_MONITOR_POOL, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__OBJECT, G_TYPE_NONE, 1, TYPE_LIBRARY_MONITOR);
#line 1994 "LibraryMonitor.c"
}

static void
library_monitor_pool_instance_init (LibraryMonitorPool * self,
                                    gpointer klass)
{
#line 28 "../src/LibraryMonitor.vala"
	self->priv = library_monitor_pool_get_instance_private (self);
#line 31 "../src/LibraryMonitor.vala"
	self->priv->monitor = NULL;
#line 32 "../src/LibraryMonitor.vala"
	self->priv->timer_id = (guint) 0;
#line 28 "../src/LibraryMonitor.vala"
	self->ref_count = 1;
#line 2009 "LibraryMonitor.c"
}

static void
library_monitor_pool_finalize (LibraryMonitorPool * obj)
{
	LibraryMonitorPool * self;
#line 28 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LIBRARY_MONITOR_POOL, LibraryMonitorPool);
#line 28 "../src/LibraryMonitor.vala"
	g_signal_handlers_destroy (self);
#line 31 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->monitor);
#line 2022 "LibraryMonitor.c"
}

static GType
library_monitor_pool_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { value_library_monitor_pool_init, value_library_monitor_pool_free_value, value_library_monitor_pool_copy_value, value_library_monitor_pool_peek_pointer, "p", value_library_monitor_pool_collect_value, "p", value_library_monitor_pool_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (LibraryMonitorPoolClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_monitor_pool_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryMonitorPool), 0, (GInstanceInitFunc) library_monitor_pool_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType library_monitor_pool_type_id;
	library_monitor_pool_type_id = g_type_register_fundamental (g_type_fundamental_next (), "LibraryMonitorPool", &g_define_type_info, &g_define_type_fundamental_info, 0);
	LibraryMonitorPool_private_offset = g_type_add_instance_private (library_monitor_pool_type_id, sizeof (LibraryMonitorPoolPrivate));
	return library_monitor_pool_type_id;
}

GType
library_monitor_pool_get_type (void)
{
	static volatile gsize library_monitor_pool_type_id__once = 0;
	if (g_once_init_enter (&library_monitor_pool_type_id__once)) {
		GType library_monitor_pool_type_id;
		library_monitor_pool_type_id = library_monitor_pool_get_type_once ();
		g_once_init_leave (&library_monitor_pool_type_id__once, library_monitor_pool_type_id);
	}
	return library_monitor_pool_type_id__once;
}

gpointer
library_monitor_pool_ref (gpointer instance)
{
	LibraryMonitorPool * self;
	self = instance;
#line 28 "../src/LibraryMonitor.vala"
	g_atomic_int_inc (&self->ref_count);
#line 28 "../src/LibraryMonitor.vala"
	return instance;
#line 2058 "LibraryMonitor.c"
}

void
library_monitor_pool_unref (gpointer instance)
{
	LibraryMonitorPool * self;
	self = instance;
#line 28 "../src/LibraryMonitor.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 28 "../src/LibraryMonitor.vala"
		LIBRARY_MONITOR_POOL_GET_CLASS (self)->finalize (self);
#line 28 "../src/LibraryMonitor.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 2072 "LibraryMonitor.c"
	}
}

static inline gpointer
library_monitor_get_instance_private (LibraryMonitor* self)
{
	return G_STRUCT_MEMBER_P (self, LibraryMonitor_private_offset);
}

static void
_library_monitor_on_config_changed_configuration_facade_auto_import_from_library_changed (ConfigurationFacade* _sender,
                                                                                          gpointer self)
{
#line 247 "../src/LibraryMonitor.vala"
	library_monitor_on_config_changed ((LibraryMonitor*) self);
#line 2088 "LibraryMonitor.c"
}

static guint
_file_hash_gee_hash_data_func (gconstpointer v,
                               gpointer self)
{
	guint result;
	result = file_hash ((GFile*) v);
#line 206 "../src/LibraryMonitor.vala"
	return result;
#line 2099 "LibraryMonitor.c"
}

static gboolean
_file_equal_gee_equal_data_func (gconstpointer a,
                                 gconstpointer b,
                                 gpointer self)
{
	gboolean result;
	result = file_equal ((GFile*) a, (GFile*) b);
#line 206 "../src/LibraryMonitor.vala"
	return result;
#line 2111 "LibraryMonitor.c"
}

static void
_library_monitor_on_unblacklist_file_dequeued_callback (gconstpointer item,
                                                        gpointer self)
{
#line 207 "../src/LibraryMonitor.vala"
	library_monitor_on_unblacklist_file ((GFile*) item);
#line 2120 "LibraryMonitor.c"
}

static gboolean
_library_monitor_on_flush_import_queue_gsource_func (gpointer self)
{
	gboolean result;
	result = library_monitor_on_flush_import_queue ((LibraryMonitor*) self);
#line 243 "../src/LibraryMonitor.vala"
	return result;
#line 2130 "LibraryMonitor.c"
}

LibraryMonitor*
library_monitor_construct (GType object_type,
                           GFile* root,
                           gboolean recurse,
                           gboolean monitoring)
{
	LibraryMonitor * self = NULL;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	ConfigFacade* _tmp2_;
	ConfigFacade* _tmp3_;
#line 236 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (root, g_file_get_type ()), NULL);
#line 237 "../src/LibraryMonitor.vala"
	self = (LibraryMonitor*) directory_monitor_construct (object_type, root, recurse, monitoring);
#line 240 "../src/LibraryMonitor.vala"
	_tmp0_ = config_facade_get_instance ();
#line 240 "../src/LibraryMonitor.vala"
	_tmp1_ = _tmp0_;
#line 240 "../src/LibraryMonitor.vala"
	self->priv->auto_import = configuration_facade_get_auto_import_from_library (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 240 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_tmp1_);
#line 241 "../src/LibraryMonitor.vala"
	_tmp2_ = config_facade_get_instance ();
#line 241 "../src/LibraryMonitor.vala"
	_tmp3_ = _tmp2_;
#line 241 "../src/LibraryMonitor.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), "auto-import-from-library-changed", (GCallback) _library_monitor_on_config_changed_configuration_facade_auto_import_from_library_changed, self, 0);
#line 241 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_tmp3_);
#line 243 "../src/LibraryMonitor.vala"
	self->priv->import_queue_timer_id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) LIBRARY_MONITOR_FLUSH_IMPORT_QUEUE_SEC, _library_monitor_on_flush_import_queue_gsource_func, g_object_ref (self), g_object_unref);
#line 236 "../src/LibraryMonitor.vala"
	return self;
#line 2168 "LibraryMonitor.c"
}

LibraryMonitor*
library_monitor_new (GFile* root,
                     gboolean recurse,
                     gboolean monitoring)
{
#line 236 "../src/LibraryMonitor.vala"
	return library_monitor_construct (TYPE_LIBRARY_MONITOR, root, recurse, monitoring);
#line 2178 "LibraryMonitor.c"
}

static void
library_monitor_real_close (DirectoryMonitor* base)
{
	LibraryMonitor * self;
	GCancellable* _tmp0_;
#line 250 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_MONITOR, LibraryMonitor);
#line 251 "../src/LibraryMonitor.vala"
	_tmp0_ = self->priv->cancellable;
#line 251 "../src/LibraryMonitor.vala"
	g_cancellable_cancel (_tmp0_);
#line 2192 "LibraryMonitor.c"
	{
		GeeList* _monitor_list = NULL;
		GeeList* _tmp1_;
		gint _monitor_size = 0;
		GeeList* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
		gint _monitor_index = 0;
#line 253 "../src/LibraryMonitor.vala"
		_tmp1_ = self->priv->monitors;
#line 253 "../src/LibraryMonitor.vala"
		_monitor_list = _tmp1_;
#line 253 "../src/LibraryMonitor.vala"
		_tmp2_ = _monitor_list;
#line 253 "../src/LibraryMonitor.vala"
		_tmp3_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection));
#line 253 "../src/LibraryMonitor.vala"
		_tmp4_ = _tmp3_;
#line 253 "../src/LibraryMonitor.vala"
		_monitor_size = _tmp4_;
#line 253 "../src/LibraryMonitor.vala"
		_monitor_index = -1;
#line 253 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 2217 "LibraryMonitor.c"
			gint _tmp5_;
			gint _tmp6_;
			MediaMonitor* monitor = NULL;
			GeeList* _tmp7_;
			gpointer _tmp8_;
			MediaMonitor* _tmp9_;
#line 253 "../src/LibraryMonitor.vala"
			_monitor_index = _monitor_index + 1;
#line 253 "../src/LibraryMonitor.vala"
			_tmp5_ = _monitor_index;
#line 253 "../src/LibraryMonitor.vala"
			_tmp6_ = _monitor_size;
#line 253 "../src/LibraryMonitor.vala"
			if (!(_tmp5_ < _tmp6_)) {
#line 253 "../src/LibraryMonitor.vala"
				break;
#line 2234 "LibraryMonitor.c"
			}
#line 253 "../src/LibraryMonitor.vala"
			_tmp7_ = _monitor_list;
#line 253 "../src/LibraryMonitor.vala"
			_tmp8_ = gee_list_get (_tmp7_, _monitor_index);
#line 253 "../src/LibraryMonitor.vala"
			monitor = (MediaMonitor*) _tmp8_;
#line 254 "../src/LibraryMonitor.vala"
			_tmp9_ = monitor;
#line 254 "../src/LibraryMonitor.vala"
			media_monitor_close (_tmp9_);
#line 253 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitor);
#line 2248 "LibraryMonitor.c"
		}
	}
#line 256 "../src/LibraryMonitor.vala"
	if (self->priv->import_queue_timer_id != ((guint) 0)) {
#line 257 "../src/LibraryMonitor.vala"
		g_source_remove (self->priv->import_queue_timer_id);
#line 258 "../src/LibraryMonitor.vala"
		self->priv->import_queue_timer_id = (guint) 0;
#line 2257 "LibraryMonitor.c"
	}
#line 261 "../src/LibraryMonitor.vala"
	DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->close (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor));
#line 2261 "LibraryMonitor.c"
}

static void
library_monitor_add_to_discovered_list (LibraryMonitor* self,
                                        MediaMonitor* monitor,
                                        Monitorable* monitorable)
{
	GeeHashMap* _tmp0_;
	GeeHashMap* _tmp4_;
	gpointer _tmp5_;
	GeeSet* _tmp6_;
#line 264 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 264 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_MEDIA_MONITOR (monitor));
#line 264 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_MONITORABLE (monitorable));
#line 265 "../src/LibraryMonitor.vala"
	_tmp0_ = self->priv->discovered;
#line 265 "../src/LibraryMonitor.vala"
	if (!gee_abstract_map_has_key (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), monitor)) {
#line 2283 "LibraryMonitor.c"
		GeeHashMap* _tmp1_;
		GeeHashSet* _tmp2_;
		GeeHashSet* _tmp3_;
#line 266 "../src/LibraryMonitor.vala"
		_tmp1_ = self->priv->discovered;
#line 266 "../src/LibraryMonitor.vala"
		_tmp2_ = gee_hash_set_new (TYPE_MONITORABLE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 266 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 266 "../src/LibraryMonitor.vala"
		gee_abstract_map_set (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), monitor, G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_SET, GeeSet));
#line 266 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_tmp3_);
#line 2297 "LibraryMonitor.c"
	}
#line 268 "../src/LibraryMonitor.vala"
	_tmp4_ = self->priv->discovered;
#line 268 "../src/LibraryMonitor.vala"
	_tmp5_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), monitor);
#line 268 "../src/LibraryMonitor.vala"
	_tmp6_ = (GeeSet*) _tmp5_;
#line 268 "../src/LibraryMonitor.vala"
	gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_COLLECTION, GeeCollection), monitorable);
#line 268 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_tmp6_);
#line 2309 "LibraryMonitor.c"
}

static MediaMonitor*
library_monitor_get_monitor_for_monitorable (LibraryMonitor* self,
                                             Monitorable* monitorable)
{
	gchar* _tmp12_;
	gchar* _tmp13_;
	MediaMonitor* result;
#line 271 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (IS_LIBRARY_MONITOR (self), NULL);
#line 271 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (IS_MONITORABLE (monitorable), NULL);
#line 2323 "LibraryMonitor.c"
	{
		GeeList* _monitor_list = NULL;
		GeeList* _tmp0_;
		gint _monitor_size = 0;
		GeeList* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		gint _monitor_index = 0;
#line 272 "../src/LibraryMonitor.vala"
		_tmp0_ = self->priv->monitors;
#line 272 "../src/LibraryMonitor.vala"
		_monitor_list = _tmp0_;
#line 272 "../src/LibraryMonitor.vala"
		_tmp1_ = _monitor_list;
#line 272 "../src/LibraryMonitor.vala"
		_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 272 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 272 "../src/LibraryMonitor.vala"
		_monitor_size = _tmp3_;
#line 272 "../src/LibraryMonitor.vala"
		_monitor_index = -1;
#line 272 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 2348 "LibraryMonitor.c"
			gint _tmp4_;
			gint _tmp5_;
			MediaMonitor* monitor = NULL;
			GeeList* _tmp6_;
			gpointer _tmp7_;
			MediaMonitor* _tmp8_;
			MediaSourceCollection* _tmp9_;
			MediaSourceCollection* _tmp10_;
			gboolean _tmp11_;
#line 272 "../src/LibraryMonitor.vala"
			_monitor_index = _monitor_index + 1;
#line 272 "../src/LibraryMonitor.vala"
			_tmp4_ = _monitor_index;
#line 272 "../src/LibraryMonitor.vala"
			_tmp5_ = _monitor_size;
#line 272 "../src/LibraryMonitor.vala"
			if (!(_tmp4_ < _tmp5_)) {
#line 272 "../src/LibraryMonitor.vala"
				break;
#line 2368 "LibraryMonitor.c"
			}
#line 272 "../src/LibraryMonitor.vala"
			_tmp6_ = _monitor_list;
#line 272 "../src/LibraryMonitor.vala"
			_tmp7_ = gee_list_get (_tmp6_, _monitor_index);
#line 272 "../src/LibraryMonitor.vala"
			monitor = (MediaMonitor*) _tmp7_;
#line 273 "../src/LibraryMonitor.vala"
			_tmp8_ = monitor;
#line 273 "../src/LibraryMonitor.vala"
			_tmp9_ = media_monitor_get_media_source_collection (_tmp8_);
#line 273 "../src/LibraryMonitor.vala"
			_tmp10_ = _tmp9_;
#line 273 "../src/LibraryMonitor.vala"
			_tmp11_ = source_collection_holds_type_of_source (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, TYPE_SOURCE_COLLECTION, SourceCollection), G_TYPE_CHECK_INSTANCE_CAST (monitorable, TYPE_DATA_SOURCE, DataSource));
#line 273 "../src/LibraryMonitor.vala"
			_data_collection_unref0 (_tmp10_);
#line 273 "../src/LibraryMonitor.vala"
			if (_tmp11_) {
#line 274 "../src/LibraryMonitor.vala"
				result = monitor;
#line 274 "../src/LibraryMonitor.vala"
				return result;
#line 2392 "LibraryMonitor.c"
			}
#line 272 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitor);
#line 2396 "LibraryMonitor.c"
		}
	}
#line 277 "../src/LibraryMonitor.vala"
	_tmp12_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (monitorable, TYPE_DATA_OBJECT, DataObject));
#line 277 "../src/LibraryMonitor.vala"
	_tmp13_ = _tmp12_;
#line 277 "../src/LibraryMonitor.vala"
	g_error ("LibraryMonitor.vala:277: Unable to locate MediaMonitor for %s", _tmp13_);
#line 277 "../src/LibraryMonitor.vala"
	_g_free0 (_tmp13_);
#line 2407 "LibraryMonitor.c"
}

static void
library_monitor_real_discovery_started (DirectoryMonitor* base)
{
	LibraryMonitor * self;
	GeeHashMap* _tmp24_;
	GeeHashSet* _tmp25_;
#line 280 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_MONITOR, LibraryMonitor);
#line 2418 "LibraryMonitor.c"
	{
		GeeIterator* _collection_it = NULL;
		MediaCollectionRegistry* _tmp0_;
		MediaCollectionRegistry* _tmp1_;
		GeeCollection* _tmp2_;
		GeeCollection* _tmp3_;
		GeeIterator* _tmp4_;
		GeeIterator* _tmp5_;
#line 281 "../src/LibraryMonitor.vala"
		_tmp0_ = media_collection_registry_get_instance ();
#line 281 "../src/LibraryMonitor.vala"
		_tmp1_ = _tmp0_;
#line 281 "../src/LibraryMonitor.vala"
		_tmp2_ = media_collection_registry_get_all (_tmp1_);
#line 281 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 281 "../src/LibraryMonitor.vala"
		_tmp4_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ITERABLE, GeeIterable));
#line 281 "../src/LibraryMonitor.vala"
		_tmp5_ = _tmp4_;
#line 281 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_tmp3_);
#line 281 "../src/LibraryMonitor.vala"
		_media_collection_registry_unref0 (_tmp1_);
#line 281 "../src/LibraryMonitor.vala"
		_collection_it = _tmp5_;
#line 281 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 2447 "LibraryMonitor.c"
			GeeIterator* _tmp6_;
			MediaSourceCollection* collection = NULL;
			GeeIterator* _tmp7_;
			gpointer _tmp8_;
			GeeList* _tmp9_;
			MediaSourceCollection* _tmp10_;
			Workers* _tmp11_;
			GCancellable* _tmp12_;
			MediaMonitor* _tmp13_;
			MediaMonitor* _tmp14_;
#line 281 "../src/LibraryMonitor.vala"
			_tmp6_ = _collection_it;
#line 281 "../src/LibraryMonitor.vala"
			if (!gee_iterator_next (_tmp6_)) {
#line 281 "../src/LibraryMonitor.vala"
				break;
#line 2464 "LibraryMonitor.c"
			}
#line 281 "../src/LibraryMonitor.vala"
			_tmp7_ = _collection_it;
#line 281 "../src/LibraryMonitor.vala"
			_tmp8_ = gee_iterator_get (_tmp7_);
#line 281 "../src/LibraryMonitor.vala"
			collection = (MediaSourceCollection*) _tmp8_;
#line 282 "../src/LibraryMonitor.vala"
			_tmp9_ = self->priv->monitors;
#line 282 "../src/LibraryMonitor.vala"
			_tmp10_ = collection;
#line 282 "../src/LibraryMonitor.vala"
			_tmp11_ = self->priv->workers;
#line 282 "../src/LibraryMonitor.vala"
			_tmp12_ = self->priv->cancellable;
#line 282 "../src/LibraryMonitor.vala"
			_tmp13_ = media_source_collection_create_media_monitor (_tmp10_, _tmp11_, _tmp12_);
#line 282 "../src/LibraryMonitor.vala"
			_tmp14_ = _tmp13_;
#line 282 "../src/LibraryMonitor.vala"
			gee_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_COLLECTION, GeeCollection), _tmp14_);
#line 282 "../src/LibraryMonitor.vala"
			_g_object_unref0 (_tmp14_);
#line 281 "../src/LibraryMonitor.vala"
			_data_collection_unref0 (collection);
#line 2490 "LibraryMonitor.c"
		}
#line 281 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_collection_it);
#line 2494 "LibraryMonitor.c"
	}
	{
		GeeList* _monitor_list = NULL;
		GeeList* _tmp15_;
		gint _monitor_size = 0;
		GeeList* _tmp16_;
		gint _tmp17_;
		gint _tmp18_;
		gint _monitor_index = 0;
#line 284 "../src/LibraryMonitor.vala"
		_tmp15_ = self->priv->monitors;
#line 284 "../src/LibraryMonitor.vala"
		_monitor_list = _tmp15_;
#line 284 "../src/LibraryMonitor.vala"
		_tmp16_ = _monitor_list;
#line 284 "../src/LibraryMonitor.vala"
		_tmp17_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_COLLECTION, GeeCollection));
#line 284 "../src/LibraryMonitor.vala"
		_tmp18_ = _tmp17_;
#line 284 "../src/LibraryMonitor.vala"
		_monitor_size = _tmp18_;
#line 284 "../src/LibraryMonitor.vala"
		_monitor_index = -1;
#line 284 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 2520 "LibraryMonitor.c"
			gint _tmp19_;
			gint _tmp20_;
			MediaMonitor* monitor = NULL;
			GeeList* _tmp21_;
			gpointer _tmp22_;
			MediaMonitor* _tmp23_;
#line 284 "../src/LibraryMonitor.vala"
			_monitor_index = _monitor_index + 1;
#line 284 "../src/LibraryMonitor.vala"
			_tmp19_ = _monitor_index;
#line 284 "../src/LibraryMonitor.vala"
			_tmp20_ = _monitor_size;
#line 284 "../src/LibraryMonitor.vala"
			if (!(_tmp19_ < _tmp20_)) {
#line 284 "../src/LibraryMonitor.vala"
				break;
#line 2537 "LibraryMonitor.c"
			}
#line 284 "../src/LibraryMonitor.vala"
			_tmp21_ = _monitor_list;
#line 284 "../src/LibraryMonitor.vala"
			_tmp22_ = gee_list_get (_tmp21_, _monitor_index);
#line 284 "../src/LibraryMonitor.vala"
			monitor = (MediaMonitor*) _tmp22_;
#line 285 "../src/LibraryMonitor.vala"
			_tmp23_ = monitor;
#line 285 "../src/LibraryMonitor.vala"
			media_monitor_notify_discovery_started (_tmp23_);
#line 284 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitor);
#line 2551 "LibraryMonitor.c"
		}
	}
#line 287 "../src/LibraryMonitor.vala"
	_tmp24_ = gee_hash_map_new (TYPE_MEDIA_MONITOR, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, GEE_TYPE_SET, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 287 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->discovered);
#line 287 "../src/LibraryMonitor.vala"
	self->priv->discovered = _tmp24_;
#line 288 "../src/LibraryMonitor.vala"
	_tmp25_ = gee_hash_set_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL);
#line 288 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->unknown_files);
#line 288 "../src/LibraryMonitor.vala"
	self->priv->unknown_files = _tmp25_;
#line 290 "../src/LibraryMonitor.vala"
	DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->discovery_started (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor));
#line 2568 "LibraryMonitor.c"
}

static void
library_monitor_real_file_discovered (DirectoryMonitor* base,
                                      GFile* file,
                                      GFileInfo* info)
{
	LibraryMonitor * self;
	Monitorable* representation = NULL;
	MediaMonitor* representing = NULL;
	gboolean ignore = FALSE;
	MediaMonitor* _tmp13_;
#line 293 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_MONITOR, LibraryMonitor);
#line 293 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 293 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (info, g_file_info_get_type ()));
#line 294 "../src/LibraryMonitor.vala"
	representation = NULL;
#line 295 "../src/LibraryMonitor.vala"
	representing = NULL;
#line 296 "../src/LibraryMonitor.vala"
	ignore = FALSE;
#line 2593 "LibraryMonitor.c"
	{
		GeeList* _monitor_list = NULL;
		GeeList* _tmp0_;
		gint _monitor_size = 0;
		GeeList* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		gint _monitor_index = 0;
#line 297 "../src/LibraryMonitor.vala"
		_tmp0_ = self->priv->monitors;
#line 297 "../src/LibraryMonitor.vala"
		_monitor_list = _tmp0_;
#line 297 "../src/LibraryMonitor.vala"
		_tmp1_ = _monitor_list;
#line 297 "../src/LibraryMonitor.vala"
		_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 297 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 297 "../src/LibraryMonitor.vala"
		_monitor_size = _tmp3_;
#line 297 "../src/LibraryMonitor.vala"
		_monitor_index = -1;
#line 297 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 2618 "LibraryMonitor.c"
			gint _tmp4_;
			gint _tmp5_;
			MediaMonitor* monitor = NULL;
			GeeList* _tmp6_;
			gpointer _tmp7_;
			MediaMonitorDiscoveredFile _result_ = 0;
			MediaMonitor* _tmp8_;
			Monitorable* _tmp9_ = NULL;
			MediaMonitorDiscoveredFile _tmp10_;
#line 297 "../src/LibraryMonitor.vala"
			_monitor_index = _monitor_index + 1;
#line 297 "../src/LibraryMonitor.vala"
			_tmp4_ = _monitor_index;
#line 297 "../src/LibraryMonitor.vala"
			_tmp5_ = _monitor_size;
#line 297 "../src/LibraryMonitor.vala"
			if (!(_tmp4_ < _tmp5_)) {
#line 297 "../src/LibraryMonitor.vala"
				break;
#line 2638 "LibraryMonitor.c"
			}
#line 297 "../src/LibraryMonitor.vala"
			_tmp6_ = _monitor_list;
#line 297 "../src/LibraryMonitor.vala"
			_tmp7_ = gee_list_get (_tmp6_, _monitor_index);
#line 297 "../src/LibraryMonitor.vala"
			monitor = (MediaMonitor*) _tmp7_;
#line 298 "../src/LibraryMonitor.vala"
			_tmp8_ = monitor;
#line 298 "../src/LibraryMonitor.vala"
			_tmp10_ = media_monitor_notify_file_discovered (_tmp8_, file, info, &_tmp9_);
#line 298 "../src/LibraryMonitor.vala"
			_g_object_unref0 (representation);
#line 298 "../src/LibraryMonitor.vala"
			representation = _tmp9_;
#line 298 "../src/LibraryMonitor.vala"
			_result_ = _tmp10_;
#line 300 "../src/LibraryMonitor.vala"
			if (_result_ == MEDIA_MONITOR_DISCOVERED_FILE_REPRESENTED) {
#line 2658 "LibraryMonitor.c"
				MediaMonitor* _tmp11_;
				MediaMonitor* _tmp12_;
#line 301 "../src/LibraryMonitor.vala"
				_tmp11_ = monitor;
#line 301 "../src/LibraryMonitor.vala"
				_tmp12_ = _g_object_ref0 (_tmp11_);
#line 301 "../src/LibraryMonitor.vala"
				_g_object_unref0 (representing);
#line 301 "../src/LibraryMonitor.vala"
				representing = _tmp12_;
#line 303 "../src/LibraryMonitor.vala"
				_g_object_unref0 (monitor);
#line 303 "../src/LibraryMonitor.vala"
				break;
#line 2673 "LibraryMonitor.c"
			} else {
#line 304 "../src/LibraryMonitor.vala"
				if (_result_ == MEDIA_MONITOR_DISCOVERED_FILE_IGNORE) {
#line 306 "../src/LibraryMonitor.vala"
					ignore = TRUE;
#line 308 "../src/LibraryMonitor.vala"
					_g_object_unref0 (monitor);
#line 308 "../src/LibraryMonitor.vala"
					break;
#line 2683 "LibraryMonitor.c"
				}
			}
#line 297 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitor);
#line 2688 "LibraryMonitor.c"
		}
	}
#line 312 "../src/LibraryMonitor.vala"
	_tmp13_ = representing;
#line 312 "../src/LibraryMonitor.vala"
	if (_tmp13_ != NULL) {
#line 2695 "LibraryMonitor.c"
		gboolean _tmp14_ = FALSE;
		Monitorable* _tmp15_;
		MediaMonitor* _tmp16_;
		Monitorable* _tmp17_;
#line 313 "../src/LibraryMonitor.vala"
		_tmp15_ = representation;
#line 313 "../src/LibraryMonitor.vala"
		if (_tmp15_ != NULL) {
#line 313 "../src/LibraryMonitor.vala"
			_tmp14_ = !ignore;
#line 2706 "LibraryMonitor.c"
		} else {
#line 313 "../src/LibraryMonitor.vala"
			_tmp14_ = FALSE;
#line 2710 "LibraryMonitor.c"
		}
#line 313 "../src/LibraryMonitor.vala"
		_vala_assert (_tmp14_, "representation != null && !ignore");
#line 314 "../src/LibraryMonitor.vala"
		_tmp16_ = representing;
#line 314 "../src/LibraryMonitor.vala"
		_tmp17_ = representation;
#line 314 "../src/LibraryMonitor.vala"
		library_monitor_add_to_discovered_list (self, _tmp16_, _tmp17_);
#line 2720 "LibraryMonitor.c"
	} else {
		gboolean _tmp18_ = FALSE;
		gboolean _tmp19_ = FALSE;
#line 315 "../src/LibraryMonitor.vala"
		if (!ignore) {
#line 2726 "LibraryMonitor.c"
			TombstoneSourceCollection* _tmp20_;
#line 315 "../src/LibraryMonitor.vala"
			_tmp20_ = tombstone_global;
#line 315 "../src/LibraryMonitor.vala"
			_tmp19_ = !tombstone_source_collection_matches (_tmp20_, file);
#line 2732 "LibraryMonitor.c"
		} else {
#line 315 "../src/LibraryMonitor.vala"
			_tmp19_ = FALSE;
#line 2736 "LibraryMonitor.c"
		}
#line 315 "../src/LibraryMonitor.vala"
		if (_tmp19_) {
#line 315 "../src/LibraryMonitor.vala"
			_tmp18_ = library_monitor_is_supported_filetype (self, file);
#line 2742 "LibraryMonitor.c"
		} else {
#line 315 "../src/LibraryMonitor.vala"
			_tmp18_ = FALSE;
#line 2746 "LibraryMonitor.c"
		}
#line 315 "../src/LibraryMonitor.vala"
		if (_tmp18_) {
#line 2750 "LibraryMonitor.c"
			GeeHashSet* _tmp21_;
#line 316 "../src/LibraryMonitor.vala"
			_tmp21_ = self->priv->unknown_files;
#line 316 "../src/LibraryMonitor.vala"
			gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), file);
#line 2756 "LibraryMonitor.c"
		}
	}
#line 319 "../src/LibraryMonitor.vala"
	DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->file_discovered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), file, info);
#line 293 "../src/LibraryMonitor.vala"
	_g_object_unref0 (representing);
#line 293 "../src/LibraryMonitor.vala"
	_g_object_unref0 (representation);
#line 2765 "LibraryMonitor.c"
}

static void
library_monitor_real_discovery_completed (DirectoryMonitor* base)
{
	LibraryMonitor * self;
#line 322 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_MONITOR, LibraryMonitor);
#line 323 "../src/LibraryMonitor.vala"
	library_monitor_async_discovery_completed (self, NULL, NULL);
#line 2776 "LibraryMonitor.c"
}

static void
library_monitor_async_discovery_completed_data_free (gpointer _data)
{
	LibraryMonitorAsyncDiscoveryCompletedData* _data_;
	_data_ = _data;
#line 97 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_data_->self);
#line 97 "../src/LibraryMonitor.vala"
	g_slice_free (LibraryMonitorAsyncDiscoveryCompletedData, _data_);
#line 2788 "LibraryMonitor.c"
}

static void
library_monitor_async_discovery_completed (LibraryMonitor* self,
                                           GAsyncReadyCallback _callback_,
                                           gpointer _user_data_)
{
	LibraryMonitorAsyncDiscoveryCompletedData* _data_;
	LibraryMonitor* _tmp0_;
#line 97 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 97 "../src/LibraryMonitor.vala"
	_data_ = g_slice_new0 (LibraryMonitorAsyncDiscoveryCompletedData);
#line 97 "../src/LibraryMonitor.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 97 "../src/LibraryMonitor.vala"
	g_task_set_task_data (_data_->_async_result, _data_, library_monitor_async_discovery_completed_data_free);
#line 97 "../src/LibraryMonitor.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 97 "../src/LibraryMonitor.vala"
	_data_->self = _tmp0_;
#line 97 "../src/LibraryMonitor.vala"
	library_monitor_async_discovery_completed_co (_data_);
#line 2812 "LibraryMonitor.c"
}

static void
library_monitor_async_discovery_completed_finish (LibraryMonitor* self,
                                                  GAsyncResult* _res_)
{
	LibraryMonitorAsyncDiscoveryCompletedData* _data_;
#line 97 "../src/LibraryMonitor.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 2822 "LibraryMonitor.c"
}

static gboolean
_library_monitor_async_discovery_completed_co_gsource_func (gpointer self)
{
	gboolean result;
	result = library_monitor_async_discovery_completed_co (self);
#line 378 "../src/LibraryMonitor.vala"
	return result;
#line 2832 "LibraryMonitor.c"
}

static gboolean
library_monitor_async_discovery_completed_co (LibraryMonitorAsyncDiscoveryCompletedData* _data_)
{
#line 326 "../src/LibraryMonitor.vala"
	switch (_data_->_state_) {
#line 326 "../src/LibraryMonitor.vala"
		case 0:
#line 2842 "LibraryMonitor.c"
		goto _state_0;
#line 326 "../src/LibraryMonitor.vala"
		case 1:
#line 2846 "LibraryMonitor.c"
		goto _state_1;
		default:
#line 326 "../src/LibraryMonitor.vala"
		g_assert_not_reached ();
#line 2851 "LibraryMonitor.c"
	}
	_state_0:
#line 331 "../src/LibraryMonitor.vala"
	_data_->_tmp0_ = _data_->self->priv->unknown_files;
#line 331 "../src/LibraryMonitor.vala"
	_data_->_tmp1_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 331 "../src/LibraryMonitor.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 331 "../src/LibraryMonitor.vala"
	if (_data_->_tmp2_ == 0) {
#line 332 "../src/LibraryMonitor.vala"
		library_monitor_discovery_stage_completed (_data_->self);
#line 334 "../src/LibraryMonitor.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 334 "../src/LibraryMonitor.vala"
		if (_data_->_state_ != 0) {
#line 334 "../src/LibraryMonitor.vala"
			while (!g_task_get_completed (_data_->_async_result)) {
#line 334 "../src/LibraryMonitor.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 2872 "LibraryMonitor.c"
			}
		}
#line 334 "../src/LibraryMonitor.vala"
		g_object_unref (_data_->_async_result);
#line 334 "../src/LibraryMonitor.vala"
		return FALSE;
#line 2879 "LibraryMonitor.c"
	}
#line 337 "../src/LibraryMonitor.vala"
	_data_->_tmp3_ = gee_array_list_new (TYPE_MONITORABLE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 337 "../src/LibraryMonitor.vala"
	_data_->all_candidates = _data_->_tmp3_;
#line 338 "../src/LibraryMonitor.vala"
	_data_->_tmp4_ = gee_array_list_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _file_equal_gee_equal_data_func, NULL, NULL);
#line 338 "../src/LibraryMonitor.vala"
	_data_->adopted = _data_->_tmp4_;
#line 2889 "LibraryMonitor.c"
	{
#line 339 "../src/LibraryMonitor.vala"
		_data_->_tmp5_ = _data_->self->priv->unknown_files;
#line 339 "../src/LibraryMonitor.vala"
		_data_->_tmp6_ = gee_abstract_collection_iterator (G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp5_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 339 "../src/LibraryMonitor.vala"
		_data_->_file_it = _data_->_tmp6_;
#line 339 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 339 "../src/LibraryMonitor.vala"
			_data_->_tmp7_ = _data_->_file_it;
#line 339 "../src/LibraryMonitor.vala"
			if (!gee_iterator_next (_data_->_tmp7_)) {
#line 339 "../src/LibraryMonitor.vala"
				break;
#line 2905 "LibraryMonitor.c"
			}
#line 339 "../src/LibraryMonitor.vala"
			_data_->_tmp8_ = _data_->_file_it;
#line 339 "../src/LibraryMonitor.vala"
			_data_->_tmp9_ = gee_iterator_get (_data_->_tmp8_);
#line 339 "../src/LibraryMonitor.vala"
			_data_->file = (GFile*) _data_->_tmp9_;
#line 340 "../src/LibraryMonitor.vala"
			_data_->_tmp10_ = _data_->file;
#line 340 "../src/LibraryMonitor.vala"
			_data_->_tmp11_ = directory_monitor_get_file_info (G_TYPE_CHECK_INSTANCE_CAST (_data_->self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), _data_->_tmp10_);
#line 340 "../src/LibraryMonitor.vala"
			_data_->info = _data_->_tmp11_;
#line 341 "../src/LibraryMonitor.vala"
			_data_->_tmp12_ = _data_->info;
#line 341 "../src/LibraryMonitor.vala"
			if (_data_->_tmp12_ == NULL) {
#line 342 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_data_->info);
#line 342 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_data_->file);
#line 342 "../src/LibraryMonitor.vala"
				continue;
#line 2929 "LibraryMonitor.c"
			}
#line 345 "../src/LibraryMonitor.vala"
			_data_->_tmp13_ = _data_->all_candidates;
#line 345 "../src/LibraryMonitor.vala"
			gee_abstract_collection_clear (G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp13_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 347 "../src/LibraryMonitor.vala"
			_data_->candidates = NULL;
#line 348 "../src/LibraryMonitor.vala"
			_data_->associated = FALSE;
#line 2939 "LibraryMonitor.c"
			{
#line 349 "../src/LibraryMonitor.vala"
				_data_->_tmp14_ = _data_->self->priv->monitors;
#line 349 "../src/LibraryMonitor.vala"
				_data_->_monitor_list = _data_->_tmp14_;
#line 349 "../src/LibraryMonitor.vala"
				_data_->_tmp15_ = _data_->_monitor_list;
#line 349 "../src/LibraryMonitor.vala"
				_data_->_tmp16_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp15_, GEE_TYPE_COLLECTION, GeeCollection));
#line 349 "../src/LibraryMonitor.vala"
				_data_->_tmp17_ = _data_->_tmp16_;
#line 349 "../src/LibraryMonitor.vala"
				_data_->_monitor_size = _data_->_tmp17_;
#line 349 "../src/LibraryMonitor.vala"
				_data_->_monitor_index = -1;
#line 349 "../src/LibraryMonitor.vala"
				while (TRUE) {
#line 349 "../src/LibraryMonitor.vala"
					_data_->_monitor_index = _data_->_monitor_index + 1;
#line 349 "../src/LibraryMonitor.vala"
					_data_->_tmp18_ = _data_->_monitor_index;
#line 349 "../src/LibraryMonitor.vala"
					_data_->_tmp19_ = _data_->_monitor_size;
#line 349 "../src/LibraryMonitor.vala"
					if (!(_data_->_tmp18_ < _data_->_tmp19_)) {
#line 349 "../src/LibraryMonitor.vala"
						break;
#line 2967 "LibraryMonitor.c"
					}
#line 349 "../src/LibraryMonitor.vala"
					_data_->_tmp20_ = _data_->_monitor_list;
#line 349 "../src/LibraryMonitor.vala"
					_data_->_tmp21_ = gee_list_get (_data_->_tmp20_, _data_->_monitor_index);
#line 349 "../src/LibraryMonitor.vala"
					_data_->monitor = (MediaMonitor*) _data_->_tmp21_;
#line 351 "../src/LibraryMonitor.vala"
					_data_->_tmp22_ = _data_->monitor;
#line 351 "../src/LibraryMonitor.vala"
					_data_->_tmp23_ = _data_->file;
#line 351 "../src/LibraryMonitor.vala"
					_data_->_tmp24_ = _data_->info;
#line 351 "../src/LibraryMonitor.vala"
					_data_->_tmp25_ = 0;
#line 351 "../src/LibraryMonitor.vala"
					_data_->_tmp26_ = media_monitor_candidates_for_unknown_file (_data_->_tmp22_, _data_->_tmp23_, _data_->_tmp24_, &_data_->_tmp25_);
#line 351 "../src/LibraryMonitor.vala"
					_data_->_result_ = _data_->_tmp25_;
#line 351 "../src/LibraryMonitor.vala"
					_g_object_unref0 (_data_->candidates);
#line 351 "../src/LibraryMonitor.vala"
					_data_->candidates = _data_->_tmp26_;
#line 352 "../src/LibraryMonitor.vala"
					if (_data_->_result_ == MEDIA_MONITOR_DISCOVERED_FILE_REPRESENTED) {
#line 352 "../src/LibraryMonitor.vala"
						_data_->_tmp27_ = TRUE;
#line 2995 "LibraryMonitor.c"
					} else {
#line 353 "../src/LibraryMonitor.vala"
						_data_->_tmp27_ = _data_->_result_ == MEDIA_MONITOR_DISCOVERED_FILE_IGNORE;
#line 2999 "LibraryMonitor.c"
					}
#line 352 "../src/LibraryMonitor.vala"
					if (_data_->_tmp27_) {
#line 354 "../src/LibraryMonitor.vala"
						_data_->associated = TRUE;
#line 356 "../src/LibraryMonitor.vala"
						_g_object_unref0 (_data_->monitor);
#line 356 "../src/LibraryMonitor.vala"
						break;
#line 3009 "LibraryMonitor.c"
					} else {
#line 357 "../src/LibraryMonitor.vala"
						_data_->_tmp28_ = _data_->candidates;
#line 357 "../src/LibraryMonitor.vala"
						if (_data_->_tmp28_ != NULL) {
#line 358 "../src/LibraryMonitor.vala"
							_data_->_tmp29_ = _data_->all_candidates;
#line 358 "../src/LibraryMonitor.vala"
							_data_->_tmp30_ = _data_->candidates;
#line 358 "../src/LibraryMonitor.vala"
							gee_array_list_add_all (_data_->_tmp29_, _data_->_tmp30_);
#line 3021 "LibraryMonitor.c"
						}
					}
#line 349 "../src/LibraryMonitor.vala"
					_g_object_unref0 (_data_->monitor);
#line 3026 "LibraryMonitor.c"
				}
			}
#line 362 "../src/LibraryMonitor.vala"
			if (_data_->associated) {
#line 363 "../src/LibraryMonitor.vala"
				_data_->_tmp31_ = _data_->adopted;
#line 363 "../src/LibraryMonitor.vala"
				_data_->_tmp32_ = _data_->file;
#line 363 "../src/LibraryMonitor.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp31_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _data_->_tmp32_);
#line 365 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_data_->candidates);
#line 365 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_data_->info);
#line 365 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_data_->file);
#line 365 "../src/LibraryMonitor.vala"
				continue;
#line 3045 "LibraryMonitor.c"
			}
#line 369 "../src/LibraryMonitor.vala"
			_data_->_tmp33_ = _data_->all_candidates;
#line 369 "../src/LibraryMonitor.vala"
			_data_->_tmp34_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp33_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 369 "../src/LibraryMonitor.vala"
			_data_->_tmp35_ = _data_->_tmp34_;
#line 369 "../src/LibraryMonitor.vala"
			if (_data_->_tmp35_ > 0) {
#line 371 "../src/LibraryMonitor.vala"
				_data_->_tmp36_ = _data_->all_candidates;
#line 371 "../src/LibraryMonitor.vala"
				_data_->_tmp37_ = _g_object_ref0 (_data_->_tmp36_);
#line 371 "../src/LibraryMonitor.vala"
				_data_->job_candidates = _data_->_tmp37_;
#line 372 "../src/LibraryMonitor.vala"
				_data_->_tmp38_ = gee_array_list_new (TYPE_MONITORABLE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 372 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_data_->all_candidates);
#line 372 "../src/LibraryMonitor.vala"
				_data_->all_candidates = _data_->_tmp38_;
#line 374 "../src/LibraryMonitor.vala"
				_data_->_tmp39_ = _data_->self->priv->checksums_total;
#line 374 "../src/LibraryMonitor.vala"
				_data_->self->priv->checksums_total = _data_->_tmp39_ + 1;
#line 375 "../src/LibraryMonitor.vala"
				_data_->_tmp40_ = _data_->self->priv->workers;
#line 375 "../src/LibraryMonitor.vala"
				_data_->_tmp41_ = _data_->file;
#line 375 "../src/LibraryMonitor.vala"
				_data_->_tmp42_ = _data_->job_candidates;
#line 375 "../src/LibraryMonitor.vala"
				_data_->_tmp43_ = library_monitor_find_move_job_new (_data_->self, _data_->_tmp41_, G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp42_, GEE_TYPE_COLLECTION, GeeCollection));
#line 375 "../src/LibraryMonitor.vala"
				_data_->_tmp44_ = _data_->_tmp43_;
#line 375 "../src/LibraryMonitor.vala"
				workers_enqueue (_data_->_tmp40_, G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp44_, TYPE_BACKGROUND_JOB, BackgroundJob));
#line 375 "../src/LibraryMonitor.vala"
				_background_job_unref0 (_data_->_tmp44_);
#line 369 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_data_->job_candidates);
#line 3087 "LibraryMonitor.c"
			}
#line 378 "../src/LibraryMonitor.vala"
			g_idle_add_full (G_PRIORITY_DEFAULT_IDLE, _library_monitor_async_discovery_completed_co_gsource_func, _data_, NULL);
#line 379 "../src/LibraryMonitor.vala"
			_data_->_state_ = 1;
#line 379 "../src/LibraryMonitor.vala"
			return FALSE;
#line 3095 "LibraryMonitor.c"
			_state_1:
			;
#line 339 "../src/LibraryMonitor.vala"
			_g_object_unref0 (_data_->candidates);
#line 339 "../src/LibraryMonitor.vala"
			_g_object_unref0 (_data_->info);
#line 339 "../src/LibraryMonitor.vala"
			_g_object_unref0 (_data_->file);
#line 3104 "LibraryMonitor.c"
		}
#line 339 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_data_->_file_it);
#line 3108 "LibraryMonitor.c"
	}
#line 383 "../src/LibraryMonitor.vala"
	_data_->_tmp45_ = _data_->self->priv->unknown_files;
#line 383 "../src/LibraryMonitor.vala"
	_data_->_tmp46_ = _data_->adopted;
#line 383 "../src/LibraryMonitor.vala"
	gee_collection_remove_all (G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp45_, GEE_TYPE_COLLECTION, GeeCollection), G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp46_, GEE_TYPE_COLLECTION, GeeCollection));
#line 385 "../src/LibraryMonitor.vala"
	_data_->self->priv->checksums_completed = 0;
#line 387 "../src/LibraryMonitor.vala"
	if (_data_->self->priv->checksums_total == 0) {
#line 388 "../src/LibraryMonitor.vala"
		library_monitor_discovery_stage_completed (_data_->self);
#line 3122 "LibraryMonitor.c"
	} else {
#line 390 "../src/LibraryMonitor.vala"
		_data_->_tmp47_ = g_strdup_printf ("%d checksum jobs initiated to verify unknown photo files", _data_->self->priv->checksums_total);
#line 390 "../src/LibraryMonitor.vala"
		_data_->_tmp48_ = _data_->_tmp47_;
#line 390 "../src/LibraryMonitor.vala"
		directory_monitor_mdbg (_data_->_tmp48_);
#line 390 "../src/LibraryMonitor.vala"
		_g_free0 (_data_->_tmp48_);
#line 391 "../src/LibraryMonitor.vala"
		g_signal_emit (_data_->self, library_monitor_signals[LIBRARY_MONITOR_AUTO_UPDATE_PROGRESS_SIGNAL], 0, _data_->self->priv->checksums_completed, _data_->self->priv->checksums_total);
#line 3134 "LibraryMonitor.c"
	}
#line 326 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_data_->adopted);
#line 326 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_data_->all_candidates);
#line 326 "../src/LibraryMonitor.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 326 "../src/LibraryMonitor.vala"
	if (_data_->_state_ != 0) {
#line 326 "../src/LibraryMonitor.vala"
		while (!g_task_get_completed (_data_->_async_result)) {
#line 326 "../src/LibraryMonitor.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 3148 "LibraryMonitor.c"
		}
	}
#line 326 "../src/LibraryMonitor.vala"
	g_object_unref (_data_->_async_result);
#line 326 "../src/LibraryMonitor.vala"
	return FALSE;
#line 3155 "LibraryMonitor.c"
}

static void
library_monitor_report_checksum_job_completed (LibraryMonitor* self)
{
	gint _tmp0_;
#line 395 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 396 "../src/LibraryMonitor.vala"
	_vala_assert (self->priv->checksums_completed < self->priv->checksums_total, "checksums_completed < checksums_total");
#line 397 "../src/LibraryMonitor.vala"
	_tmp0_ = self->priv->checksums_completed;
#line 397 "../src/LibraryMonitor.vala"
	self->priv->checksums_completed = _tmp0_ + 1;
#line 399 "../src/LibraryMonitor.vala"
	g_signal_emit (self, library_monitor_signals[LIBRARY_MONITOR_AUTO_UPDATE_PROGRESS_SIGNAL], 0, self->priv->checksums_completed, self->priv->checksums_total);
#line 401 "../src/LibraryMonitor.vala"
	if (self->priv->checksums_completed == self->priv->checksums_total) {
#line 402 "../src/LibraryMonitor.vala"
		library_monitor_discovery_stage_completed (self);
#line 3176 "LibraryMonitor.c"
	}
}

static gpointer
_background_job_ref0 (gpointer self)
{
#line 406 "../src/LibraryMonitor.vala"
	return self ? background_job_ref (self) : NULL;
#line 3185 "LibraryMonitor.c"
}

static void
library_monitor_on_find_move_completed (LibraryMonitor* self,
                                        BackgroundJob* j)
{
	LibraryMonitorFindMoveJob* job = NULL;
	LibraryMonitorFindMoveJob* _tmp0_;
	LibraryMonitorFindMoveJob* _tmp1_;
	Monitorable* _tmp2_;
	LibraryMonitorFindMoveJob* _tmp27_;
	GError* _tmp28_;
#line 405 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 405 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_BACKGROUND_JOB (j));
#line 406 "../src/LibraryMonitor.vala"
	_tmp0_ = _background_job_ref0 (G_TYPE_CHECK_INSTANCE_CAST (j, LIBRARY_MONITOR_TYPE_FIND_MOVE_JOB, LibraryMonitorFindMoveJob));
#line 406 "../src/LibraryMonitor.vala"
	job = _tmp0_;
#line 411 "../src/LibraryMonitor.vala"
	_tmp1_ = job;
#line 411 "../src/LibraryMonitor.vala"
	_tmp2_ = _tmp1_->match;
#line 411 "../src/LibraryMonitor.vala"
	if (_tmp2_ != NULL) {
#line 3212 "LibraryMonitor.c"
		LibraryMonitorFindMoveJob* _tmp3_;
		GFile* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		LibraryMonitorFindMoveJob* _tmp7_;
		Monitorable* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		MediaMonitor* monitor = NULL;
		LibraryMonitorFindMoveJob* _tmp13_;
		Monitorable* _tmp14_;
		MediaMonitor* _tmp15_;
		MediaMonitor* _tmp16_;
		LibraryMonitorFindMoveJob* _tmp17_;
		Monitorable* _tmp18_;
		LibraryMonitorFindMoveJob* _tmp19_;
		GFile* _tmp20_;
		GeeHashSet* _tmp21_;
		LibraryMonitorFindMoveJob* _tmp22_;
		GFile* _tmp23_;
		MediaMonitor* _tmp24_;
		LibraryMonitorFindMoveJob* _tmp25_;
		Monitorable* _tmp26_;
#line 412 "../src/LibraryMonitor.vala"
		_tmp3_ = job;
#line 412 "../src/LibraryMonitor.vala"
		_tmp4_ = _tmp3_->file;
#line 412 "../src/LibraryMonitor.vala"
		_tmp5_ = g_file_get_path (_tmp4_);
#line 412 "../src/LibraryMonitor.vala"
		_tmp6_ = _tmp5_;
#line 412 "../src/LibraryMonitor.vala"
		_tmp7_ = job;
#line 412 "../src/LibraryMonitor.vala"
		_tmp8_ = _tmp7_->match;
#line 412 "../src/LibraryMonitor.vala"
		_tmp9_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, TYPE_DATA_OBJECT, DataObject));
#line 412 "../src/LibraryMonitor.vala"
		_tmp10_ = _tmp9_;
#line 412 "../src/LibraryMonitor.vala"
		_tmp11_ = g_strdup_printf ("Found moved master file: %s matches %s", _tmp6_, _tmp10_);
#line 412 "../src/LibraryMonitor.vala"
		_tmp12_ = _tmp11_;
#line 412 "../src/LibraryMonitor.vala"
		directory_monitor_mdbg (_tmp12_);
#line 412 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp12_);
#line 412 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp10_);
#line 412 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp6_);
#line 415 "../src/LibraryMonitor.vala"
		_tmp13_ = job;
#line 415 "../src/LibraryMonitor.vala"
		_tmp14_ = _tmp13_->match;
#line 415 "../src/LibraryMonitor.vala"
		_tmp15_ = library_monitor_get_monitor_for_monitorable (self, _tmp14_);
#line 415 "../src/LibraryMonitor.vala"
		monitor = _tmp15_;
#line 416 "../src/LibraryMonitor.vala"
		_tmp16_ = monitor;
#line 416 "../src/LibraryMonitor.vala"
		_tmp17_ = job;
#line 416 "../src/LibraryMonitor.vala"
		_tmp18_ = _tmp17_->match;
#line 416 "../src/LibraryMonitor.vala"
		_tmp19_ = job;
#line 416 "../src/LibraryMonitor.vala"
		_tmp20_ = _tmp19_->file;
#line 416 "../src/LibraryMonitor.vala"
		media_monitor_update_master_file (_tmp16_, _tmp18_, _tmp20_);
#line 417 "../src/LibraryMonitor.vala"
		_tmp21_ = self->priv->unknown_files;
#line 417 "../src/LibraryMonitor.vala"
		_tmp22_ = job;
#line 417 "../src/LibraryMonitor.vala"
		_tmp23_ = _tmp22_->file;
#line 417 "../src/LibraryMonitor.vala"
		gee_abstract_collection_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp23_);
#line 418 "../src/LibraryMonitor.vala"
		_tmp24_ = monitor;
#line 418 "../src/LibraryMonitor.vala"
		_tmp25_ = job;
#line 418 "../src/LibraryMonitor.vala"
		_tmp26_ = _tmp25_->match;
#line 418 "../src/LibraryMonitor.vala"
		library_monitor_add_to_discovered_list (self, _tmp24_, _tmp26_);
#line 411 "../src/LibraryMonitor.vala"
		_g_object_unref0 (monitor);
#line 3304 "LibraryMonitor.c"
	}
#line 421 "../src/LibraryMonitor.vala"
	_tmp27_ = job;
#line 421 "../src/LibraryMonitor.vala"
	_tmp28_ = _tmp27_->err;
#line 421 "../src/LibraryMonitor.vala"
	if (_tmp28_ != NULL) {
#line 3312 "LibraryMonitor.c"
		LibraryMonitorFindMoveJob* _tmp29_;
		GFile* _tmp30_;
		gchar* _tmp31_;
		gchar* _tmp32_;
		LibraryMonitorFindMoveJob* _tmp33_;
		GError* _tmp34_;
		const gchar* _tmp35_;
#line 422 "../src/LibraryMonitor.vala"
		_tmp29_ = job;
#line 422 "../src/LibraryMonitor.vala"
		_tmp30_ = _tmp29_->file;
#line 422 "../src/LibraryMonitor.vala"
		_tmp31_ = g_file_get_path (_tmp30_);
#line 422 "../src/LibraryMonitor.vala"
		_tmp32_ = _tmp31_;
#line 422 "../src/LibraryMonitor.vala"
		_tmp33_ = job;
#line 422 "../src/LibraryMonitor.vala"
		_tmp34_ = _tmp33_->err;
#line 422 "../src/LibraryMonitor.vala"
		_tmp35_ = _tmp34_->message;
#line 422 "../src/LibraryMonitor.vala"
		g_warning ("LibraryMonitor.vala:422: Unable to checksum unknown media file %s: %s", _tmp32_, _tmp35_);
#line 422 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp32_);
#line 3338 "LibraryMonitor.c"
	}
#line 424 "../src/LibraryMonitor.vala"
	library_monitor_report_checksum_job_completed (self);
#line 405 "../src/LibraryMonitor.vala"
	_background_job_unref0 (job);
#line 3344 "LibraryMonitor.c"
}

static void
library_monitor_on_find_move_cancelled (LibraryMonitor* self,
                                        BackgroundJob* j)
{
#line 427 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 427 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_BACKGROUND_JOB (j));
#line 428 "../src/LibraryMonitor.vala"
	library_monitor_report_checksum_job_completed (self);
#line 3357 "LibraryMonitor.c"
}

static void
library_monitor_discovery_stage_completed (LibraryMonitor* self)
{
	TombstoneSourceCollection* _tmp58_;
	GCancellable* _tmp59_;
#line 431 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 3367 "LibraryMonitor.c"
	{
		GeeList* _monitor_list = NULL;
		GeeList* _tmp0_;
		gint _monitor_size = 0;
		GeeList* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		gint _monitor_index = 0;
#line 432 "../src/LibraryMonitor.vala"
		_tmp0_ = self->priv->monitors;
#line 432 "../src/LibraryMonitor.vala"
		_monitor_list = _tmp0_;
#line 432 "../src/LibraryMonitor.vala"
		_tmp1_ = _monitor_list;
#line 432 "../src/LibraryMonitor.vala"
		_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 432 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 432 "../src/LibraryMonitor.vala"
		_monitor_size = _tmp3_;
#line 432 "../src/LibraryMonitor.vala"
		_monitor_index = -1;
#line 432 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 3392 "LibraryMonitor.c"
			gint _tmp4_;
			gint _tmp5_;
			MediaMonitor* monitor = NULL;
			GeeList* _tmp6_;
			gpointer _tmp7_;
			GeeSet* monitorables = NULL;
			GeeHashMap* _tmp8_;
			MediaMonitor* _tmp9_;
			gpointer _tmp10_;
			GeeSet* _tmp11_;
#line 432 "../src/LibraryMonitor.vala"
			_monitor_index = _monitor_index + 1;
#line 432 "../src/LibraryMonitor.vala"
			_tmp4_ = _monitor_index;
#line 432 "../src/LibraryMonitor.vala"
			_tmp5_ = _monitor_size;
#line 432 "../src/LibraryMonitor.vala"
			if (!(_tmp4_ < _tmp5_)) {
#line 432 "../src/LibraryMonitor.vala"
				break;
#line 3413 "LibraryMonitor.c"
			}
#line 432 "../src/LibraryMonitor.vala"
			_tmp6_ = _monitor_list;
#line 432 "../src/LibraryMonitor.vala"
			_tmp7_ = gee_list_get (_tmp6_, _monitor_index);
#line 432 "../src/LibraryMonitor.vala"
			monitor = (MediaMonitor*) _tmp7_;
#line 433 "../src/LibraryMonitor.vala"
			_tmp8_ = self->priv->discovered;
#line 433 "../src/LibraryMonitor.vala"
			_tmp9_ = monitor;
#line 433 "../src/LibraryMonitor.vala"
			_tmp10_ = gee_abstract_map_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GEE_TYPE_ABSTRACT_MAP, GeeAbstractMap), _tmp9_);
#line 433 "../src/LibraryMonitor.vala"
			monitorables = (GeeSet*) _tmp10_;
#line 434 "../src/LibraryMonitor.vala"
			_tmp11_ = monitorables;
#line 434 "../src/LibraryMonitor.vala"
			if (_tmp11_ != NULL) {
#line 3433 "LibraryMonitor.c"
				{
					GeeIterator* _monitorable_it = NULL;
					GeeSet* _tmp12_;
					GeeIterator* _tmp13_;
#line 435 "../src/LibraryMonitor.vala"
					_tmp12_ = monitorables;
#line 435 "../src/LibraryMonitor.vala"
					_tmp13_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_ITERABLE, GeeIterable));
#line 435 "../src/LibraryMonitor.vala"
					_monitorable_it = _tmp13_;
#line 435 "../src/LibraryMonitor.vala"
					while (TRUE) {
#line 3446 "LibraryMonitor.c"
						GeeIterator* _tmp14_;
						Monitorable* monitorable = NULL;
						GeeIterator* _tmp15_;
						gpointer _tmp16_;
						Monitorable* _tmp17_;
						MediaMonitor* _tmp18_;
#line 435 "../src/LibraryMonitor.vala"
						_tmp14_ = _monitorable_it;
#line 435 "../src/LibraryMonitor.vala"
						if (!gee_iterator_next (_tmp14_)) {
#line 435 "../src/LibraryMonitor.vala"
							break;
#line 3459 "LibraryMonitor.c"
						}
#line 435 "../src/LibraryMonitor.vala"
						_tmp15_ = _monitorable_it;
#line 435 "../src/LibraryMonitor.vala"
						_tmp16_ = gee_iterator_get (_tmp15_);
#line 435 "../src/LibraryMonitor.vala"
						monitorable = (Monitorable*) _tmp16_;
#line 436 "../src/LibraryMonitor.vala"
						_tmp17_ = monitorable;
#line 436 "../src/LibraryMonitor.vala"
						_tmp18_ = monitor;
#line 436 "../src/LibraryMonitor.vala"
						library_monitor_enqueue_verify_monitorable (self, _tmp17_, _tmp18_);
#line 435 "../src/LibraryMonitor.vala"
						_g_object_unref0 (monitorable);
#line 3475 "LibraryMonitor.c"
					}
#line 435 "../src/LibraryMonitor.vala"
					_g_object_unref0 (_monitorable_it);
#line 3479 "LibraryMonitor.c"
				}
			}
			{
				GeeIterator* _object_it = NULL;
				MediaMonitor* _tmp19_;
				MediaSourceCollection* _tmp20_;
				MediaSourceCollection* _tmp21_;
				GeeCollection* _tmp22_;
				GeeCollection* _tmp23_;
				GeeIterator* _tmp24_;
				GeeIterator* _tmp25_;
#line 439 "../src/LibraryMonitor.vala"
				_tmp19_ = monitor;
#line 439 "../src/LibraryMonitor.vala"
				_tmp20_ = media_monitor_get_media_source_collection (_tmp19_);
#line 439 "../src/LibraryMonitor.vala"
				_tmp21_ = _tmp20_;
#line 439 "../src/LibraryMonitor.vala"
				_tmp22_ = data_collection_get_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, TYPE_DATA_COLLECTION, DataCollection));
#line 439 "../src/LibraryMonitor.vala"
				_tmp23_ = _tmp22_;
#line 439 "../src/LibraryMonitor.vala"
				_tmp24_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, GEE_TYPE_ITERABLE, GeeIterable));
#line 439 "../src/LibraryMonitor.vala"
				_tmp25_ = _tmp24_;
#line 439 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_tmp23_);
#line 439 "../src/LibraryMonitor.vala"
				_data_collection_unref0 (_tmp21_);
#line 439 "../src/LibraryMonitor.vala"
				_object_it = _tmp25_;
#line 439 "../src/LibraryMonitor.vala"
				while (TRUE) {
#line 3513 "LibraryMonitor.c"
					GeeIterator* _tmp26_;
					DataObject* object = NULL;
					GeeIterator* _tmp27_;
					gpointer _tmp28_;
					Monitorable* monitorable = NULL;
					DataObject* _tmp29_;
					Monitorable* _tmp30_;
					gboolean _tmp31_ = FALSE;
					GeeSet* _tmp32_;
					Monitorable* _tmp35_;
					MediaMonitor* _tmp36_;
#line 439 "../src/LibraryMonitor.vala"
					_tmp26_ = _object_it;
#line 439 "../src/LibraryMonitor.vala"
					if (!gee_iterator_next (_tmp26_)) {
#line 439 "../src/LibraryMonitor.vala"
						break;
#line 3531 "LibraryMonitor.c"
					}
#line 439 "../src/LibraryMonitor.vala"
					_tmp27_ = _object_it;
#line 439 "../src/LibraryMonitor.vala"
					_tmp28_ = gee_iterator_get (_tmp27_);
#line 439 "../src/LibraryMonitor.vala"
					object = (DataObject*) _tmp28_;
#line 440 "../src/LibraryMonitor.vala"
					_tmp29_ = object;
#line 440 "../src/LibraryMonitor.vala"
					_tmp30_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, TYPE_MONITORABLE, Monitorable));
#line 440 "../src/LibraryMonitor.vala"
					monitorable = _tmp30_;
#line 442 "../src/LibraryMonitor.vala"
					_tmp32_ = monitorables;
#line 442 "../src/LibraryMonitor.vala"
					if (_tmp32_ != NULL) {
#line 3549 "LibraryMonitor.c"
						GeeSet* _tmp33_;
						Monitorable* _tmp34_;
#line 442 "../src/LibraryMonitor.vala"
						_tmp33_ = monitorables;
#line 442 "../src/LibraryMonitor.vala"
						_tmp34_ = monitorable;
#line 442 "../src/LibraryMonitor.vala"
						_tmp31_ = gee_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, GEE_TYPE_COLLECTION, GeeCollection), _tmp34_);
#line 3558 "LibraryMonitor.c"
					} else {
#line 442 "../src/LibraryMonitor.vala"
						_tmp31_ = FALSE;
#line 3562 "LibraryMonitor.c"
					}
#line 442 "../src/LibraryMonitor.vala"
					if (_tmp31_) {
#line 443 "../src/LibraryMonitor.vala"
						_g_object_unref0 (monitorable);
#line 443 "../src/LibraryMonitor.vala"
						_g_object_unref0 (object);
#line 443 "../src/LibraryMonitor.vala"
						continue;
#line 3572 "LibraryMonitor.c"
					}
#line 445 "../src/LibraryMonitor.vala"
					_tmp35_ = monitorable;
#line 445 "../src/LibraryMonitor.vala"
					_tmp36_ = monitor;
#line 445 "../src/LibraryMonitor.vala"
					library_monitor_enqueue_verify_monitorable (self, _tmp35_, _tmp36_);
#line 439 "../src/LibraryMonitor.vala"
					_g_object_unref0 (monitorable);
#line 439 "../src/LibraryMonitor.vala"
					_g_object_unref0 (object);
#line 3584 "LibraryMonitor.c"
				}
#line 439 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_object_it);
#line 3588 "LibraryMonitor.c"
			}
			{
				GeeIterator* _source_it = NULL;
				MediaMonitor* _tmp37_;
				MediaSourceCollection* _tmp38_;
				MediaSourceCollection* _tmp39_;
				MediaSourceHoldingTank* _tmp40_;
				MediaSourceHoldingTank* _tmp41_;
				GeeCollection* _tmp42_;
				GeeCollection* _tmp43_;
				GeeIterator* _tmp44_;
				GeeIterator* _tmp45_;
#line 448 "../src/LibraryMonitor.vala"
				_tmp37_ = monitor;
#line 448 "../src/LibraryMonitor.vala"
				_tmp38_ = media_monitor_get_media_source_collection (_tmp37_);
#line 448 "../src/LibraryMonitor.vala"
				_tmp39_ = _tmp38_;
#line 448 "../src/LibraryMonitor.vala"
				_tmp40_ = media_source_collection_get_offline_bin (_tmp39_);
#line 448 "../src/LibraryMonitor.vala"
				_tmp41_ = _tmp40_;
#line 448 "../src/LibraryMonitor.vala"
				_tmp42_ = source_holding_tank_get_all (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, TYPE_SOURCE_HOLDING_TANK, SourceHoldingTank));
#line 448 "../src/LibraryMonitor.vala"
				_tmp43_ = _tmp42_;
#line 448 "../src/LibraryMonitor.vala"
				_tmp44_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, GEE_TYPE_ITERABLE, GeeIterable));
#line 448 "../src/LibraryMonitor.vala"
				_tmp45_ = _tmp44_;
#line 448 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_tmp43_);
#line 448 "../src/LibraryMonitor.vala"
				_source_holding_tank_unref0 (_tmp41_);
#line 448 "../src/LibraryMonitor.vala"
				_data_collection_unref0 (_tmp39_);
#line 448 "../src/LibraryMonitor.vala"
				_source_it = _tmp45_;
#line 448 "../src/LibraryMonitor.vala"
				while (TRUE) {
#line 3629 "LibraryMonitor.c"
					GeeIterator* _tmp46_;
					DataSource* source = NULL;
					GeeIterator* _tmp47_;
					gpointer _tmp48_;
					Monitorable* monitorable = NULL;
					DataSource* _tmp49_;
					Monitorable* _tmp50_;
					gboolean _tmp51_ = FALSE;
					GeeSet* _tmp52_;
					Monitorable* _tmp55_;
					MediaMonitor* _tmp56_;
#line 448 "../src/LibraryMonitor.vala"
					_tmp46_ = _source_it;
#line 448 "../src/LibraryMonitor.vala"
					if (!gee_iterator_next (_tmp46_)) {
#line 448 "../src/LibraryMonitor.vala"
						break;
#line 3647 "LibraryMonitor.c"
					}
#line 448 "../src/LibraryMonitor.vala"
					_tmp47_ = _source_it;
#line 448 "../src/LibraryMonitor.vala"
					_tmp48_ = gee_iterator_get (_tmp47_);
#line 448 "../src/LibraryMonitor.vala"
					source = (DataSource*) _tmp48_;
#line 450 "../src/LibraryMonitor.vala"
					_tmp49_ = source;
#line 450 "../src/LibraryMonitor.vala"
					_tmp50_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, TYPE_MONITORABLE, Monitorable));
#line 450 "../src/LibraryMonitor.vala"
					monitorable = _tmp50_;
#line 452 "../src/LibraryMonitor.vala"
					_tmp52_ = monitorables;
#line 452 "../src/LibraryMonitor.vala"
					if (_tmp52_ != NULL) {
#line 3665 "LibraryMonitor.c"
						GeeSet* _tmp53_;
						Monitorable* _tmp54_;
#line 452 "../src/LibraryMonitor.vala"
						_tmp53_ = monitorables;
#line 452 "../src/LibraryMonitor.vala"
						_tmp54_ = monitorable;
#line 452 "../src/LibraryMonitor.vala"
						_tmp51_ = gee_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, GEE_TYPE_COLLECTION, GeeCollection), _tmp54_);
#line 3674 "LibraryMonitor.c"
					} else {
#line 452 "../src/LibraryMonitor.vala"
						_tmp51_ = FALSE;
#line 3678 "LibraryMonitor.c"
					}
#line 452 "../src/LibraryMonitor.vala"
					if (_tmp51_) {
#line 453 "../src/LibraryMonitor.vala"
						_g_object_unref0 (monitorable);
#line 453 "../src/LibraryMonitor.vala"
						_g_object_unref0 (source);
#line 453 "../src/LibraryMonitor.vala"
						continue;
#line 3688 "LibraryMonitor.c"
					}
#line 455 "../src/LibraryMonitor.vala"
					_tmp55_ = monitorable;
#line 455 "../src/LibraryMonitor.vala"
					_tmp56_ = monitor;
#line 455 "../src/LibraryMonitor.vala"
					library_monitor_enqueue_verify_monitorable (self, _tmp55_, _tmp56_);
#line 448 "../src/LibraryMonitor.vala"
					_g_object_unref0 (monitorable);
#line 448 "../src/LibraryMonitor.vala"
					_g_object_unref0 (source);
#line 3700 "LibraryMonitor.c"
				}
#line 448 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_source_it);
#line 3704 "LibraryMonitor.c"
			}
#line 432 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitorables);
#line 432 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitor);
#line 3710 "LibraryMonitor.c"
		}
	}
#line 460 "../src/LibraryMonitor.vala"
	if (self->priv->auto_import) {
#line 3715 "LibraryMonitor.c"
		GeeHashSet* _tmp57_;
#line 461 "../src/LibraryMonitor.vala"
		_tmp57_ = self->priv->unknown_files;
#line 461 "../src/LibraryMonitor.vala"
		library_monitor_enqueue_import_many (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp57_, GEE_TYPE_COLLECTION, GeeCollection));
#line 3721 "LibraryMonitor.c"
	}
#line 464 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->discovered);
#line 464 "../src/LibraryMonitor.vala"
	self->priv->discovered = NULL;
#line 465 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->unknown_files);
#line 465 "../src/LibraryMonitor.vala"
	self->priv->unknown_files = NULL;
#line 469 "../src/LibraryMonitor.vala"
	_tmp58_ = tombstone_global;
#line 469 "../src/LibraryMonitor.vala"
	_tmp59_ = self->priv->cancellable;
#line 469 "../src/LibraryMonitor.vala"
	tombstone_source_collection_launch_scan (_tmp58_, G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), _tmp59_);
#line 472 "../src/LibraryMonitor.vala"
	DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->discovery_completed (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor));
#line 3739 "LibraryMonitor.c"
}

static void
library_monitor_enqueue_verify_monitorable (LibraryMonitor* self,
                                            Monitorable* monitorable,
                                            MediaMonitor* monitor)
{
	gboolean offered = FALSE;
	GeeQueue* _tmp0_;
	LibraryMonitorVerifyJob* _tmp1_;
	LibraryMonitorVerifyJob* _tmp2_;
	gboolean _tmp3_;
#line 475 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 475 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_MONITORABLE (monitorable));
#line 475 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_MEDIA_MONITOR (monitor));
#line 476 "../src/LibraryMonitor.vala"
	_tmp0_ = self->priv->verify_queue;
#line 476 "../src/LibraryMonitor.vala"
	_tmp1_ = library_monitor_verify_job_new (monitorable, monitor);
#line 476 "../src/LibraryMonitor.vala"
	_tmp2_ = _tmp1_;
#line 476 "../src/LibraryMonitor.vala"
	_tmp3_ = gee_queue_offer (_tmp0_, _tmp2_);
#line 476 "../src/LibraryMonitor.vala"
	_library_monitor_verify_job_unref0 (_tmp2_);
#line 476 "../src/LibraryMonitor.vala"
	offered = _tmp3_;
#line 477 "../src/LibraryMonitor.vala"
	_vala_assert (offered, "offered");
#line 479 "../src/LibraryMonitor.vala"
	library_monitor_execute_next_verify_job (self);
#line 3774 "LibraryMonitor.c"
}

static void
library_monitor_execute_next_verify_job (LibraryMonitor* self)
{
	gboolean _tmp0_ = FALSE;
	LibraryMonitorVerifyJob* job = NULL;
	GeeQueue* _tmp4_;
	gpointer _tmp5_;
	LibraryMonitorVerifyJob* _tmp6_;
	gint _tmp7_;
	LibraryMonitorVerifyJob* _tmp8_;
	Monitorable* _tmp9_;
	LibraryMonitorVerifyJob* _tmp10_;
	MediaMonitor* _tmp11_;
#line 482 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 483 "../src/LibraryMonitor.vala"
	if (self->priv->outstanding_verify_jobs >= LIBRARY_MONITOR_MAX_VERIFY_EXISTING_MEDIA_JOBS) {
#line 483 "../src/LibraryMonitor.vala"
		_tmp0_ = TRUE;
#line 3796 "LibraryMonitor.c"
	} else {
		GeeQueue* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
#line 483 "../src/LibraryMonitor.vala"
		_tmp1_ = self->priv->verify_queue;
#line 483 "../src/LibraryMonitor.vala"
		_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 483 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 483 "../src/LibraryMonitor.vala"
		_tmp0_ = _tmp3_ == 0;
#line 3809 "LibraryMonitor.c"
	}
#line 483 "../src/LibraryMonitor.vala"
	if (_tmp0_) {
#line 484 "../src/LibraryMonitor.vala"
		return;
#line 3815 "LibraryMonitor.c"
	}
#line 486 "../src/LibraryMonitor.vala"
	_tmp4_ = self->priv->verify_queue;
#line 486 "../src/LibraryMonitor.vala"
	_tmp5_ = gee_queue_poll (_tmp4_);
#line 486 "../src/LibraryMonitor.vala"
	job = (LibraryMonitorVerifyJob*) _tmp5_;
#line 487 "../src/LibraryMonitor.vala"
	_tmp6_ = job;
#line 487 "../src/LibraryMonitor.vala"
	_vala_assert (_tmp6_ != NULL, "job != null");
#line 489 "../src/LibraryMonitor.vala"
	_tmp7_ = self->priv->outstanding_verify_jobs;
#line 489 "../src/LibraryMonitor.vala"
	self->priv->outstanding_verify_jobs = _tmp7_ + 1;
#line 490 "../src/LibraryMonitor.vala"
	_tmp8_ = job;
#line 490 "../src/LibraryMonitor.vala"
	_tmp9_ = _tmp8_->monitorable;
#line 490 "../src/LibraryMonitor.vala"
	_tmp10_ = job;
#line 490 "../src/LibraryMonitor.vala"
	_tmp11_ = _tmp10_->monitor;
#line 490 "../src/LibraryMonitor.vala"
	library_monitor_verify_monitorable (self, _tmp9_, _tmp11_, NULL, NULL);
#line 482 "../src/LibraryMonitor.vala"
	_library_monitor_verify_job_unref0 (job);
#line 3843 "LibraryMonitor.c"
}

static void
library_monitor_verify_monitorable_data_free (gpointer _data)
{
	LibraryMonitorVerifyMonitorableData* _data_;
	_data_ = _data;
#line 97 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_data_->monitorable);
#line 97 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_data_->monitor);
#line 97 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_data_->self);
#line 97 "../src/LibraryMonitor.vala"
	g_slice_free (LibraryMonitorVerifyMonitorableData, _data_);
#line 3859 "LibraryMonitor.c"
}

static void
library_monitor_verify_monitorable (LibraryMonitor* self,
                                    Monitorable* monitorable,
                                    MediaMonitor* monitor,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_)
{
	LibraryMonitorVerifyMonitorableData* _data_;
	LibraryMonitor* _tmp0_;
	Monitorable* _tmp1_;
	MediaMonitor* _tmp2_;
#line 97 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 97 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_MONITORABLE (monitorable));
#line 97 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_MEDIA_MONITOR (monitor));
#line 97 "../src/LibraryMonitor.vala"
	_data_ = g_slice_new0 (LibraryMonitorVerifyMonitorableData);
#line 97 "../src/LibraryMonitor.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 97 "../src/LibraryMonitor.vala"
	g_task_set_task_data (_data_->_async_result, _data_, library_monitor_verify_monitorable_data_free);
#line 97 "../src/LibraryMonitor.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 97 "../src/LibraryMonitor.vala"
	_data_->self = _tmp0_;
#line 97 "../src/LibraryMonitor.vala"
	_tmp1_ = _g_object_ref0 (monitorable);
#line 97 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_data_->monitorable);
#line 97 "../src/LibraryMonitor.vala"
	_data_->monitorable = _tmp1_;
#line 97 "../src/LibraryMonitor.vala"
	_tmp2_ = _g_object_ref0 (monitor);
#line 97 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_data_->monitor);
#line 97 "../src/LibraryMonitor.vala"
	_data_->monitor = _tmp2_;
#line 97 "../src/LibraryMonitor.vala"
	library_monitor_verify_monitorable_co (_data_);
#line 3903 "LibraryMonitor.c"
}

static void
library_monitor_verify_monitorable_finish (LibraryMonitor* self,
                                           GAsyncResult* _res_)
{
	LibraryMonitorVerifyMonitorableData* _data_;
#line 97 "../src/LibraryMonitor.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 3913 "LibraryMonitor.c"
}

static void
_vala_array_add126 (GFile** * array,
                    gint* length,
                    gint* size,
                    GFile* value)
{
#line 500 "../src/LibraryMonitor.vala"
	if ((*length) == (*size)) {
#line 500 "../src/LibraryMonitor.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 500 "../src/LibraryMonitor.vala"
		*array = g_renew (GFile*, *array, (*size) + 1);
#line 3928 "LibraryMonitor.c"
	}
#line 500 "../src/LibraryMonitor.vala"
	(*array)[(*length)++] = value;
#line 500 "../src/LibraryMonitor.vala"
	(*array)[*length] = NULL;
#line 3934 "LibraryMonitor.c"
}

static void
library_monitor_verify_monitorable_ready (GObject* source_object,
                                          GAsyncResult* _res_,
                                          gpointer _user_data_)
{
	LibraryMonitorVerifyMonitorableData* _data_;
#line 509 "../src/LibraryMonitor.vala"
	_data_ = _user_data_;
#line 509 "../src/LibraryMonitor.vala"
	_data_->_source_object_ = source_object;
#line 509 "../src/LibraryMonitor.vala"
	_data_->_res_ = _res_;
#line 509 "../src/LibraryMonitor.vala"
	library_monitor_verify_monitorable_co (_data_);
#line 3951 "LibraryMonitor.c"
}

static gboolean
_library_monitor_verify_monitorable_co_gsource_func (gpointer self)
{
	gboolean result;
	result = library_monitor_verify_monitorable_co (self);
#line 530 "../src/LibraryMonitor.vala"
	return result;
#line 3961 "LibraryMonitor.c"
}

static gboolean
library_monitor_verify_monitorable_co (LibraryMonitorVerifyMonitorableData* _data_)
{
#line 493 "../src/LibraryMonitor.vala"
	switch (_data_->_state_) {
#line 493 "../src/LibraryMonitor.vala"
		case 0:
#line 3971 "LibraryMonitor.c"
		goto _state_0;
#line 493 "../src/LibraryMonitor.vala"
		case 1:
#line 3975 "LibraryMonitor.c"
		goto _state_1;
#line 493 "../src/LibraryMonitor.vala"
		case 2:
#line 3979 "LibraryMonitor.c"
		goto _state_2;
		default:
#line 493 "../src/LibraryMonitor.vala"
		g_assert_not_reached ();
#line 3984 "LibraryMonitor.c"
	}
	_state_0:
#line 494 "../src/LibraryMonitor.vala"
	_data_->_tmp0_ = g_new0 (GFile*, 1 + 1);
#line 494 "../src/LibraryMonitor.vala"
	_data_->files = _data_->_tmp0_;
#line 494 "../src/LibraryMonitor.vala"
	_data_->files_length1 = 1;
#line 494 "../src/LibraryMonitor.vala"
	_data_->_files_size_ = _data_->files_length1;
#line 495 "../src/LibraryMonitor.vala"
	_data_->_tmp1_ = _data_->files;
#line 495 "../src/LibraryMonitor.vala"
	_data_->_tmp1__length1 = _data_->files_length1;
#line 495 "../src/LibraryMonitor.vala"
	_data_->_tmp2_ = media_monitor_get_master_file (_data_->monitor, _data_->monitorable);
#line 495 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_data_->_tmp1_[0]);
#line 495 "../src/LibraryMonitor.vala"
	_data_->_tmp1_[0] = _data_->_tmp2_;
#line 497 "../src/LibraryMonitor.vala"
	_data_->_tmp3_ = 0;
#line 497 "../src/LibraryMonitor.vala"
	_data_->_tmp4_ = media_monitor_get_auxilliary_backing_files (_data_->monitor, _data_->monitorable, &_data_->_tmp3_);
#line 497 "../src/LibraryMonitor.vala"
	_data_->aux_files = _data_->_tmp4_;
#line 497 "../src/LibraryMonitor.vala"
	_data_->aux_files_length1 = _data_->_tmp3_;
#line 497 "../src/LibraryMonitor.vala"
	_data_->_aux_files_size_ = _data_->aux_files_length1;
#line 498 "../src/LibraryMonitor.vala"
	_data_->_tmp5_ = _data_->aux_files;
#line 498 "../src/LibraryMonitor.vala"
	_data_->_tmp5__length1 = _data_->aux_files_length1;
#line 498 "../src/LibraryMonitor.vala"
	if (_data_->_tmp5_ != NULL) {
#line 499 "../src/LibraryMonitor.vala"
		_data_->_tmp6_ = _data_->aux_files;
#line 499 "../src/LibraryMonitor.vala"
		_data_->_tmp6__length1 = _data_->aux_files_length1;
#line 4025 "LibraryMonitor.c"
		{
#line 499 "../src/LibraryMonitor.vala"
			_data_->aux_file_collection_length1 = 0;
#line 499 "../src/LibraryMonitor.vala"
			_data_->_aux_file_collection_size_ = 0;
#line 499 "../src/LibraryMonitor.vala"
			_data_->aux_file_collection = _data_->_tmp6_;
#line 499 "../src/LibraryMonitor.vala"
			_data_->aux_file_collection_length1 = _data_->_tmp6__length1;
#line 499 "../src/LibraryMonitor.vala"
			for (_data_->aux_file_it = 0; _data_->aux_file_it < _data_->aux_file_collection_length1; _data_->aux_file_it = _data_->aux_file_it + 1) {
#line 499 "../src/LibraryMonitor.vala"
				_data_->_tmp7_ = _g_object_ref0 (_data_->aux_file_collection[_data_->aux_file_it]);
#line 499 "../src/LibraryMonitor.vala"
				_data_->aux_file = _data_->_tmp7_;
#line 4041 "LibraryMonitor.c"
				{
#line 500 "../src/LibraryMonitor.vala"
					_data_->_tmp8_ = _data_->aux_file;
#line 500 "../src/LibraryMonitor.vala"
					_data_->_tmp9_ = _g_object_ref0 (_data_->_tmp8_);
#line 500 "../src/LibraryMonitor.vala"
					_vala_array_add126 (&_data_->files, &_data_->files_length1, &_data_->_files_size_, _data_->_tmp9_);
#line 499 "../src/LibraryMonitor.vala"
					_g_object_unref0 (_data_->aux_file);
#line 4051 "LibraryMonitor.c"
				}
			}
		}
	}
	{
#line 503 "../src/LibraryMonitor.vala"
		_data_->ctr = 0;
#line 4059 "LibraryMonitor.c"
		{
#line 503 "../src/LibraryMonitor.vala"
			_data_->_tmp10_ = TRUE;
#line 503 "../src/LibraryMonitor.vala"
			while (TRUE) {
#line 503 "../src/LibraryMonitor.vala"
				if (!_data_->_tmp10_) {
#line 503 "../src/LibraryMonitor.vala"
					_data_->_tmp11_ = _data_->ctr;
#line 503 "../src/LibraryMonitor.vala"
					_data_->ctr = _data_->_tmp11_ + 1;
#line 4071 "LibraryMonitor.c"
				}
#line 503 "../src/LibraryMonitor.vala"
				_data_->_tmp10_ = FALSE;
#line 503 "../src/LibraryMonitor.vala"
				_data_->_tmp12_ = _data_->files;
#line 503 "../src/LibraryMonitor.vala"
				_data_->_tmp12__length1 = _data_->files_length1;
#line 503 "../src/LibraryMonitor.vala"
				if (!(_data_->ctr < _data_->_tmp12__length1)) {
#line 503 "../src/LibraryMonitor.vala"
					break;
#line 4083 "LibraryMonitor.c"
				}
#line 504 "../src/LibraryMonitor.vala"
				_data_->_tmp13_ = _data_->files;
#line 504 "../src/LibraryMonitor.vala"
				_data_->_tmp13__length1 = _data_->files_length1;
#line 504 "../src/LibraryMonitor.vala"
				_data_->_tmp14_ = _data_->_tmp13_[_data_->ctr];
#line 504 "../src/LibraryMonitor.vala"
				_data_->_tmp15_ = _g_object_ref0 (_data_->_tmp14_);
#line 504 "../src/LibraryMonitor.vala"
				_data_->file = _data_->_tmp15_;
#line 506 "../src/LibraryMonitor.vala"
				_data_->_tmp16_ = _data_->file;
#line 506 "../src/LibraryMonitor.vala"
				_data_->_tmp17_ = directory_monitor_get_file_info (G_TYPE_CHECK_INSTANCE_CAST (_data_->self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), _data_->_tmp16_);
#line 506 "../src/LibraryMonitor.vala"
				_data_->info = _data_->_tmp17_;
#line 507 "../src/LibraryMonitor.vala"
				_data_->_tmp18_ = _data_->info;
#line 507 "../src/LibraryMonitor.vala"
				if (_data_->_tmp18_ == NULL) {
#line 4105 "LibraryMonitor.c"
					{
#line 509 "../src/LibraryMonitor.vala"
						_data_->_tmp20_ = _data_->file;
#line 509 "../src/LibraryMonitor.vala"
						_data_->_tmp21_ = _data_->self->priv->cancellable;
#line 509 "../src/LibraryMonitor.vala"
						_data_->_state_ = 1;
#line 509 "../src/LibraryMonitor.vala"
						g_file_query_info_async (_data_->_tmp20_, DIRECTORY_MONITOR_SUPPLIED_ATTRIBUTES, DIRECTORY_MONITOR_FILE_INFO_FLAGS, DIRECTORY_MONITOR_DEFAULT_PRIORITY, _data_->_tmp21_, library_monitor_verify_monitorable_ready, _data_);
#line 509 "../src/LibraryMonitor.vala"
						return FALSE;
#line 4117 "LibraryMonitor.c"
						_state_1:
#line 509 "../src/LibraryMonitor.vala"
						_data_->_tmp22_ = g_file_query_info_finish (_data_->_tmp20_, _data_->_res_, &_data_->_inner_error0_);
#line 509 "../src/LibraryMonitor.vala"
						_data_->_tmp19_ = _data_->_tmp22_;
#line 509 "../src/LibraryMonitor.vala"
						if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 4125 "LibraryMonitor.c"
							goto __catch0_g_error;
						}
#line 509 "../src/LibraryMonitor.vala"
						_data_->_tmp23_ = _data_->_tmp19_;
#line 509 "../src/LibraryMonitor.vala"
						_data_->_tmp19_ = NULL;
#line 509 "../src/LibraryMonitor.vala"
						_g_object_unref0 (_data_->info);
#line 509 "../src/LibraryMonitor.vala"
						_data_->info = _data_->_tmp23_;
#line 508 "../src/LibraryMonitor.vala"
						_g_object_unref0 (_data_->_tmp19_);
#line 4138 "LibraryMonitor.c"
					}
					goto __finally0;
					__catch0_g_error:
					{
#line 508 "../src/LibraryMonitor.vala"
						g_clear_error (&_data_->_inner_error0_);
#line 4145 "LibraryMonitor.c"
					}
					__finally0:
#line 508 "../src/LibraryMonitor.vala"
					if (G_UNLIKELY (_data_->_inner_error0_ != NULL)) {
#line 508 "../src/LibraryMonitor.vala"
						_g_object_unref0 (_data_->info);
#line 508 "../src/LibraryMonitor.vala"
						_g_object_unref0 (_data_->file);
#line 508 "../src/LibraryMonitor.vala"
						_data_->aux_files = (_vala_array_free (_data_->aux_files, _data_->aux_files_length1, (GDestroyNotify) g_object_unref), NULL);
#line 508 "../src/LibraryMonitor.vala"
						_data_->files = (_vala_array_free (_data_->files, _data_->files_length1, (GDestroyNotify) g_object_unref), NULL);
#line 508 "../src/LibraryMonitor.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error0_->message, g_quark_to_string (_data_->_inner_error0_->domain), _data_->_inner_error0_->code);
#line 508 "../src/LibraryMonitor.vala"
						g_clear_error (&_data_->_inner_error0_);
#line 508 "../src/LibraryMonitor.vala"
						g_object_unref (_data_->_async_result);
#line 508 "../src/LibraryMonitor.vala"
						return FALSE;
#line 4166 "LibraryMonitor.c"
					}
				}
#line 517 "../src/LibraryMonitor.vala"
				if (_data_->ctr == 0) {
#line 518 "../src/LibraryMonitor.vala"
					_data_->_tmp25_ = _data_->info;
#line 518 "../src/LibraryMonitor.vala"
					if (_data_->_tmp25_ != NULL) {
#line 518 "../src/LibraryMonitor.vala"
						_data_->_tmp24_ = media_monitor_is_offline (_data_->monitor, _data_->monitorable);
#line 4177 "LibraryMonitor.c"
					} else {
#line 518 "../src/LibraryMonitor.vala"
						_data_->_tmp24_ = FALSE;
#line 4181 "LibraryMonitor.c"
					}
#line 518 "../src/LibraryMonitor.vala"
					if (_data_->_tmp24_) {
#line 519 "../src/LibraryMonitor.vala"
						media_monitor_update_online (_data_->monitor, _data_->monitorable);
#line 4187 "LibraryMonitor.c"
					} else {
#line 520 "../src/LibraryMonitor.vala"
						_data_->_tmp27_ = _data_->info;
#line 520 "../src/LibraryMonitor.vala"
						if (_data_->_tmp27_ == NULL) {
#line 520 "../src/LibraryMonitor.vala"
							_data_->_tmp26_ = !media_monitor_is_offline (_data_->monitor, _data_->monitorable);
#line 4195 "LibraryMonitor.c"
						} else {
#line 520 "../src/LibraryMonitor.vala"
							_data_->_tmp26_ = FALSE;
#line 4199 "LibraryMonitor.c"
						}
#line 520 "../src/LibraryMonitor.vala"
						if (_data_->_tmp26_) {
#line 521 "../src/LibraryMonitor.vala"
							media_monitor_update_offline (_data_->monitor, _data_->monitorable);
#line 4205 "LibraryMonitor.c"
						}
					}
				}
#line 524 "../src/LibraryMonitor.vala"
				_data_->_tmp28_ = _data_->file;
#line 524 "../src/LibraryMonitor.vala"
				_data_->_tmp29_ = _data_->info;
#line 524 "../src/LibraryMonitor.vala"
				media_monitor_update_backing_file_info (_data_->monitor, _data_->monitorable, _data_->_tmp28_, _data_->_tmp29_);
#line 503 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_data_->info);
#line 503 "../src/LibraryMonitor.vala"
				_g_object_unref0 (_data_->file);
#line 4219 "LibraryMonitor.c"
			}
		}
	}
#line 527 "../src/LibraryMonitor.vala"
	_data_->_tmp30_ = _data_->self->priv->completed_monitorable_verifies;
#line 527 "../src/LibraryMonitor.vala"
	_data_->self->priv->completed_monitorable_verifies = _data_->_tmp30_ + 1;
#line 528 "../src/LibraryMonitor.vala"
	g_signal_emit (_data_->self, library_monitor_signals[LIBRARY_MONITOR_AUTO_UPDATE_PROGRESS_SIGNAL], 0, _data_->self->priv->completed_monitorable_verifies, _data_->self->priv->total_monitorable_verifies);
#line 530 "../src/LibraryMonitor.vala"
	g_idle_add_full (DIRECTORY_MONITOR_DEFAULT_PRIORITY, _library_monitor_verify_monitorable_co_gsource_func, _data_, NULL);
#line 531 "../src/LibraryMonitor.vala"
	_data_->_state_ = 2;
#line 531 "../src/LibraryMonitor.vala"
	return FALSE;
#line 4235 "LibraryMonitor.c"
	_state_2:
	;
#line 534 "../src/LibraryMonitor.vala"
	_vala_assert (_data_->self->priv->outstanding_verify_jobs > 0, "outstanding_verify_jobs > 0");
#line 535 "../src/LibraryMonitor.vala"
	_data_->_tmp31_ = _data_->self->priv->outstanding_verify_jobs;
#line 535 "../src/LibraryMonitor.vala"
	_data_->self->priv->outstanding_verify_jobs = _data_->_tmp31_ - 1;
#line 537 "../src/LibraryMonitor.vala"
	library_monitor_execute_next_verify_job (_data_->self);
#line 493 "../src/LibraryMonitor.vala"
	_data_->aux_files = (_vala_array_free (_data_->aux_files, _data_->aux_files_length1, (GDestroyNotify) g_object_unref), NULL);
#line 493 "../src/LibraryMonitor.vala"
	_data_->files = (_vala_array_free (_data_->files, _data_->files_length1, (GDestroyNotify) g_object_unref), NULL);
#line 493 "../src/LibraryMonitor.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 493 "../src/LibraryMonitor.vala"
	if (_data_->_state_ != 0) {
#line 493 "../src/LibraryMonitor.vala"
		while (!g_task_get_completed (_data_->_async_result)) {
#line 493 "../src/LibraryMonitor.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 4258 "LibraryMonitor.c"
		}
	}
#line 493 "../src/LibraryMonitor.vala"
	g_object_unref (_data_->_async_result);
#line 493 "../src/LibraryMonitor.vala"
	return FALSE;
#line 4265 "LibraryMonitor.c"
}

static void
library_monitor_on_config_changed (LibraryMonitor* self)
{
	gboolean value = FALSE;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	gboolean _tmp2_;
#line 540 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 541 "../src/LibraryMonitor.vala"
	_tmp0_ = config_facade_get_instance ();
#line 541 "../src/LibraryMonitor.vala"
	_tmp1_ = _tmp0_;
#line 541 "../src/LibraryMonitor.vala"
	_tmp2_ = configuration_facade_get_auto_import_from_library (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 541 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_tmp1_);
#line 541 "../src/LibraryMonitor.vala"
	value = _tmp2_;
#line 543 "../src/LibraryMonitor.vala"
	if (self->priv->auto_import == value) {
#line 544 "../src/LibraryMonitor.vala"
		return;
#line 4291 "LibraryMonitor.c"
	}
#line 546 "../src/LibraryMonitor.vala"
	self->priv->auto_import = value;
#line 547 "../src/LibraryMonitor.vala"
	if (self->priv->auto_import) {
#line 548 "../src/LibraryMonitor.vala"
		if (!commandline_options_no_runtime_monitoring) {
#line 549 "../src/LibraryMonitor.vala"
			library_monitor_import_unrepresented_files (self);
#line 4301 "LibraryMonitor.c"
		}
	} else {
#line 551 "../src/LibraryMonitor.vala"
		library_monitor_cancel_batch_imports (self);
#line 4306 "LibraryMonitor.c"
	}
}

static void
library_monitor_enqueue_import (LibraryMonitor* self,
                                GFile* file)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
	GeeHashSet* _tmp2_;
#line 555 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 555 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 556 "../src/LibraryMonitor.vala"
	_tmp2_ = self->priv->pending_imports;
#line 556 "../src/LibraryMonitor.vala"
	if (!gee_abstract_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), file)) {
#line 556 "../src/LibraryMonitor.vala"
		_tmp1_ = library_monitor_is_supported_filetype (self, file);
#line 4327 "LibraryMonitor.c"
	} else {
#line 556 "../src/LibraryMonitor.vala"
		_tmp1_ = FALSE;
#line 4331 "LibraryMonitor.c"
	}
#line 556 "../src/LibraryMonitor.vala"
	if (_tmp1_) {
#line 556 "../src/LibraryMonitor.vala"
		_tmp0_ = !library_monitor_is_blacklisted (file);
#line 4337 "LibraryMonitor.c"
	} else {
#line 556 "../src/LibraryMonitor.vala"
		_tmp0_ = FALSE;
#line 4341 "LibraryMonitor.c"
	}
#line 556 "../src/LibraryMonitor.vala"
	if (_tmp0_) {
#line 4345 "LibraryMonitor.c"
		GeeHashSet* _tmp3_;
#line 557 "../src/LibraryMonitor.vala"
		_tmp3_ = self->priv->import_queue;
#line 557 "../src/LibraryMonitor.vala"
		gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), file);
#line 4351 "LibraryMonitor.c"
	}
}

static void
library_monitor_enqueue_import_many (LibraryMonitor* self,
                                     GeeCollection* files)
{
#line 560 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 560 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (files, GEE_TYPE_COLLECTION));
#line 4363 "LibraryMonitor.c"
	{
		GeeIterator* _file_it = NULL;
		GeeIterator* _tmp0_;
#line 561 "../src/LibraryMonitor.vala"
		_tmp0_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (files, GEE_TYPE_ITERABLE, GeeIterable));
#line 561 "../src/LibraryMonitor.vala"
		_file_it = _tmp0_;
#line 561 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 4373 "LibraryMonitor.c"
			GeeIterator* _tmp1_;
			GFile* file = NULL;
			GeeIterator* _tmp2_;
			gpointer _tmp3_;
			GFile* _tmp4_;
#line 561 "../src/LibraryMonitor.vala"
			_tmp1_ = _file_it;
#line 561 "../src/LibraryMonitor.vala"
			if (!gee_iterator_next (_tmp1_)) {
#line 561 "../src/LibraryMonitor.vala"
				break;
#line 4385 "LibraryMonitor.c"
			}
#line 561 "../src/LibraryMonitor.vala"
			_tmp2_ = _file_it;
#line 561 "../src/LibraryMonitor.vala"
			_tmp3_ = gee_iterator_get (_tmp2_);
#line 561 "../src/LibraryMonitor.vala"
			file = (GFile*) _tmp3_;
#line 562 "../src/LibraryMonitor.vala"
			_tmp4_ = file;
#line 562 "../src/LibraryMonitor.vala"
			library_monitor_enqueue_import (self, _tmp4_);
#line 561 "../src/LibraryMonitor.vala"
			_g_object_unref0 (file);
#line 4399 "LibraryMonitor.c"
		}
#line 561 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_file_it);
#line 4403 "LibraryMonitor.c"
	}
}

static void
library_monitor_remove_queued_import (LibraryMonitor* self,
                                      GFile* file)
{
	GeeHashSet* _tmp0_;
#line 565 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 565 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 566 "../src/LibraryMonitor.vala"
	_tmp0_ = self->priv->import_queue;
#line 566 "../src/LibraryMonitor.vala"
	gee_abstract_collection_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), file);
#line 4420 "LibraryMonitor.c"
}

static gboolean
library_monitor_on_flush_import_queue (LibraryMonitor* self)
{
	GCancellable* _tmp0_;
	GeeHashSet* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	BatchImport* _tmp4_;
	GeeHashSet* _tmp5_;
	gint _tmp6_;
	gint _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	gint64 now = 0LL;
	gboolean _tmp10_ = FALSE;
	BatchImportRoll* _tmp11_;
	GeeArrayList* jobs = NULL;
	GeeArrayList* _tmp13_;
	GeeHashSet* _tmp26_;
	BatchImport* importer = NULL;
	GeeArrayList* _tmp27_;
	BatchImportRoll* _tmp28_;
	BatchImport* _tmp29_;
	BatchImport* _tmp30_;
	BatchImport* _tmp31_;
	GeeArrayList* _tmp32_;
	BatchImport* _tmp33_;
	gboolean result;
#line 569 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (IS_LIBRARY_MONITOR (self), FALSE);
#line 570 "../src/LibraryMonitor.vala"
	_tmp0_ = self->priv->cancellable;
#line 570 "../src/LibraryMonitor.vala"
	if (g_cancellable_is_cancelled (_tmp0_)) {
#line 571 "../src/LibraryMonitor.vala"
		result = FALSE;
#line 571 "../src/LibraryMonitor.vala"
		return result;
#line 4461 "LibraryMonitor.c"
	}
#line 573 "../src/LibraryMonitor.vala"
	_tmp1_ = self->priv->import_queue;
#line 573 "../src/LibraryMonitor.vala"
	_tmp2_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 573 "../src/LibraryMonitor.vala"
	_tmp3_ = _tmp2_;
#line 573 "../src/LibraryMonitor.vala"
	if (_tmp3_ == 0) {
#line 574 "../src/LibraryMonitor.vala"
		result = TRUE;
#line 574 "../src/LibraryMonitor.vala"
		return result;
#line 4475 "LibraryMonitor.c"
	}
#line 578 "../src/LibraryMonitor.vala"
	_tmp4_ = self->priv->current_batch_import;
#line 578 "../src/LibraryMonitor.vala"
	if (_tmp4_ != NULL) {
#line 579 "../src/LibraryMonitor.vala"
		result = TRUE;
#line 579 "../src/LibraryMonitor.vala"
		return result;
#line 4485 "LibraryMonitor.c"
	}
#line 581 "../src/LibraryMonitor.vala"
	_tmp5_ = self->priv->import_queue;
#line 581 "../src/LibraryMonitor.vala"
	_tmp6_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 581 "../src/LibraryMonitor.vala"
	_tmp7_ = _tmp6_;
#line 581 "../src/LibraryMonitor.vala"
	_tmp8_ = g_strdup_printf ("Auto-importing %d files", _tmp7_);
#line 581 "../src/LibraryMonitor.vala"
	_tmp9_ = _tmp8_;
#line 581 "../src/LibraryMonitor.vala"
	directory_monitor_mdbg (_tmp9_);
#line 581 "../src/LibraryMonitor.vala"
	_g_free0 (_tmp9_);
#line 586 "../src/LibraryMonitor.vala"
	now = g_get_monotonic_time ();
#line 587 "../src/LibraryMonitor.vala"
	_tmp11_ = self->priv->current_import_roll;
#line 587 "../src/LibraryMonitor.vala"
	if (_tmp11_ == NULL) {
#line 587 "../src/LibraryMonitor.vala"
		_tmp10_ = TRUE;
#line 4509 "LibraryMonitor.c"
	} else {
#line 587 "../src/LibraryMonitor.vala"
		_tmp10_ = (now - self->priv->last_import_roll_use) >= ((gint64) LIBRARY_MONITOR_IMPORT_ROLL_QUIET_SEC);
#line 4513 "LibraryMonitor.c"
	}
#line 587 "../src/LibraryMonitor.vala"
	if (_tmp10_) {
#line 4517 "LibraryMonitor.c"
		BatchImportRoll* _tmp12_;
#line 588 "../src/LibraryMonitor.vala"
		_tmp12_ = batch_import_roll_new ();
#line 588 "../src/LibraryMonitor.vala"
		_batch_import_roll_unref0 (self->priv->current_import_roll);
#line 588 "../src/LibraryMonitor.vala"
		self->priv->current_import_roll = _tmp12_;
#line 4525 "LibraryMonitor.c"
	}
#line 589 "../src/LibraryMonitor.vala"
	self->priv->last_import_roll_use = now;
#line 591 "../src/LibraryMonitor.vala"
	_tmp13_ = gee_array_list_new (TYPE_BATCH_IMPORT_JOB, (GBoxedCopyFunc) batch_import_job_ref, (GDestroyNotify) batch_import_job_unref, NULL, NULL, NULL);
#line 591 "../src/LibraryMonitor.vala"
	jobs = _tmp13_;
#line 4533 "LibraryMonitor.c"
	{
		GeeIterator* _file_it = NULL;
		GeeHashSet* _tmp14_;
		GeeIterator* _tmp15_;
#line 592 "../src/LibraryMonitor.vala"
		_tmp14_ = self->priv->import_queue;
#line 592 "../src/LibraryMonitor.vala"
		_tmp15_ = gee_abstract_collection_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 592 "../src/LibraryMonitor.vala"
		_file_it = _tmp15_;
#line 592 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 4546 "LibraryMonitor.c"
			GeeIterator* _tmp16_;
			GFile* file = NULL;
			GeeIterator* _tmp17_;
			gpointer _tmp18_;
			GFile* _tmp19_;
			GeeArrayList* _tmp20_;
			GFile* _tmp21_;
			FileImportJob* _tmp22_;
			FileImportJob* _tmp23_;
			GeeHashSet* _tmp24_;
			GFile* _tmp25_;
#line 592 "../src/LibraryMonitor.vala"
			_tmp16_ = _file_it;
#line 592 "../src/LibraryMonitor.vala"
			if (!gee_iterator_next (_tmp16_)) {
#line 592 "../src/LibraryMonitor.vala"
				break;
#line 4564 "LibraryMonitor.c"
			}
#line 592 "../src/LibraryMonitor.vala"
			_tmp17_ = _file_it;
#line 592 "../src/LibraryMonitor.vala"
			_tmp18_ = gee_iterator_get (_tmp17_);
#line 592 "../src/LibraryMonitor.vala"
			file = (GFile*) _tmp18_;
#line 593 "../src/LibraryMonitor.vala"
			_tmp19_ = file;
#line 593 "../src/LibraryMonitor.vala"
			if (library_monitor_is_blacklisted (_tmp19_)) {
#line 594 "../src/LibraryMonitor.vala"
				_g_object_unref0 (file);
#line 594 "../src/LibraryMonitor.vala"
				continue;
#line 4580 "LibraryMonitor.c"
			}
#line 596 "../src/LibraryMonitor.vala"
			_tmp20_ = jobs;
#line 596 "../src/LibraryMonitor.vala"
			_tmp21_ = file;
#line 596 "../src/LibraryMonitor.vala"
			_tmp22_ = file_import_job_new (_tmp21_, FALSE, TRUE);
#line 596 "../src/LibraryMonitor.vala"
			_tmp23_ = _tmp22_;
#line 596 "../src/LibraryMonitor.vala"
			gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, TYPE_BATCH_IMPORT_JOB, BatchImportJob));
#line 596 "../src/LibraryMonitor.vala"
			_batch_import_job_unref0 (_tmp23_);
#line 597 "../src/LibraryMonitor.vala"
			_tmp24_ = self->priv->pending_imports;
#line 597 "../src/LibraryMonitor.vala"
			_tmp25_ = file;
#line 597 "../src/LibraryMonitor.vala"
			gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp25_);
#line 592 "../src/LibraryMonitor.vala"
			_g_object_unref0 (file);
#line 4602 "LibraryMonitor.c"
		}
#line 592 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_file_it);
#line 4606 "LibraryMonitor.c"
	}
#line 600 "../src/LibraryMonitor.vala"
	_tmp26_ = self->priv->import_queue;
#line 600 "../src/LibraryMonitor.vala"
	gee_abstract_collection_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 602 "../src/LibraryMonitor.vala"
	_tmp27_ = jobs;
#line 602 "../src/LibraryMonitor.vala"
	_tmp28_ = self->priv->current_import_roll;
#line 602 "../src/LibraryMonitor.vala"
	_tmp29_ = batch_import_new (G_TYPE_CHECK_INSTANCE_CAST (_tmp27_, GEE_TYPE_ITERABLE, GeeIterable), "LibraryMonitor autoimport", NULL, NULL, NULL, NULL, NULL, _tmp28_, NULL);
#line 602 "../src/LibraryMonitor.vala"
	importer = _tmp29_;
#line 604 "../src/LibraryMonitor.vala"
	_tmp30_ = importer;
#line 604 "../src/LibraryMonitor.vala"
	batch_import_set_untrash_duplicates (_tmp30_, FALSE);
#line 605 "../src/LibraryMonitor.vala"
	_tmp31_ = importer;
#line 605 "../src/LibraryMonitor.vala"
	batch_import_set_mark_duplicates_online (_tmp31_, FALSE);
#line 606 "../src/LibraryMonitor.vala"
	_tmp32_ = self->priv->batch_import_queue;
#line 606 "../src/LibraryMonitor.vala"
	_tmp33_ = importer;
#line 606 "../src/LibraryMonitor.vala"
	gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp33_);
#line 608 "../src/LibraryMonitor.vala"
	library_monitor_schedule_next_batch_import (self);
#line 610 "../src/LibraryMonitor.vala"
	result = TRUE;
#line 610 "../src/LibraryMonitor.vala"
	_g_object_unref0 (importer);
#line 610 "../src/LibraryMonitor.vala"
	_g_object_unref0 (jobs);
#line 610 "../src/LibraryMonitor.vala"
	return result;
#line 4644 "LibraryMonitor.c"
}

static void
_library_monitor_on_import_preparing_batch_import_preparing (BatchImport* _sender,
                                                             gpointer self)
{
#line 618 "../src/LibraryMonitor.vala"
	library_monitor_on_import_preparing ((LibraryMonitor*) self);
#line 4653 "LibraryMonitor.c"
}

static void
_library_monitor_on_import_progress_batch_import_progress (BatchImport* _sender,
                                                           guint64 completed_bytes,
                                                           guint64 total_bytes,
                                                           gpointer self)
{
#line 619 "../src/LibraryMonitor.vala"
	library_monitor_on_import_progress ((LibraryMonitor*) self, completed_bytes, total_bytes);
#line 4664 "LibraryMonitor.c"
}

static void
_library_monitor_on_import_complete_batch_import_import_complete (BatchImport* _sender,
                                                                  ImportManifest* manifest,
                                                                  BatchImportRoll* import_roll,
                                                                  gpointer self)
{
#line 620 "../src/LibraryMonitor.vala"
	library_monitor_on_import_complete ((LibraryMonitor*) self, _sender, manifest, import_roll);
#line 4675 "LibraryMonitor.c"
}

static void
library_monitor_schedule_next_batch_import (LibraryMonitor* self)
{
	gboolean _tmp0_ = FALSE;
	BatchImport* _tmp1_;
	GeeArrayList* _tmp5_;
	gpointer _tmp6_;
	BatchImport* _tmp7_;
	BatchImport* _tmp8_;
	BatchImport* _tmp9_;
	BatchImport* _tmp10_;
#line 613 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 614 "../src/LibraryMonitor.vala"
	_tmp1_ = self->priv->current_batch_import;
#line 614 "../src/LibraryMonitor.vala"
	if (_tmp1_ != NULL) {
#line 614 "../src/LibraryMonitor.vala"
		_tmp0_ = TRUE;
#line 4697 "LibraryMonitor.c"
	} else {
		GeeArrayList* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
#line 614 "../src/LibraryMonitor.vala"
		_tmp2_ = self->priv->batch_import_queue;
#line 614 "../src/LibraryMonitor.vala"
		_tmp3_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 614 "../src/LibraryMonitor.vala"
		_tmp4_ = _tmp3_;
#line 614 "../src/LibraryMonitor.vala"
		_tmp0_ = _tmp4_ == 0;
#line 4710 "LibraryMonitor.c"
	}
#line 614 "../src/LibraryMonitor.vala"
	if (_tmp0_) {
#line 615 "../src/LibraryMonitor.vala"
		return;
#line 4716 "LibraryMonitor.c"
	}
#line 617 "../src/LibraryMonitor.vala"
	_tmp5_ = self->priv->batch_import_queue;
#line 617 "../src/LibraryMonitor.vala"
	_tmp6_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), 0);
#line 617 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->current_batch_import);
#line 617 "../src/LibraryMonitor.vala"
	self->priv->current_batch_import = (BatchImport*) _tmp6_;
#line 618 "../src/LibraryMonitor.vala"
	_tmp7_ = self->priv->current_batch_import;
#line 618 "../src/LibraryMonitor.vala"
	g_signal_connect_object (_tmp7_, "preparing", (GCallback) _library_monitor_on_import_preparing_batch_import_preparing, self, 0);
#line 619 "../src/LibraryMonitor.vala"
	_tmp8_ = self->priv->current_batch_import;
#line 619 "../src/LibraryMonitor.vala"
	g_signal_connect_object (_tmp8_, "progress", (GCallback) _library_monitor_on_import_progress_batch_import_progress, self, 0);
#line 620 "../src/LibraryMonitor.vala"
	_tmp9_ = self->priv->current_batch_import;
#line 620 "../src/LibraryMonitor.vala"
	g_signal_connect_object (_tmp9_, "import-complete", (GCallback) _library_monitor_on_import_complete_batch_import_import_complete, self, 0);
#line 621 "../src/LibraryMonitor.vala"
	_tmp10_ = self->priv->current_batch_import;
#line 621 "../src/LibraryMonitor.vala"
	batch_import_schedule (_tmp10_);
#line 4742 "LibraryMonitor.c"
}

static void
library_monitor_discard_current_batch_import (LibraryMonitor* self)
{
	BatchImport* _tmp0_;
	gboolean removed = FALSE;
	GeeArrayList* _tmp1_;
	BatchImport* _tmp2_;
	BatchImport* _tmp3_;
	guint _tmp4_;
	BatchImport* _tmp5_;
	guint _tmp6_;
	BatchImport* _tmp7_;
	guint _tmp8_;
	GeeArrayList* _tmp9_;
	gint _tmp10_;
	gint _tmp11_;
#line 624 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 625 "../src/LibraryMonitor.vala"
	_tmp0_ = self->priv->current_batch_import;
#line 625 "../src/LibraryMonitor.vala"
	_vala_assert (_tmp0_ != NULL, "current_batch_import != null");
#line 627 "../src/LibraryMonitor.vala"
	_tmp1_ = self->priv->batch_import_queue;
#line 627 "../src/LibraryMonitor.vala"
	_tmp2_ = self->priv->current_batch_import;
#line 627 "../src/LibraryMonitor.vala"
	removed = gee_abstract_collection_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp2_);
#line 628 "../src/LibraryMonitor.vala"
	_vala_assert (removed, "removed");
#line 629 "../src/LibraryMonitor.vala"
	_tmp3_ = self->priv->current_batch_import;
#line 629 "../src/LibraryMonitor.vala"
	g_signal_parse_name ("preparing", TYPE_BATCH_IMPORT, &_tmp4_, NULL, FALSE);
#line 629 "../src/LibraryMonitor.vala"
	g_signal_handlers_disconnect_matched (_tmp3_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp4_, 0, NULL, (GCallback) _library_monitor_on_import_preparing_batch_import_preparing, self);
#line 630 "../src/LibraryMonitor.vala"
	_tmp5_ = self->priv->current_batch_import;
#line 630 "../src/LibraryMonitor.vala"
	g_signal_parse_name ("progress", TYPE_BATCH_IMPORT, &_tmp6_, NULL, FALSE);
#line 630 "../src/LibraryMonitor.vala"
	g_signal_handlers_disconnect_matched (_tmp5_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp6_, 0, NULL, (GCallback) _library_monitor_on_import_progress_batch_import_progress, self);
#line 631 "../src/LibraryMonitor.vala"
	_tmp7_ = self->priv->current_batch_import;
#line 631 "../src/LibraryMonitor.vala"
	g_signal_parse_name ("import-complete", TYPE_BATCH_IMPORT, &_tmp8_, NULL, FALSE);
#line 631 "../src/LibraryMonitor.vala"
	g_signal_handlers_disconnect_matched (_tmp7_, G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp8_, 0, NULL, (GCallback) _library_monitor_on_import_complete_batch_import_import_complete, self);
#line 632 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->current_batch_import);
#line 632 "../src/LibraryMonitor.vala"
	self->priv->current_batch_import = NULL;
#line 639 "../src/LibraryMonitor.vala"
	_tmp9_ = self->priv->batch_import_queue;
#line 639 "../src/LibraryMonitor.vala"
	_tmp10_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 639 "../src/LibraryMonitor.vala"
	_tmp11_ = _tmp10_;
#line 639 "../src/LibraryMonitor.vala"
	if (_tmp11_ == 0) {
#line 4805 "LibraryMonitor.c"
		GeeHashSet* _tmp12_;
#line 640 "../src/LibraryMonitor.vala"
		_tmp12_ = self->priv->pending_imports;
#line 640 "../src/LibraryMonitor.vala"
		gee_abstract_collection_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 4811 "LibraryMonitor.c"
	}
}

static void
library_monitor_cancel_batch_imports (LibraryMonitor* self)
{
	gint ctr = 0;
	BatchImport* _tmp13_;
	GeeHashSet* _tmp15_;
#line 643 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 645 "../src/LibraryMonitor.vala"
	ctr = 0;
#line 646 "../src/LibraryMonitor.vala"
	while (TRUE) {
#line 4827 "LibraryMonitor.c"
		GeeArrayList* _tmp0_;
		gint _tmp1_;
		gint _tmp2_;
		GeeArrayList* _tmp3_;
		gpointer _tmp4_;
		BatchImport* _tmp5_;
		BatchImport* _tmp6_;
		gboolean _tmp7_;
		GeeArrayList* _tmp9_;
		GeeArrayList* _tmp10_;
		gpointer _tmp11_;
		BatchImport* _tmp12_;
#line 646 "../src/LibraryMonitor.vala"
		_tmp0_ = self->priv->batch_import_queue;
#line 646 "../src/LibraryMonitor.vala"
		_tmp1_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 646 "../src/LibraryMonitor.vala"
		_tmp2_ = _tmp1_;
#line 646 "../src/LibraryMonitor.vala"
		if (!(ctr < _tmp2_)) {
#line 646 "../src/LibraryMonitor.vala"
			break;
#line 4850 "LibraryMonitor.c"
		}
#line 647 "../src/LibraryMonitor.vala"
		_tmp3_ = self->priv->batch_import_queue;
#line 647 "../src/LibraryMonitor.vala"
		_tmp4_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), ctr);
#line 647 "../src/LibraryMonitor.vala"
		_tmp5_ = (BatchImport*) _tmp4_;
#line 647 "../src/LibraryMonitor.vala"
		_tmp6_ = self->priv->current_batch_import;
#line 647 "../src/LibraryMonitor.vala"
		_tmp7_ = _tmp5_ == _tmp6_;
#line 647 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_tmp5_);
#line 647 "../src/LibraryMonitor.vala"
		if (_tmp7_) {
#line 4866 "LibraryMonitor.c"
			gint _tmp8_;
#line 648 "../src/LibraryMonitor.vala"
			_tmp8_ = ctr;
#line 648 "../src/LibraryMonitor.vala"
			ctr = _tmp8_ + 1;
#line 650 "../src/LibraryMonitor.vala"
			continue;
#line 4874 "LibraryMonitor.c"
		}
#line 653 "../src/LibraryMonitor.vala"
		_tmp9_ = self->priv->batch_import_queue;
#line 653 "../src/LibraryMonitor.vala"
		_tmp10_ = self->priv->batch_import_queue;
#line 653 "../src/LibraryMonitor.vala"
		_tmp11_ = gee_abstract_list_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_ABSTRACT_LIST, GeeAbstractList), ctr);
#line 653 "../src/LibraryMonitor.vala"
		_tmp12_ = (BatchImport*) _tmp11_;
#line 653 "../src/LibraryMonitor.vala"
		gee_abstract_collection_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp12_);
#line 653 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_tmp12_);
#line 4888 "LibraryMonitor.c"
	}
#line 657 "../src/LibraryMonitor.vala"
	_tmp13_ = self->priv->current_batch_import;
#line 657 "../src/LibraryMonitor.vala"
	if (_tmp13_ != NULL) {
#line 4894 "LibraryMonitor.c"
		BatchImport* _tmp14_;
#line 658 "../src/LibraryMonitor.vala"
		_tmp14_ = self->priv->current_batch_import;
#line 658 "../src/LibraryMonitor.vala"
		batch_import_user_halt (_tmp14_);
#line 4900 "LibraryMonitor.c"
	}
#line 661 "../src/LibraryMonitor.vala"
	_tmp15_ = self->priv->pending_imports;
#line 661 "../src/LibraryMonitor.vala"
	gee_abstract_collection_clear (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 4906 "LibraryMonitor.c"
}

static void
library_monitor_on_import_preparing (LibraryMonitor* self)
{
#line 664 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 665 "../src/LibraryMonitor.vala"
	g_signal_emit (self, library_monitor_signals[LIBRARY_MONITOR_AUTO_IMPORT_PREPARING_SIGNAL], 0);
#line 4916 "LibraryMonitor.c"
}

static void
library_monitor_on_import_progress (LibraryMonitor* self,
                                    guint64 completed_bytes,
                                    guint64 total_bytes)
{
#line 668 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 669 "../src/LibraryMonitor.vala"
	g_signal_emit (self, library_monitor_signals[LIBRARY_MONITOR_AUTO_IMPORT_PROGRESS_SIGNAL], 0, completed_bytes, total_bytes);
#line 4928 "LibraryMonitor.c"
}

static void
library_monitor_on_import_complete (LibraryMonitor* self,
                                    BatchImport* batch_import,
                                    ImportManifest* manifest,
                                    BatchImportRoll* import_roll)
{
	BatchImport* _tmp0_;
	GeeList* _tmp1_;
	gint _tmp2_;
	gint _tmp3_;
	gchar* _tmp4_;
	gchar* _tmp5_;
	GeeList* _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
	GeeHashSet* _tmp47_;
	gint _tmp48_;
	gint _tmp49_;
	gchar* _tmp50_;
	gchar* _tmp51_;
	GError* _inner_error0_ = NULL;
#line 672 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 672 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_BATCH_IMPORT (batch_import));
#line 672 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_IMPORT_MANIFEST (manifest));
#line 672 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_BATCH_IMPORT_ROLL (import_roll));
#line 674 "../src/LibraryMonitor.vala"
	_tmp0_ = self->priv->current_batch_import;
#line 674 "../src/LibraryMonitor.vala"
	_vala_assert (batch_import == _tmp0_, "batch_import == current_batch_import");
#line 676 "../src/LibraryMonitor.vala"
	_tmp1_ = manifest->all;
#line 676 "../src/LibraryMonitor.vala"
	_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 676 "../src/LibraryMonitor.vala"
	_tmp3_ = _tmp2_;
#line 676 "../src/LibraryMonitor.vala"
	_tmp4_ = g_strdup_printf ("auto-import batch completed %d", _tmp3_);
#line 676 "../src/LibraryMonitor.vala"
	_tmp5_ = _tmp4_;
#line 676 "../src/LibraryMonitor.vala"
	directory_monitor_mdbg (_tmp5_);
#line 676 "../src/LibraryMonitor.vala"
	_g_free0 (_tmp5_);
#line 677 "../src/LibraryMonitor.vala"
	g_signal_emit (self, library_monitor_signals[LIBRARY_MONITOR_AUTO_IMPORT_PROGRESS_SIGNAL], 0, (guint64) 0, (guint64) 0);
#line 4980 "LibraryMonitor.c"
	{
		GeeList* _result_list = NULL;
		GeeList* _tmp6_;
		gint _result_size = 0;
		GeeList* _tmp7_;
		gint _tmp8_;
		gint _tmp9_;
		gint _result_index = 0;
#line 679 "../src/LibraryMonitor.vala"
		_tmp6_ = manifest->all;
#line 679 "../src/LibraryMonitor.vala"
		_result_list = _tmp6_;
#line 679 "../src/LibraryMonitor.vala"
		_tmp7_ = _result_list;
#line 679 "../src/LibraryMonitor.vala"
		_tmp8_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GEE_TYPE_COLLECTION, GeeCollection));
#line 679 "../src/LibraryMonitor.vala"
		_tmp9_ = _tmp8_;
#line 679 "../src/LibraryMonitor.vala"
		_result_size = _tmp9_;
#line 679 "../src/LibraryMonitor.vala"
		_result_index = -1;
#line 679 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 5005 "LibraryMonitor.c"
			gint _tmp10_;
			gint _tmp11_;
			BatchImportResult* _result_ = NULL;
			GeeList* _tmp12_;
			gpointer _tmp13_;
			BatchImportResult* _tmp14_;
			GFile* _tmp15_;
#line 679 "../src/LibraryMonitor.vala"
			_result_index = _result_index + 1;
#line 679 "../src/LibraryMonitor.vala"
			_tmp10_ = _result_index;
#line 679 "../src/LibraryMonitor.vala"
			_tmp11_ = _result_size;
#line 679 "../src/LibraryMonitor.vala"
			if (!(_tmp10_ < _tmp11_)) {
#line 679 "../src/LibraryMonitor.vala"
				break;
#line 5023 "LibraryMonitor.c"
			}
#line 679 "../src/LibraryMonitor.vala"
			_tmp12_ = _result_list;
#line 679 "../src/LibraryMonitor.vala"
			_tmp13_ = gee_list_get (_tmp12_, _result_index);
#line 679 "../src/LibraryMonitor.vala"
			_result_ = (BatchImportResult*) _tmp13_;
#line 682 "../src/LibraryMonitor.vala"
			_tmp14_ = _result_;
#line 682 "../src/LibraryMonitor.vala"
			_tmp15_ = _tmp14_->file;
#line 682 "../src/LibraryMonitor.vala"
			if (_tmp15_ != NULL) {
#line 5037 "LibraryMonitor.c"
				GeeHashSet* _tmp16_;
				BatchImportResult* _tmp17_;
				GFile* _tmp18_;
#line 683 "../src/LibraryMonitor.vala"
				_tmp16_ = self->priv->pending_imports;
#line 683 "../src/LibraryMonitor.vala"
				_tmp17_ = _result_;
#line 683 "../src/LibraryMonitor.vala"
				_tmp18_ = _tmp17_->file;
#line 683 "../src/LibraryMonitor.vala"
				gee_abstract_collection_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp18_);
#line 5049 "LibraryMonitor.c"
			}
#line 679 "../src/LibraryMonitor.vala"
			_batch_import_result_unref0 (_result_);
#line 5053 "LibraryMonitor.c"
		}
	}
#line 686 "../src/LibraryMonitor.vala"
	_tmp19_ = manifest->already_imported;
#line 686 "../src/LibraryMonitor.vala"
	_tmp20_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_COLLECTION, GeeCollection));
#line 686 "../src/LibraryMonitor.vala"
	_tmp21_ = _tmp20_;
#line 686 "../src/LibraryMonitor.vala"
	if (_tmp21_ > 0) {
#line 5064 "LibraryMonitor.c"
		GeeArrayList* to_tombstone = NULL;
		GeeArrayList* _tmp22_;
#line 687 "../src/LibraryMonitor.vala"
		_tmp22_ = gee_array_list_new (TYPE_TOMBSTONED_FILE, (GBoxedCopyFunc) tombstoned_file_ref, (GDestroyNotify) tombstoned_file_unref, NULL, NULL, NULL);
#line 687 "../src/LibraryMonitor.vala"
		to_tombstone = _tmp22_;
#line 5071 "LibraryMonitor.c"
		{
			GeeList* _result_list = NULL;
			GeeList* _tmp23_;
			gint _result_size = 0;
			GeeList* _tmp24_;
			gint _tmp25_;
			gint _tmp26_;
			gint _result_index = 0;
#line 688 "../src/LibraryMonitor.vala"
			_tmp23_ = manifest->already_imported;
#line 688 "../src/LibraryMonitor.vala"
			_result_list = _tmp23_;
#line 688 "../src/LibraryMonitor.vala"
			_tmp24_ = _result_list;
#line 688 "../src/LibraryMonitor.vala"
			_tmp25_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, GEE_TYPE_COLLECTION, GeeCollection));
#line 688 "../src/LibraryMonitor.vala"
			_tmp26_ = _tmp25_;
#line 688 "../src/LibraryMonitor.vala"
			_result_size = _tmp26_;
#line 688 "../src/LibraryMonitor.vala"
			_result_index = -1;
#line 688 "../src/LibraryMonitor.vala"
			while (TRUE) {
#line 5096 "LibraryMonitor.c"
				gint _tmp27_;
				gint _tmp28_;
				BatchImportResult* _result_ = NULL;
				GeeList* _tmp29_;
				gpointer _tmp30_;
				GFileInfo* info = NULL;
				BatchImportResult* _tmp31_;
				GFile* _tmp32_;
				GFileInfo* _tmp33_;
				GFileInfo* _tmp34_;
				GeeArrayList* _tmp39_;
				BatchImportResult* _tmp40_;
				GFile* _tmp41_;
				GFileInfo* _tmp42_;
				TombstonedFile* _tmp43_;
				TombstonedFile* _tmp44_;
#line 688 "../src/LibraryMonitor.vala"
				_result_index = _result_index + 1;
#line 688 "../src/LibraryMonitor.vala"
				_tmp27_ = _result_index;
#line 688 "../src/LibraryMonitor.vala"
				_tmp28_ = _result_size;
#line 688 "../src/LibraryMonitor.vala"
				if (!(_tmp27_ < _tmp28_)) {
#line 688 "../src/LibraryMonitor.vala"
					break;
#line 5123 "LibraryMonitor.c"
				}
#line 688 "../src/LibraryMonitor.vala"
				_tmp29_ = _result_list;
#line 688 "../src/LibraryMonitor.vala"
				_tmp30_ = gee_list_get (_tmp29_, _result_index);
#line 688 "../src/LibraryMonitor.vala"
				_result_ = (BatchImportResult*) _tmp30_;
#line 689 "../src/LibraryMonitor.vala"
				_tmp31_ = _result_;
#line 689 "../src/LibraryMonitor.vala"
				_tmp32_ = _tmp31_->file;
#line 689 "../src/LibraryMonitor.vala"
				_tmp33_ = directory_monitor_get_file_info (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), _tmp32_);
#line 689 "../src/LibraryMonitor.vala"
				info = _tmp33_;
#line 690 "../src/LibraryMonitor.vala"
				_tmp34_ = info;
#line 690 "../src/LibraryMonitor.vala"
				if (_tmp34_ == NULL) {
#line 5143 "LibraryMonitor.c"
					BatchImportResult* _tmp35_;
					GFile* _tmp36_;
					gchar* _tmp37_;
					gchar* _tmp38_;
#line 691 "../src/LibraryMonitor.vala"
					_tmp35_ = _result_;
#line 691 "../src/LibraryMonitor.vala"
					_tmp36_ = _tmp35_->file;
#line 691 "../src/LibraryMonitor.vala"
					_tmp37_ = g_file_get_path (_tmp36_);
#line 691 "../src/LibraryMonitor.vala"
					_tmp38_ = _tmp37_;
#line 691 "../src/LibraryMonitor.vala"
					g_warning ("LibraryMonitor.vala:691: Unable to get info for duplicate file %s", _tmp38_);
#line 691 "../src/LibraryMonitor.vala"
					_g_free0 (_tmp38_);
#line 693 "../src/LibraryMonitor.vala"
					_g_object_unref0 (info);
#line 693 "../src/LibraryMonitor.vala"
					_batch_import_result_unref0 (_result_);
#line 693 "../src/LibraryMonitor.vala"
					continue;
#line 5166 "LibraryMonitor.c"
				}
#line 696 "../src/LibraryMonitor.vala"
				_tmp39_ = to_tombstone;
#line 696 "../src/LibraryMonitor.vala"
				_tmp40_ = _result_;
#line 696 "../src/LibraryMonitor.vala"
				_tmp41_ = _tmp40_->file;
#line 696 "../src/LibraryMonitor.vala"
				_tmp42_ = info;
#line 696 "../src/LibraryMonitor.vala"
				_tmp43_ = tombstoned_file_new (_tmp41_, g_file_info_get_size (_tmp42_), NULL);
#line 696 "../src/LibraryMonitor.vala"
				_tmp44_ = _tmp43_;
#line 696 "../src/LibraryMonitor.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp39_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp44_);
#line 696 "../src/LibraryMonitor.vala"
				_tombstoned_file_unref0 (_tmp44_);
#line 688 "../src/LibraryMonitor.vala"
				_g_object_unref0 (info);
#line 688 "../src/LibraryMonitor.vala"
				_batch_import_result_unref0 (_result_);
#line 5188 "LibraryMonitor.c"
			}
		}
		{
			GeeArrayList* _tmp45_;
#line 700 "../src/LibraryMonitor.vala"
			_tmp45_ = to_tombstone;
#line 700 "../src/LibraryMonitor.vala"
			tombstone_entomb_many_files (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, GEE_TYPE_COLLECTION, GeeCollection), TOMBSTONE_REASON_AUTO_DETECTED_DUPLICATE, &_inner_error0_);
#line 700 "../src/LibraryMonitor.vala"
			if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 700 "../src/LibraryMonitor.vala"
				if (_inner_error0_->domain == DATABASE_ERROR) {
#line 5201 "LibraryMonitor.c"
					goto __catch0_database_error;
				}
#line 700 "../src/LibraryMonitor.vala"
				_g_object_unref0 (to_tombstone);
#line 700 "../src/LibraryMonitor.vala"
				g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 700 "../src/LibraryMonitor.vala"
				g_clear_error (&_inner_error0_);
#line 700 "../src/LibraryMonitor.vala"
				return;
#line 5212 "LibraryMonitor.c"
			}
		}
		goto __finally0;
		__catch0_database_error:
		{
			GError* err = NULL;
			GError* _tmp46_;
#line 699 "../src/LibraryMonitor.vala"
			err = _inner_error0_;
#line 699 "../src/LibraryMonitor.vala"
			_inner_error0_ = NULL;
#line 702 "../src/LibraryMonitor.vala"
			_tmp46_ = err;
#line 702 "../src/LibraryMonitor.vala"
			app_window_database_error (_tmp46_);
#line 699 "../src/LibraryMonitor.vala"
			_g_error_free0 (err);
#line 5230 "LibraryMonitor.c"
		}
		__finally0:
#line 699 "../src/LibraryMonitor.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 699 "../src/LibraryMonitor.vala"
			_g_object_unref0 (to_tombstone);
#line 699 "../src/LibraryMonitor.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 699 "../src/LibraryMonitor.vala"
			g_clear_error (&_inner_error0_);
#line 699 "../src/LibraryMonitor.vala"
			return;
#line 5243 "LibraryMonitor.c"
		}
#line 686 "../src/LibraryMonitor.vala"
		_g_object_unref0 (to_tombstone);
#line 5247 "LibraryMonitor.c"
	}
#line 706 "../src/LibraryMonitor.vala"
	_tmp47_ = self->priv->pending_imports;
#line 706 "../src/LibraryMonitor.vala"
	_tmp48_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp47_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 706 "../src/LibraryMonitor.vala"
	_tmp49_ = _tmp48_;
#line 706 "../src/LibraryMonitor.vala"
	_tmp50_ = g_strdup_printf ("%d files remain pending for auto-import", _tmp49_);
#line 706 "../src/LibraryMonitor.vala"
	_tmp51_ = _tmp50_;
#line 706 "../src/LibraryMonitor.vala"
	directory_monitor_mdbg (_tmp51_);
#line 706 "../src/LibraryMonitor.vala"
	_g_free0 (_tmp51_);
#line 708 "../src/LibraryMonitor.vala"
	library_monitor_discard_current_batch_import (self);
#line 709 "../src/LibraryMonitor.vala"
	library_monitor_schedule_next_batch_import (self);
#line 5267 "LibraryMonitor.c"
}

void
library_monitor_blacklist_file (GFile* file,
                                const gchar* reason)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	GError* _inner_error0_ = NULL;
#line 725 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 725 "../src/LibraryMonitor.vala"
	g_return_if_fail (reason != NULL);
#line 726 "../src/LibraryMonitor.vala"
	_tmp0_ = g_file_get_path (file);
#line 726 "../src/LibraryMonitor.vala"
	_tmp1_ = _tmp0_;
#line 726 "../src/LibraryMonitor.vala"
	_tmp2_ = g_strdup_printf ("[%s] Blacklisting %s", reason, _tmp1_);
#line 726 "../src/LibraryMonitor.vala"
	_tmp3_ = _tmp2_;
#line 726 "../src/LibraryMonitor.vala"
	directory_monitor_mdbg (_tmp3_);
#line 726 "../src/LibraryMonitor.vala"
	_g_free0 (_tmp3_);
#line 726 "../src/LibraryMonitor.vala"
	_g_free0 (_tmp1_);
#line 5297 "LibraryMonitor.c"
	{
		GeeHashSet* _tmp4_;
#line 727 "../src/LibraryMonitor.vala"
		_tmp4_ = library_monitor_blacklist;
#line 727 "../src/LibraryMonitor.vala"
		g_rec_mutex_lock (&__lock_library_monitor_library_monitor_blacklist);
#line 5304 "LibraryMonitor.c"
		{
			GeeHashSet* _tmp5_;
#line 728 "../src/LibraryMonitor.vala"
			_tmp5_ = library_monitor_blacklist;
#line 728 "../src/LibraryMonitor.vala"
			gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), file);
#line 5311 "LibraryMonitor.c"
		}
		__finally0:
		{
			GeeHashSet* _tmp6_;
#line 727 "../src/LibraryMonitor.vala"
			_tmp6_ = library_monitor_blacklist;
#line 727 "../src/LibraryMonitor.vala"
			g_rec_mutex_unlock (&__lock_library_monitor_library_monitor_blacklist);
#line 5320 "LibraryMonitor.c"
		}
#line 727 "../src/LibraryMonitor.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 727 "../src/LibraryMonitor.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 727 "../src/LibraryMonitor.vala"
			g_clear_error (&_inner_error0_);
#line 727 "../src/LibraryMonitor.vala"
			return;
#line 5330 "LibraryMonitor.c"
		}
	}
}

void
library_monitor_unblacklist_file (GFile* file)
{
	GError* _inner_error0_ = NULL;
#line 732 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 5341 "LibraryMonitor.c"
	{
		GeeHashSet* _tmp0_;
#line 735 "../src/LibraryMonitor.vala"
		_tmp0_ = library_monitor_blacklist;
#line 735 "../src/LibraryMonitor.vala"
		g_rec_mutex_lock (&__lock_library_monitor_library_monitor_blacklist);
#line 5348 "LibraryMonitor.c"
		{
			gboolean _tmp1_ = FALSE;
			GeeHashSet* _tmp2_;
#line 736 "../src/LibraryMonitor.vala"
			_tmp2_ = library_monitor_blacklist;
#line 736 "../src/LibraryMonitor.vala"
			if (gee_abstract_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), file)) {
#line 5356 "LibraryMonitor.c"
				HashTimedQueue* _tmp3_;
#line 736 "../src/LibraryMonitor.vala"
				_tmp3_ = library_monitor_to_unblacklist;
#line 736 "../src/LibraryMonitor.vala"
				_tmp1_ = !hash_timed_queue_contains (_tmp3_, file);
#line 5362 "LibraryMonitor.c"
			} else {
#line 736 "../src/LibraryMonitor.vala"
				_tmp1_ = FALSE;
#line 5366 "LibraryMonitor.c"
			}
#line 736 "../src/LibraryMonitor.vala"
			if (_tmp1_) {
#line 5370 "LibraryMonitor.c"
				HashTimedQueue* _tmp4_;
#line 737 "../src/LibraryMonitor.vala"
				_tmp4_ = library_monitor_to_unblacklist;
#line 737 "../src/LibraryMonitor.vala"
				hash_timed_queue_enqueue (_tmp4_, file);
#line 5376 "LibraryMonitor.c"
			}
		}
		__finally0:
		{
			GeeHashSet* _tmp5_;
#line 735 "../src/LibraryMonitor.vala"
			_tmp5_ = library_monitor_blacklist;
#line 735 "../src/LibraryMonitor.vala"
			g_rec_mutex_unlock (&__lock_library_monitor_library_monitor_blacklist);
#line 5386 "LibraryMonitor.c"
		}
#line 735 "../src/LibraryMonitor.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 735 "../src/LibraryMonitor.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 735 "../src/LibraryMonitor.vala"
			g_clear_error (&_inner_error0_);
#line 735 "../src/LibraryMonitor.vala"
			return;
#line 5396 "LibraryMonitor.c"
		}
	}
}

static void
library_monitor_on_unblacklist_file (GFile* file)
{
	gboolean removed = FALSE;
	GError* _inner_error0_ = NULL;
#line 741 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 5408 "LibraryMonitor.c"
	{
		GeeHashSet* _tmp0_;
#line 743 "../src/LibraryMonitor.vala"
		_tmp0_ = library_monitor_blacklist;
#line 743 "../src/LibraryMonitor.vala"
		g_rec_mutex_lock (&__lock_library_monitor_library_monitor_blacklist);
#line 5415 "LibraryMonitor.c"
		{
			GeeHashSet* _tmp1_;
#line 744 "../src/LibraryMonitor.vala"
			_tmp1_ = library_monitor_blacklist;
#line 744 "../src/LibraryMonitor.vala"
			removed = gee_abstract_collection_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), file);
#line 5422 "LibraryMonitor.c"
		}
		__finally0:
		{
			GeeHashSet* _tmp2_;
#line 743 "../src/LibraryMonitor.vala"
			_tmp2_ = library_monitor_blacklist;
#line 743 "../src/LibraryMonitor.vala"
			g_rec_mutex_unlock (&__lock_library_monitor_library_monitor_blacklist);
#line 5431 "LibraryMonitor.c"
		}
#line 743 "../src/LibraryMonitor.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 743 "../src/LibraryMonitor.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 743 "../src/LibraryMonitor.vala"
			g_clear_error (&_inner_error0_);
#line 743 "../src/LibraryMonitor.vala"
			return;
#line 5441 "LibraryMonitor.c"
		}
	}
#line 747 "../src/LibraryMonitor.vala"
	if (removed) {
#line 5446 "LibraryMonitor.c"
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
#line 748 "../src/LibraryMonitor.vala"
		_tmp3_ = g_file_get_path (file);
#line 748 "../src/LibraryMonitor.vala"
		_tmp4_ = _tmp3_;
#line 748 "../src/LibraryMonitor.vala"
		_tmp5_ = g_strdup_printf ("Blacklist for %s removed", _tmp4_);
#line 748 "../src/LibraryMonitor.vala"
		_tmp6_ = _tmp5_;
#line 748 "../src/LibraryMonitor.vala"
		directory_monitor_mdbg (_tmp6_);
#line 748 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp6_);
#line 748 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp4_);
#line 5465 "LibraryMonitor.c"
	} else {
		gchar* _tmp7_;
		gchar* _tmp8_;
#line 750 "../src/LibraryMonitor.vala"
		_tmp7_ = g_file_get_path (file);
#line 750 "../src/LibraryMonitor.vala"
		_tmp8_ = _tmp7_;
#line 750 "../src/LibraryMonitor.vala"
		g_warning ("LibraryMonitor.vala:750: File %s was not blacklisted but unblacklisted", _tmp8_);
#line 750 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp8_);
#line 5477 "LibraryMonitor.c"
	}
}

gboolean
library_monitor_is_blacklisted (GFile* file)
{
	GError* _inner_error0_ = NULL;
	gboolean result;
#line 753 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()), FALSE);
#line 5488 "LibraryMonitor.c"
	{
		GeeHashSet* _tmp0_;
		gboolean _tmp4_ = FALSE;
#line 754 "../src/LibraryMonitor.vala"
		_tmp0_ = library_monitor_blacklist;
#line 754 "../src/LibraryMonitor.vala"
		g_rec_mutex_lock (&__lock_library_monitor_library_monitor_blacklist);
#line 5496 "LibraryMonitor.c"
		{
			GeeHashSet* _tmp1_;
#line 755 "../src/LibraryMonitor.vala"
			_tmp1_ = library_monitor_blacklist;
#line 755 "../src/LibraryMonitor.vala"
			result = gee_abstract_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), file);
#line 5503 "LibraryMonitor.c"
			{
				GeeHashSet* _tmp2_;
#line 754 "../src/LibraryMonitor.vala"
				_tmp2_ = library_monitor_blacklist;
#line 754 "../src/LibraryMonitor.vala"
				g_rec_mutex_unlock (&__lock_library_monitor_library_monitor_blacklist);
#line 5510 "LibraryMonitor.c"
			}
#line 755 "../src/LibraryMonitor.vala"
			return result;
#line 5514 "LibraryMonitor.c"
		}
		__finally0:
		{
			GeeHashSet* _tmp3_;
#line 754 "../src/LibraryMonitor.vala"
			_tmp3_ = library_monitor_blacklist;
#line 754 "../src/LibraryMonitor.vala"
			g_rec_mutex_unlock (&__lock_library_monitor_library_monitor_blacklist);
#line 5523 "LibraryMonitor.c"
		}
#line 754 "../src/LibraryMonitor.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 754 "../src/LibraryMonitor.vala"
		g_clear_error (&_inner_error0_);
#line 754 "../src/LibraryMonitor.vala"
		return _tmp4_;
#line 5531 "LibraryMonitor.c"
	}
}

static gboolean
library_monitor_is_supported_filetype (LibraryMonitor* self,
                                       GFile* file)
{
	MediaCollectionRegistry* _tmp0_;
	MediaCollectionRegistry* _tmp1_;
	MediaSourceCollection* _tmp2_;
	MediaSourceCollection* _tmp3_;
	gboolean _tmp4_;
	gboolean result;
#line 759 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (IS_LIBRARY_MONITOR (self), FALSE);
#line 759 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()), FALSE);
#line 760 "../src/LibraryMonitor.vala"
	_tmp0_ = media_collection_registry_get_instance ();
#line 760 "../src/LibraryMonitor.vala"
	_tmp1_ = _tmp0_;
#line 760 "../src/LibraryMonitor.vala"
	_tmp2_ = media_collection_registry_get_collection_for_file (_tmp1_, file);
#line 760 "../src/LibraryMonitor.vala"
	_tmp3_ = _tmp2_;
#line 760 "../src/LibraryMonitor.vala"
	_tmp4_ = _tmp3_ != NULL;
#line 760 "../src/LibraryMonitor.vala"
	_data_collection_unref0 (_tmp3_);
#line 760 "../src/LibraryMonitor.vala"
	_media_collection_registry_unref0 (_tmp1_);
#line 760 "../src/LibraryMonitor.vala"
	result = _tmp4_;
#line 760 "../src/LibraryMonitor.vala"
	return result;
#line 5567 "LibraryMonitor.c"
}

static void
library_monitor_import_unrepresented_files (LibraryMonitor* self)
{
	GeeArrayList* to_import = NULL;
	GeeArrayList* _tmp31_;
#line 765 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 766 "../src/LibraryMonitor.vala"
	if (!self->priv->auto_import) {
#line 767 "../src/LibraryMonitor.vala"
		return;
#line 5581 "LibraryMonitor.c"
	}
#line 769 "../src/LibraryMonitor.vala"
	to_import = NULL;
#line 5585 "LibraryMonitor.c"
	{
		GeeIterator* _file_it = NULL;
		GeeCollection* _tmp0_;
		GeeCollection* _tmp1_;
		GeeIterator* _tmp2_;
		GeeIterator* _tmp3_;
#line 770 "../src/LibraryMonitor.vala"
		_tmp0_ = directory_monitor_get_files (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor));
#line 770 "../src/LibraryMonitor.vala"
		_tmp1_ = _tmp0_;
#line 770 "../src/LibraryMonitor.vala"
		_tmp2_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_ITERABLE, GeeIterable));
#line 770 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 770 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_tmp1_);
#line 770 "../src/LibraryMonitor.vala"
		_file_it = _tmp3_;
#line 770 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 5606 "LibraryMonitor.c"
			GeeIterator* _tmp4_;
			GFile* file = NULL;
			GeeIterator* _tmp5_;
			gpointer _tmp6_;
			GFileInfo* info = NULL;
			GFile* _tmp7_;
			GFileInfo* _tmp8_;
			gboolean _tmp9_ = FALSE;
			GFileInfo* _tmp10_;
			GeeHashSet* _tmp12_;
			GFile* _tmp13_;
			TombstoneSourceCollection* _tmp14_;
			GFile* _tmp15_;
			gboolean represented = FALSE;
			GFile* _tmp26_;
			GeeArrayList* _tmp27_;
			GeeArrayList* _tmp29_;
			GFile* _tmp30_;
#line 770 "../src/LibraryMonitor.vala"
			_tmp4_ = _file_it;
#line 770 "../src/LibraryMonitor.vala"
			if (!gee_iterator_next (_tmp4_)) {
#line 770 "../src/LibraryMonitor.vala"
				break;
#line 5631 "LibraryMonitor.c"
			}
#line 770 "../src/LibraryMonitor.vala"
			_tmp5_ = _file_it;
#line 770 "../src/LibraryMonitor.vala"
			_tmp6_ = gee_iterator_get (_tmp5_);
#line 770 "../src/LibraryMonitor.vala"
			file = (GFile*) _tmp6_;
#line 771 "../src/LibraryMonitor.vala"
			_tmp7_ = file;
#line 771 "../src/LibraryMonitor.vala"
			_tmp8_ = directory_monitor_get_file_info (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), _tmp7_);
#line 771 "../src/LibraryMonitor.vala"
			info = _tmp8_;
#line 772 "../src/LibraryMonitor.vala"
			_tmp10_ = info;
#line 772 "../src/LibraryMonitor.vala"
			if (_tmp10_ == NULL) {
#line 772 "../src/LibraryMonitor.vala"
				_tmp9_ = TRUE;
#line 5651 "LibraryMonitor.c"
			} else {
				GFileInfo* _tmp11_;
#line 772 "../src/LibraryMonitor.vala"
				_tmp11_ = info;
#line 772 "../src/LibraryMonitor.vala"
				_tmp9_ = g_file_info_get_file_type (_tmp11_) != G_FILE_TYPE_REGULAR;
#line 5658 "LibraryMonitor.c"
			}
#line 772 "../src/LibraryMonitor.vala"
			if (_tmp9_) {
#line 773 "../src/LibraryMonitor.vala"
				_g_object_unref0 (info);
#line 773 "../src/LibraryMonitor.vala"
				_g_object_unref0 (file);
#line 773 "../src/LibraryMonitor.vala"
				continue;
#line 5668 "LibraryMonitor.c"
			}
#line 775 "../src/LibraryMonitor.vala"
			_tmp12_ = self->priv->pending_imports;
#line 775 "../src/LibraryMonitor.vala"
			_tmp13_ = file;
#line 775 "../src/LibraryMonitor.vala"
			if (gee_abstract_collection_contains (G_TYPE_CHECK_INSTANCE_CAST (_tmp12_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp13_)) {
#line 776 "../src/LibraryMonitor.vala"
				_g_object_unref0 (info);
#line 776 "../src/LibraryMonitor.vala"
				_g_object_unref0 (file);
#line 776 "../src/LibraryMonitor.vala"
				continue;
#line 5682 "LibraryMonitor.c"
			}
#line 778 "../src/LibraryMonitor.vala"
			_tmp14_ = tombstone_global;
#line 778 "../src/LibraryMonitor.vala"
			_tmp15_ = file;
#line 778 "../src/LibraryMonitor.vala"
			if (tombstone_source_collection_matches (_tmp14_, _tmp15_)) {
#line 779 "../src/LibraryMonitor.vala"
				_g_object_unref0 (info);
#line 779 "../src/LibraryMonitor.vala"
				_g_object_unref0 (file);
#line 779 "../src/LibraryMonitor.vala"
				continue;
#line 5696 "LibraryMonitor.c"
			}
#line 781 "../src/LibraryMonitor.vala"
			represented = FALSE;
#line 5700 "LibraryMonitor.c"
			{
				GeeList* _monitor_list = NULL;
				GeeList* _tmp16_;
				gint _monitor_size = 0;
				GeeList* _tmp17_;
				gint _tmp18_;
				gint _tmp19_;
				gint _monitor_index = 0;
#line 782 "../src/LibraryMonitor.vala"
				_tmp16_ = self->priv->monitors;
#line 782 "../src/LibraryMonitor.vala"
				_monitor_list = _tmp16_;
#line 782 "../src/LibraryMonitor.vala"
				_tmp17_ = _monitor_list;
#line 782 "../src/LibraryMonitor.vala"
				_tmp18_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp17_, GEE_TYPE_COLLECTION, GeeCollection));
#line 782 "../src/LibraryMonitor.vala"
				_tmp19_ = _tmp18_;
#line 782 "../src/LibraryMonitor.vala"
				_monitor_size = _tmp19_;
#line 782 "../src/LibraryMonitor.vala"
				_monitor_index = -1;
#line 782 "../src/LibraryMonitor.vala"
				while (TRUE) {
#line 5725 "LibraryMonitor.c"
					gint _tmp20_;
					gint _tmp21_;
					MediaMonitor* monitor = NULL;
					GeeList* _tmp22_;
					gpointer _tmp23_;
					MediaMonitor* _tmp24_;
					GFile* _tmp25_;
#line 782 "../src/LibraryMonitor.vala"
					_monitor_index = _monitor_index + 1;
#line 782 "../src/LibraryMonitor.vala"
					_tmp20_ = _monitor_index;
#line 782 "../src/LibraryMonitor.vala"
					_tmp21_ = _monitor_size;
#line 782 "../src/LibraryMonitor.vala"
					if (!(_tmp20_ < _tmp21_)) {
#line 782 "../src/LibraryMonitor.vala"
						break;
#line 5743 "LibraryMonitor.c"
					}
#line 782 "../src/LibraryMonitor.vala"
					_tmp22_ = _monitor_list;
#line 782 "../src/LibraryMonitor.vala"
					_tmp23_ = gee_list_get (_tmp22_, _monitor_index);
#line 782 "../src/LibraryMonitor.vala"
					monitor = (MediaMonitor*) _tmp23_;
#line 783 "../src/LibraryMonitor.vala"
					_tmp24_ = monitor;
#line 783 "../src/LibraryMonitor.vala"
					_tmp25_ = file;
#line 783 "../src/LibraryMonitor.vala"
					if (media_monitor_is_file_represented (_tmp24_, _tmp25_)) {
#line 784 "../src/LibraryMonitor.vala"
						represented = TRUE;
#line 786 "../src/LibraryMonitor.vala"
						_g_object_unref0 (monitor);
#line 786 "../src/LibraryMonitor.vala"
						break;
#line 5763 "LibraryMonitor.c"
					}
#line 782 "../src/LibraryMonitor.vala"
					_g_object_unref0 (monitor);
#line 5767 "LibraryMonitor.c"
				}
			}
#line 790 "../src/LibraryMonitor.vala"
			if (represented) {
#line 791 "../src/LibraryMonitor.vala"
				_g_object_unref0 (info);
#line 791 "../src/LibraryMonitor.vala"
				_g_object_unref0 (file);
#line 791 "../src/LibraryMonitor.vala"
				continue;
#line 5778 "LibraryMonitor.c"
			}
#line 793 "../src/LibraryMonitor.vala"
			_tmp26_ = file;
#line 793 "../src/LibraryMonitor.vala"
			if (!library_monitor_is_supported_filetype (self, _tmp26_)) {
#line 794 "../src/LibraryMonitor.vala"
				_g_object_unref0 (info);
#line 794 "../src/LibraryMonitor.vala"
				_g_object_unref0 (file);
#line 794 "../src/LibraryMonitor.vala"
				continue;
#line 5790 "LibraryMonitor.c"
			}
#line 796 "../src/LibraryMonitor.vala"
			_tmp27_ = to_import;
#line 796 "../src/LibraryMonitor.vala"
			if (_tmp27_ == NULL) {
#line 5796 "LibraryMonitor.c"
				GeeArrayList* _tmp28_;
#line 797 "../src/LibraryMonitor.vala"
				_tmp28_ = gee_array_list_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _file_equal_gee_equal_data_func, NULL, NULL);
#line 797 "../src/LibraryMonitor.vala"
				_g_object_unref0 (to_import);
#line 797 "../src/LibraryMonitor.vala"
				to_import = _tmp28_;
#line 5804 "LibraryMonitor.c"
			}
#line 799 "../src/LibraryMonitor.vala"
			_tmp29_ = to_import;
#line 799 "../src/LibraryMonitor.vala"
			_tmp30_ = file;
#line 799 "../src/LibraryMonitor.vala"
			gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp29_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp30_);
#line 770 "../src/LibraryMonitor.vala"
			_g_object_unref0 (info);
#line 770 "../src/LibraryMonitor.vala"
			_g_object_unref0 (file);
#line 5816 "LibraryMonitor.c"
		}
#line 770 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_file_it);
#line 5820 "LibraryMonitor.c"
	}
#line 802 "../src/LibraryMonitor.vala"
	_tmp31_ = to_import;
#line 802 "../src/LibraryMonitor.vala"
	if (_tmp31_ != NULL) {
#line 5826 "LibraryMonitor.c"
		GeeArrayList* _tmp32_;
#line 803 "../src/LibraryMonitor.vala"
		_tmp32_ = to_import;
#line 803 "../src/LibraryMonitor.vala"
		library_monitor_enqueue_import_many (self, G_TYPE_CHECK_INSTANCE_CAST (_tmp32_, GEE_TYPE_COLLECTION, GeeCollection));
#line 5832 "LibraryMonitor.c"
	}
#line 765 "../src/LibraryMonitor.vala"
	_g_object_unref0 (to_import);
#line 5836 "LibraryMonitor.c"
}

static void
library_monitor_runtime_unknown_file_discovered (LibraryMonitor* self,
                                                 GFile* file)
{
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 808 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 808 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 809 "../src/LibraryMonitor.vala"
	if (self->priv->auto_import) {
#line 809 "../src/LibraryMonitor.vala"
		_tmp1_ = library_monitor_is_supported_filetype (self, file);
#line 5853 "LibraryMonitor.c"
	} else {
#line 809 "../src/LibraryMonitor.vala"
		_tmp1_ = FALSE;
#line 5857 "LibraryMonitor.c"
	}
#line 809 "../src/LibraryMonitor.vala"
	if (_tmp1_) {
#line 5861 "LibraryMonitor.c"
		TombstoneSourceCollection* _tmp2_;
#line 809 "../src/LibraryMonitor.vala"
		_tmp2_ = tombstone_global;
#line 809 "../src/LibraryMonitor.vala"
		_tmp0_ = !tombstone_source_collection_matches (_tmp2_, file);
#line 5867 "LibraryMonitor.c"
	} else {
#line 809 "../src/LibraryMonitor.vala"
		_tmp0_ = FALSE;
#line 5871 "LibraryMonitor.c"
	}
#line 809 "../src/LibraryMonitor.vala"
	if (_tmp0_) {
#line 5875 "LibraryMonitor.c"
		gchar* _tmp3_;
		gchar* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
#line 810 "../src/LibraryMonitor.vala"
		_tmp3_ = g_file_get_path (file);
#line 810 "../src/LibraryMonitor.vala"
		_tmp4_ = _tmp3_;
#line 810 "../src/LibraryMonitor.vala"
		_tmp5_ = g_strdup_printf ("Unknown file %s discovered, enqueuing for import", _tmp4_);
#line 810 "../src/LibraryMonitor.vala"
		_tmp6_ = _tmp5_;
#line 810 "../src/LibraryMonitor.vala"
		directory_monitor_mdbg (_tmp6_);
#line 810 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp6_);
#line 810 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp4_);
#line 811 "../src/LibraryMonitor.vala"
		library_monitor_enqueue_import (self, file);
#line 5896 "LibraryMonitor.c"
	}
}

static void
library_monitor_real_notify_file_created (DirectoryMonitor* base,
                                          GFile* file,
                                          GFileInfo* info)
{
	LibraryMonitor * self;
	gboolean known = FALSE;
#line 815 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_MONITOR, LibraryMonitor);
#line 815 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 815 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (info, g_file_info_get_type ()));
#line 816 "../src/LibraryMonitor.vala"
	if (library_monitor_is_blacklisted (file)) {
#line 817 "../src/LibraryMonitor.vala"
		DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_created (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), file, info);
#line 819 "../src/LibraryMonitor.vala"
		return;
#line 5919 "LibraryMonitor.c"
	}
#line 822 "../src/LibraryMonitor.vala"
	known = FALSE;
#line 5923 "LibraryMonitor.c"
	{
		GeeList* _monitor_list = NULL;
		GeeList* _tmp0_;
		gint _monitor_size = 0;
		GeeList* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		gint _monitor_index = 0;
#line 823 "../src/LibraryMonitor.vala"
		_tmp0_ = self->priv->monitors;
#line 823 "../src/LibraryMonitor.vala"
		_monitor_list = _tmp0_;
#line 823 "../src/LibraryMonitor.vala"
		_tmp1_ = _monitor_list;
#line 823 "../src/LibraryMonitor.vala"
		_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 823 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 823 "../src/LibraryMonitor.vala"
		_monitor_size = _tmp3_;
#line 823 "../src/LibraryMonitor.vala"
		_monitor_index = -1;
#line 823 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 5948 "LibraryMonitor.c"
			gint _tmp4_;
			gint _tmp5_;
			MediaMonitor* monitor = NULL;
			GeeList* _tmp6_;
			gpointer _tmp7_;
			MediaMonitor* _tmp8_;
#line 823 "../src/LibraryMonitor.vala"
			_monitor_index = _monitor_index + 1;
#line 823 "../src/LibraryMonitor.vala"
			_tmp4_ = _monitor_index;
#line 823 "../src/LibraryMonitor.vala"
			_tmp5_ = _monitor_size;
#line 823 "../src/LibraryMonitor.vala"
			if (!(_tmp4_ < _tmp5_)) {
#line 823 "../src/LibraryMonitor.vala"
				break;
#line 5965 "LibraryMonitor.c"
			}
#line 823 "../src/LibraryMonitor.vala"
			_tmp6_ = _monitor_list;
#line 823 "../src/LibraryMonitor.vala"
			_tmp7_ = gee_list_get (_tmp6_, _monitor_index);
#line 823 "../src/LibraryMonitor.vala"
			monitor = (MediaMonitor*) _tmp7_;
#line 824 "../src/LibraryMonitor.vala"
			_tmp8_ = monitor;
#line 824 "../src/LibraryMonitor.vala"
			if (media_monitor_notify_file_created (_tmp8_, file, info)) {
#line 825 "../src/LibraryMonitor.vala"
				known = TRUE;
#line 827 "../src/LibraryMonitor.vala"
				_g_object_unref0 (monitor);
#line 827 "../src/LibraryMonitor.vala"
				break;
#line 5983 "LibraryMonitor.c"
			}
#line 823 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitor);
#line 5987 "LibraryMonitor.c"
		}
	}
#line 831 "../src/LibraryMonitor.vala"
	if (!known) {
#line 5992 "LibraryMonitor.c"
		GeeHashSet* all_candidates = NULL;
		gboolean _tmp55_ = FALSE;
		gboolean _tmp56_ = FALSE;
#line 833 "../src/LibraryMonitor.vala"
		all_candidates = NULL;
#line 5998 "LibraryMonitor.c"
		{
			GeeList* _monitor_list = NULL;
			GeeList* _tmp9_;
			gint _monitor_size = 0;
			GeeList* _tmp10_;
			gint _tmp11_;
			gint _tmp12_;
			gint _monitor_index = 0;
#line 834 "../src/LibraryMonitor.vala"
			_tmp9_ = self->priv->monitors;
#line 834 "../src/LibraryMonitor.vala"
			_monitor_list = _tmp9_;
#line 834 "../src/LibraryMonitor.vala"
			_tmp10_ = _monitor_list;
#line 834 "../src/LibraryMonitor.vala"
			_tmp11_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GEE_TYPE_COLLECTION, GeeCollection));
#line 834 "../src/LibraryMonitor.vala"
			_tmp12_ = _tmp11_;
#line 834 "../src/LibraryMonitor.vala"
			_monitor_size = _tmp12_;
#line 834 "../src/LibraryMonitor.vala"
			_monitor_index = -1;
#line 834 "../src/LibraryMonitor.vala"
			while (TRUE) {
#line 6023 "LibraryMonitor.c"
				gint _tmp13_;
				gint _tmp14_;
				MediaMonitor* monitor = NULL;
				GeeList* _tmp15_;
				gpointer _tmp16_;
				MediaMonitorDiscoveredFile _result_ = 0;
				GeeCollection* candidates = NULL;
				MediaMonitor* _tmp17_;
				MediaMonitorDiscoveredFile _tmp18_ = 0;
				GeeCollection* _tmp19_;
				gboolean _tmp20_ = FALSE;
#line 834 "../src/LibraryMonitor.vala"
				_monitor_index = _monitor_index + 1;
#line 834 "../src/LibraryMonitor.vala"
				_tmp13_ = _monitor_index;
#line 834 "../src/LibraryMonitor.vala"
				_tmp14_ = _monitor_size;
#line 834 "../src/LibraryMonitor.vala"
				if (!(_tmp13_ < _tmp14_)) {
#line 834 "../src/LibraryMonitor.vala"
					break;
#line 6045 "LibraryMonitor.c"
				}
#line 834 "../src/LibraryMonitor.vala"
				_tmp15_ = _monitor_list;
#line 834 "../src/LibraryMonitor.vala"
				_tmp16_ = gee_list_get (_tmp15_, _monitor_index);
#line 834 "../src/LibraryMonitor.vala"
				monitor = (MediaMonitor*) _tmp16_;
#line 836 "../src/LibraryMonitor.vala"
				_tmp17_ = monitor;
#line 836 "../src/LibraryMonitor.vala"
				_tmp19_ = media_monitor_candidates_for_unknown_file (_tmp17_, file, info, &_tmp18_);
#line 836 "../src/LibraryMonitor.vala"
				_result_ = _tmp18_;
#line 836 "../src/LibraryMonitor.vala"
				candidates = _tmp19_;
#line 838 "../src/LibraryMonitor.vala"
				if (_result_ == MEDIA_MONITOR_DISCOVERED_FILE_REPRESENTED) {
#line 838 "../src/LibraryMonitor.vala"
					_tmp20_ = TRUE;
#line 6065 "LibraryMonitor.c"
				} else {
#line 839 "../src/LibraryMonitor.vala"
					_tmp20_ = _result_ == MEDIA_MONITOR_DISCOVERED_FILE_IGNORE;
#line 6069 "LibraryMonitor.c"
				}
#line 838 "../src/LibraryMonitor.vala"
				if (_tmp20_) {
#line 6073 "LibraryMonitor.c"
					MediaMonitor* _tmp21_;
					gchar* _tmp22_;
					gchar* _tmp23_;
					GEnumValue* _tmp24_;
					gchar* _tmp25_;
					gchar* _tmp26_;
					gchar* _tmp27_;
					gchar* _tmp28_;
#line 840 "../src/LibraryMonitor.vala"
					_tmp21_ = monitor;
#line 840 "../src/LibraryMonitor.vala"
					_tmp22_ = media_monitor_to_string (_tmp21_);
#line 840 "../src/LibraryMonitor.vala"
					_tmp23_ = _tmp22_;
#line 840 "../src/LibraryMonitor.vala"
					_tmp24_ = g_enum_get_value (g_type_class_ref (MEDIA_MONITOR_TYPE_DISCOVERED_FILE), _result_);
#line 840 "../src/LibraryMonitor.vala"
					_tmp25_ = g_file_get_path (file);
#line 840 "../src/LibraryMonitor.vala"
					_tmp26_ = _tmp25_;
#line 840 "../src/LibraryMonitor.vala"
					_tmp27_ = g_strdup_printf ("%s %s created file %s", _tmp23_, (_tmp24_ != NULL) ? _tmp24_->value_name : NULL, _tmp26_);
#line 840 "../src/LibraryMonitor.vala"
					_tmp28_ = _tmp27_;
#line 840 "../src/LibraryMonitor.vala"
					directory_monitor_mdbg (_tmp28_);
#line 840 "../src/LibraryMonitor.vala"
					_g_free0 (_tmp28_);
#line 840 "../src/LibraryMonitor.vala"
					_g_free0 (_tmp26_);
#line 840 "../src/LibraryMonitor.vala"
					_g_free0 (_tmp23_);
#line 843 "../src/LibraryMonitor.vala"
					known = TRUE;
#line 845 "../src/LibraryMonitor.vala"
					_g_object_unref0 (candidates);
#line 845 "../src/LibraryMonitor.vala"
					_g_object_unref0 (monitor);
#line 845 "../src/LibraryMonitor.vala"
					break;
#line 6114 "LibraryMonitor.c"
				} else {
					gboolean _tmp29_ = FALSE;
					GeeCollection* _tmp30_;
#line 846 "../src/LibraryMonitor.vala"
					_tmp30_ = candidates;
#line 846 "../src/LibraryMonitor.vala"
					if (_tmp30_ != NULL) {
#line 6122 "LibraryMonitor.c"
						GeeCollection* _tmp31_;
						gint _tmp32_;
						gint _tmp33_;
#line 846 "../src/LibraryMonitor.vala"
						_tmp31_ = candidates;
#line 846 "../src/LibraryMonitor.vala"
						_tmp32_ = gee_collection_get_size (_tmp31_);
#line 846 "../src/LibraryMonitor.vala"
						_tmp33_ = _tmp32_;
#line 846 "../src/LibraryMonitor.vala"
						_tmp29_ = _tmp33_ > 0;
#line 6134 "LibraryMonitor.c"
					} else {
#line 846 "../src/LibraryMonitor.vala"
						_tmp29_ = FALSE;
#line 6138 "LibraryMonitor.c"
					}
#line 846 "../src/LibraryMonitor.vala"
					if (_tmp29_) {
#line 6142 "LibraryMonitor.c"
						MediaMonitor* _tmp34_;
						gchar* _tmp35_;
						gchar* _tmp36_;
						GeeCollection* _tmp37_;
						gint _tmp38_;
						gint _tmp39_;
						gchar* _tmp40_;
						gchar* _tmp41_;
						gchar* _tmp42_;
						gchar* _tmp43_;
						GeeHashSet* _tmp44_;
#line 847 "../src/LibraryMonitor.vala"
						_tmp34_ = monitor;
#line 847 "../src/LibraryMonitor.vala"
						_tmp35_ = media_monitor_to_string (_tmp34_);
#line 847 "../src/LibraryMonitor.vala"
						_tmp36_ = _tmp35_;
#line 847 "../src/LibraryMonitor.vala"
						_tmp37_ = candidates;
#line 847 "../src/LibraryMonitor.vala"
						_tmp38_ = gee_collection_get_size (_tmp37_);
#line 847 "../src/LibraryMonitor.vala"
						_tmp39_ = _tmp38_;
#line 847 "../src/LibraryMonitor.vala"
						_tmp40_ = g_file_get_path (file);
#line 847 "../src/LibraryMonitor.vala"
						_tmp41_ = _tmp40_;
#line 847 "../src/LibraryMonitor.vala"
						_tmp42_ = g_strdup_printf ("%s suggests %d candidates for created file %s", _tmp36_, _tmp39_, _tmp41_);
#line 847 "../src/LibraryMonitor.vala"
						_tmp43_ = _tmp42_;
#line 847 "../src/LibraryMonitor.vala"
						directory_monitor_mdbg (_tmp43_);
#line 847 "../src/LibraryMonitor.vala"
						_g_free0 (_tmp43_);
#line 847 "../src/LibraryMonitor.vala"
						_g_free0 (_tmp41_);
#line 847 "../src/LibraryMonitor.vala"
						_g_free0 (_tmp36_);
#line 850 "../src/LibraryMonitor.vala"
						_tmp44_ = all_candidates;
#line 850 "../src/LibraryMonitor.vala"
						if (_tmp44_ == NULL) {
#line 6186 "LibraryMonitor.c"
							GeeHashSet* _tmp45_;
#line 851 "../src/LibraryMonitor.vala"
							_tmp45_ = gee_hash_set_new (TYPE_MONITORABLE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL, NULL, NULL, NULL);
#line 851 "../src/LibraryMonitor.vala"
							_g_object_unref0 (all_candidates);
#line 851 "../src/LibraryMonitor.vala"
							all_candidates = _tmp45_;
#line 6194 "LibraryMonitor.c"
						}
						{
							GeeIterator* _candidate_it = NULL;
							GeeCollection* _tmp46_;
							GeeIterator* _tmp47_;
#line 853 "../src/LibraryMonitor.vala"
							_tmp46_ = candidates;
#line 853 "../src/LibraryMonitor.vala"
							_tmp47_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, GEE_TYPE_ITERABLE, GeeIterable));
#line 853 "../src/LibraryMonitor.vala"
							_candidate_it = _tmp47_;
#line 853 "../src/LibraryMonitor.vala"
							while (TRUE) {
#line 6208 "LibraryMonitor.c"
								GeeIterator* _tmp48_;
								Monitorable* candidate = NULL;
								GeeIterator* _tmp49_;
								gpointer _tmp50_;
								MediaMonitor* _tmp51_;
								Monitorable* _tmp52_;
#line 853 "../src/LibraryMonitor.vala"
								_tmp48_ = _candidate_it;
#line 853 "../src/LibraryMonitor.vala"
								if (!gee_iterator_next (_tmp48_)) {
#line 853 "../src/LibraryMonitor.vala"
									break;
#line 6221 "LibraryMonitor.c"
								}
#line 853 "../src/LibraryMonitor.vala"
								_tmp49_ = _candidate_it;
#line 853 "../src/LibraryMonitor.vala"
								_tmp50_ = gee_iterator_get (_tmp49_);
#line 853 "../src/LibraryMonitor.vala"
								candidate = (Monitorable*) _tmp50_;
#line 854 "../src/LibraryMonitor.vala"
								_tmp51_ = monitor;
#line 854 "../src/LibraryMonitor.vala"
								_tmp52_ = candidate;
#line 854 "../src/LibraryMonitor.vala"
								if (media_monitor_is_offline (_tmp51_, _tmp52_)) {
#line 6235 "LibraryMonitor.c"
									GeeHashSet* _tmp53_;
									Monitorable* _tmp54_;
#line 855 "../src/LibraryMonitor.vala"
									_tmp53_ = all_candidates;
#line 855 "../src/LibraryMonitor.vala"
									_tmp54_ = candidate;
#line 855 "../src/LibraryMonitor.vala"
									gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp53_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp54_);
#line 6244 "LibraryMonitor.c"
								}
#line 853 "../src/LibraryMonitor.vala"
								_g_object_unref0 (candidate);
#line 6248 "LibraryMonitor.c"
							}
#line 853 "../src/LibraryMonitor.vala"
							_g_object_unref0 (_candidate_it);
#line 6252 "LibraryMonitor.c"
						}
					}
				}
#line 834 "../src/LibraryMonitor.vala"
				_g_object_unref0 (candidates);
#line 834 "../src/LibraryMonitor.vala"
				_g_object_unref0 (monitor);
#line 6260 "LibraryMonitor.c"
			}
		}
#line 860 "../src/LibraryMonitor.vala"
		if (!known) {
#line 6265 "LibraryMonitor.c"
			GeeHashSet* _tmp57_;
#line 860 "../src/LibraryMonitor.vala"
			_tmp57_ = all_candidates;
#line 860 "../src/LibraryMonitor.vala"
			_tmp56_ = _tmp57_ != NULL;
#line 6271 "LibraryMonitor.c"
		} else {
#line 860 "../src/LibraryMonitor.vala"
			_tmp56_ = FALSE;
#line 6275 "LibraryMonitor.c"
		}
#line 860 "../src/LibraryMonitor.vala"
		if (_tmp56_) {
#line 6279 "LibraryMonitor.c"
			GeeHashSet* _tmp58_;
			gint _tmp59_;
			gint _tmp60_;
#line 860 "../src/LibraryMonitor.vala"
			_tmp58_ = all_candidates;
#line 860 "../src/LibraryMonitor.vala"
			_tmp59_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp58_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 860 "../src/LibraryMonitor.vala"
			_tmp60_ = _tmp59_;
#line 860 "../src/LibraryMonitor.vala"
			_tmp55_ = _tmp60_ > 0;
#line 6291 "LibraryMonitor.c"
		} else {
#line 860 "../src/LibraryMonitor.vala"
			_tmp55_ = FALSE;
#line 6295 "LibraryMonitor.c"
		}
#line 860 "../src/LibraryMonitor.vala"
		if (_tmp55_) {
#line 6299 "LibraryMonitor.c"
			GeeHashSet* _tmp61_;
			gint _tmp62_;
			gint _tmp63_;
			gchar* _tmp64_;
			gchar* _tmp65_;
			gchar* _tmp66_;
			gchar* _tmp67_;
			Workers* _tmp68_;
			GeeHashSet* _tmp69_;
			LibraryMonitorRuntimeFindMoveJob* _tmp70_;
			LibraryMonitorRuntimeFindMoveJob* _tmp71_;
#line 861 "../src/LibraryMonitor.vala"
			_tmp61_ = all_candidates;
#line 861 "../src/LibraryMonitor.vala"
			_tmp62_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp61_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 861 "../src/LibraryMonitor.vala"
			_tmp63_ = _tmp62_;
#line 861 "../src/LibraryMonitor.vala"
			_tmp64_ = g_file_get_path (file);
#line 861 "../src/LibraryMonitor.vala"
			_tmp65_ = _tmp64_;
#line 861 "../src/LibraryMonitor.vala"
			_tmp66_ = g_strdup_printf ("%d candidates for created file %s being checksummed", _tmp63_, _tmp65_);
#line 861 "../src/LibraryMonitor.vala"
			_tmp67_ = _tmp66_;
#line 861 "../src/LibraryMonitor.vala"
			directory_monitor_mdbg (_tmp67_);
#line 861 "../src/LibraryMonitor.vala"
			_g_free0 (_tmp67_);
#line 861 "../src/LibraryMonitor.vala"
			_g_free0 (_tmp65_);
#line 864 "../src/LibraryMonitor.vala"
			_tmp68_ = self->priv->workers;
#line 864 "../src/LibraryMonitor.vala"
			_tmp69_ = all_candidates;
#line 864 "../src/LibraryMonitor.vala"
			_tmp70_ = library_monitor_runtime_find_move_job_new (self, file, G_TYPE_CHECK_INSTANCE_CAST (_tmp69_, GEE_TYPE_COLLECTION, GeeCollection));
#line 864 "../src/LibraryMonitor.vala"
			_tmp71_ = _tmp70_;
#line 864 "../src/LibraryMonitor.vala"
			workers_enqueue (_tmp68_, G_TYPE_CHECK_INSTANCE_CAST (_tmp71_, TYPE_BACKGROUND_JOB, BackgroundJob));
#line 864 "../src/LibraryMonitor.vala"
			_background_job_unref0 (_tmp71_);
#line 866 "../src/LibraryMonitor.vala"
			known = TRUE;
#line 6345 "LibraryMonitor.c"
		}
#line 831 "../src/LibraryMonitor.vala"
		_g_object_unref0 (all_candidates);
#line 6349 "LibraryMonitor.c"
	}
#line 870 "../src/LibraryMonitor.vala"
	if (!known) {
#line 871 "../src/LibraryMonitor.vala"
		library_monitor_runtime_unknown_file_discovered (self, file);
#line 6355 "LibraryMonitor.c"
	}
#line 873 "../src/LibraryMonitor.vala"
	DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_created (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), file, info);
#line 6359 "LibraryMonitor.c"
}

static void
library_monitor_on_runtime_find_move_completed (LibraryMonitor* self,
                                                BackgroundJob* j)
{
	LibraryMonitorRuntimeFindMoveJob* job = NULL;
	LibraryMonitorRuntimeFindMoveJob* _tmp0_;
	LibraryMonitorRuntimeFindMoveJob* _tmp1_;
	GError* _tmp2_;
	LibraryMonitorRuntimeFindMoveJob* _tmp10_;
	Monitorable* _tmp11_;
#line 876 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_LIBRARY_MONITOR (self));
#line 876 "../src/LibraryMonitor.vala"
	g_return_if_fail (IS_BACKGROUND_JOB (j));
#line 877 "../src/LibraryMonitor.vala"
	_tmp0_ = _background_job_ref0 (G_TYPE_CHECK_INSTANCE_CAST (j, LIBRARY_MONITOR_TYPE_RUNTIME_FIND_MOVE_JOB, LibraryMonitorRuntimeFindMoveJob));
#line 877 "../src/LibraryMonitor.vala"
	job = _tmp0_;
#line 879 "../src/LibraryMonitor.vala"
	_tmp1_ = job;
#line 879 "../src/LibraryMonitor.vala"
	_tmp2_ = _tmp1_->err;
#line 879 "../src/LibraryMonitor.vala"
	if (_tmp2_ != NULL) {
#line 6386 "LibraryMonitor.c"
		LibraryMonitorRuntimeFindMoveJob* _tmp3_;
		GFile* _tmp4_;
		gchar* _tmp5_;
		gchar* _tmp6_;
		LibraryMonitorRuntimeFindMoveJob* _tmp7_;
		GError* _tmp8_;
		const gchar* _tmp9_;
#line 880 "../src/LibraryMonitor.vala"
		_tmp3_ = job;
#line 880 "../src/LibraryMonitor.vala"
		_tmp4_ = _tmp3_->file;
#line 880 "../src/LibraryMonitor.vala"
		_tmp5_ = g_file_get_path (_tmp4_);
#line 880 "../src/LibraryMonitor.vala"
		_tmp6_ = _tmp5_;
#line 880 "../src/LibraryMonitor.vala"
		_tmp7_ = job;
#line 880 "../src/LibraryMonitor.vala"
		_tmp8_ = _tmp7_->err;
#line 880 "../src/LibraryMonitor.vala"
		_tmp9_ = _tmp8_->message;
#line 880 "../src/LibraryMonitor.vala"
		g_critical ("LibraryMonitor.vala:880: Error attempting to find a match at runtime f" \
"or %s: %s", _tmp6_, _tmp9_);
#line 880 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp6_);
#line 6412 "LibraryMonitor.c"
	}
#line 884 "../src/LibraryMonitor.vala"
	_tmp10_ = job;
#line 884 "../src/LibraryMonitor.vala"
	_tmp11_ = _tmp10_->match;
#line 884 "../src/LibraryMonitor.vala"
	if (_tmp11_ != NULL) {
#line 6420 "LibraryMonitor.c"
		MediaMonitor* monitor = NULL;
		LibraryMonitorRuntimeFindMoveJob* _tmp12_;
		Monitorable* _tmp13_;
		MediaMonitor* _tmp14_;
		MediaMonitor* _tmp15_;
		LibraryMonitorRuntimeFindMoveJob* _tmp16_;
		Monitorable* _tmp17_;
		LibraryMonitorRuntimeFindMoveJob* _tmp18_;
		GFile* _tmp19_;
		MediaMonitor* _tmp20_;
		LibraryMonitorRuntimeFindMoveJob* _tmp21_;
		Monitorable* _tmp22_;
#line 885 "../src/LibraryMonitor.vala"
		_tmp12_ = job;
#line 885 "../src/LibraryMonitor.vala"
		_tmp13_ = _tmp12_->match;
#line 885 "../src/LibraryMonitor.vala"
		_tmp14_ = library_monitor_get_monitor_for_monitorable (self, _tmp13_);
#line 885 "../src/LibraryMonitor.vala"
		monitor = _tmp14_;
#line 886 "../src/LibraryMonitor.vala"
		_tmp15_ = monitor;
#line 886 "../src/LibraryMonitor.vala"
		_tmp16_ = job;
#line 886 "../src/LibraryMonitor.vala"
		_tmp17_ = _tmp16_->match;
#line 886 "../src/LibraryMonitor.vala"
		_tmp18_ = job;
#line 886 "../src/LibraryMonitor.vala"
		_tmp19_ = _tmp18_->file;
#line 886 "../src/LibraryMonitor.vala"
		media_monitor_update_master_file (_tmp15_, _tmp17_, _tmp19_);
#line 887 "../src/LibraryMonitor.vala"
		_tmp20_ = monitor;
#line 887 "../src/LibraryMonitor.vala"
		_tmp21_ = job;
#line 887 "../src/LibraryMonitor.vala"
		_tmp22_ = _tmp21_->match;
#line 887 "../src/LibraryMonitor.vala"
		media_monitor_update_online (_tmp20_, _tmp22_);
#line 884 "../src/LibraryMonitor.vala"
		_g_object_unref0 (monitor);
#line 6463 "LibraryMonitor.c"
	} else {
		LibraryMonitorRuntimeFindMoveJob* _tmp23_;
		GFile* _tmp24_;
#line 890 "../src/LibraryMonitor.vala"
		_tmp23_ = job;
#line 890 "../src/LibraryMonitor.vala"
		_tmp24_ = _tmp23_->file;
#line 890 "../src/LibraryMonitor.vala"
		library_monitor_runtime_unknown_file_discovered (self, _tmp24_);
#line 6473 "LibraryMonitor.c"
	}
#line 876 "../src/LibraryMonitor.vala"
	_background_job_unref0 (job);
#line 6477 "LibraryMonitor.c"
}

static void
library_monitor_real_notify_file_moved (DirectoryMonitor* base,
                                        GFile* old_file,
                                        GFile* new_file,
                                        GFileInfo* new_info)
{
	LibraryMonitor * self;
	gboolean _tmp0_ = FALSE;
	gboolean known = FALSE;
#line 894 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_MONITOR, LibraryMonitor);
#line 894 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (old_file, g_file_get_type ()));
#line 894 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (new_file, g_file_get_type ()));
#line 894 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (new_info, g_file_info_get_type ()));
#line 895 "../src/LibraryMonitor.vala"
	if (library_monitor_is_blacklisted (old_file)) {
#line 895 "../src/LibraryMonitor.vala"
		_tmp0_ = TRUE;
#line 6501 "LibraryMonitor.c"
	} else {
#line 895 "../src/LibraryMonitor.vala"
		_tmp0_ = library_monitor_is_blacklisted (new_file);
#line 6505 "LibraryMonitor.c"
	}
#line 895 "../src/LibraryMonitor.vala"
	if (_tmp0_) {
#line 896 "../src/LibraryMonitor.vala"
		DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_moved (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), old_file, new_file, new_info);
#line 898 "../src/LibraryMonitor.vala"
		return;
#line 6513 "LibraryMonitor.c"
	}
#line 901 "../src/LibraryMonitor.vala"
	known = FALSE;
#line 6517 "LibraryMonitor.c"
	{
		GeeList* _monitor_list = NULL;
		GeeList* _tmp1_;
		gint _monitor_size = 0;
		GeeList* _tmp2_;
		gint _tmp3_;
		gint _tmp4_;
		gint _monitor_index = 0;
#line 902 "../src/LibraryMonitor.vala"
		_tmp1_ = self->priv->monitors;
#line 902 "../src/LibraryMonitor.vala"
		_monitor_list = _tmp1_;
#line 902 "../src/LibraryMonitor.vala"
		_tmp2_ = _monitor_list;
#line 902 "../src/LibraryMonitor.vala"
		_tmp3_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_COLLECTION, GeeCollection));
#line 902 "../src/LibraryMonitor.vala"
		_tmp4_ = _tmp3_;
#line 902 "../src/LibraryMonitor.vala"
		_monitor_size = _tmp4_;
#line 902 "../src/LibraryMonitor.vala"
		_monitor_index = -1;
#line 902 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 6542 "LibraryMonitor.c"
			gint _tmp5_;
			gint _tmp6_;
			MediaMonitor* monitor = NULL;
			GeeList* _tmp7_;
			gpointer _tmp8_;
			MediaMonitor* _tmp9_;
#line 902 "../src/LibraryMonitor.vala"
			_monitor_index = _monitor_index + 1;
#line 902 "../src/LibraryMonitor.vala"
			_tmp5_ = _monitor_index;
#line 902 "../src/LibraryMonitor.vala"
			_tmp6_ = _monitor_size;
#line 902 "../src/LibraryMonitor.vala"
			if (!(_tmp5_ < _tmp6_)) {
#line 902 "../src/LibraryMonitor.vala"
				break;
#line 6559 "LibraryMonitor.c"
			}
#line 902 "../src/LibraryMonitor.vala"
			_tmp7_ = _monitor_list;
#line 902 "../src/LibraryMonitor.vala"
			_tmp8_ = gee_list_get (_tmp7_, _monitor_index);
#line 902 "../src/LibraryMonitor.vala"
			monitor = (MediaMonitor*) _tmp8_;
#line 903 "../src/LibraryMonitor.vala"
			_tmp9_ = monitor;
#line 903 "../src/LibraryMonitor.vala"
			if (media_monitor_notify_file_moved (_tmp9_, old_file, new_file, new_info)) {
#line 904 "../src/LibraryMonitor.vala"
				known = TRUE;
#line 906 "../src/LibraryMonitor.vala"
				_g_object_unref0 (monitor);
#line 906 "../src/LibraryMonitor.vala"
				break;
#line 6577 "LibraryMonitor.c"
			}
#line 902 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitor);
#line 6581 "LibraryMonitor.c"
		}
	}
#line 910 "../src/LibraryMonitor.vala"
	if (!known) {
#line 911 "../src/LibraryMonitor.vala"
		library_monitor_runtime_unknown_file_discovered (self, new_file);
#line 6588 "LibraryMonitor.c"
	}
#line 913 "../src/LibraryMonitor.vala"
	DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_moved (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), old_file, new_file, new_info);
#line 6592 "LibraryMonitor.c"
}

static void
library_monitor_real_notify_file_altered (DirectoryMonitor* base,
                                          GFile* file)
{
	LibraryMonitor * self;
	gboolean known = FALSE;
#line 916 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_MONITOR, LibraryMonitor);
#line 916 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 917 "../src/LibraryMonitor.vala"
	if (library_monitor_is_blacklisted (file)) {
#line 918 "../src/LibraryMonitor.vala"
		DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), file);
#line 920 "../src/LibraryMonitor.vala"
		return;
#line 6611 "LibraryMonitor.c"
	}
#line 923 "../src/LibraryMonitor.vala"
	known = FALSE;
#line 6615 "LibraryMonitor.c"
	{
		GeeList* _monitor_list = NULL;
		GeeList* _tmp0_;
		gint _monitor_size = 0;
		GeeList* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		gint _monitor_index = 0;
#line 924 "../src/LibraryMonitor.vala"
		_tmp0_ = self->priv->monitors;
#line 924 "../src/LibraryMonitor.vala"
		_monitor_list = _tmp0_;
#line 924 "../src/LibraryMonitor.vala"
		_tmp1_ = _monitor_list;
#line 924 "../src/LibraryMonitor.vala"
		_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 924 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 924 "../src/LibraryMonitor.vala"
		_monitor_size = _tmp3_;
#line 924 "../src/LibraryMonitor.vala"
		_monitor_index = -1;
#line 924 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 6640 "LibraryMonitor.c"
			gint _tmp4_;
			gint _tmp5_;
			MediaMonitor* monitor = NULL;
			GeeList* _tmp6_;
			gpointer _tmp7_;
			MediaMonitor* _tmp8_;
#line 924 "../src/LibraryMonitor.vala"
			_monitor_index = _monitor_index + 1;
#line 924 "../src/LibraryMonitor.vala"
			_tmp4_ = _monitor_index;
#line 924 "../src/LibraryMonitor.vala"
			_tmp5_ = _monitor_size;
#line 924 "../src/LibraryMonitor.vala"
			if (!(_tmp4_ < _tmp5_)) {
#line 924 "../src/LibraryMonitor.vala"
				break;
#line 6657 "LibraryMonitor.c"
			}
#line 924 "../src/LibraryMonitor.vala"
			_tmp6_ = _monitor_list;
#line 924 "../src/LibraryMonitor.vala"
			_tmp7_ = gee_list_get (_tmp6_, _monitor_index);
#line 924 "../src/LibraryMonitor.vala"
			monitor = (MediaMonitor*) _tmp7_;
#line 925 "../src/LibraryMonitor.vala"
			_tmp8_ = monitor;
#line 925 "../src/LibraryMonitor.vala"
			if (media_monitor_notify_file_altered (_tmp8_, file)) {
#line 926 "../src/LibraryMonitor.vala"
				known = TRUE;
#line 928 "../src/LibraryMonitor.vala"
				_g_object_unref0 (monitor);
#line 928 "../src/LibraryMonitor.vala"
				break;
#line 6675 "LibraryMonitor.c"
			}
#line 924 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitor);
#line 6679 "LibraryMonitor.c"
		}
	}
#line 932 "../src/LibraryMonitor.vala"
	if (!known) {
#line 933 "../src/LibraryMonitor.vala"
		library_monitor_runtime_unknown_file_discovered (self, file);
#line 6686 "LibraryMonitor.c"
	}
#line 935 "../src/LibraryMonitor.vala"
	DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), file);
#line 6690 "LibraryMonitor.c"
}

static void
library_monitor_real_notify_file_attributes_altered (DirectoryMonitor* base,
                                                     GFile* file)
{
	LibraryMonitor * self;
	gboolean known = FALSE;
#line 938 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_MONITOR, LibraryMonitor);
#line 938 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 939 "../src/LibraryMonitor.vala"
	if (library_monitor_is_blacklisted (file)) {
#line 940 "../src/LibraryMonitor.vala"
		DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_attributes_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), file);
#line 942 "../src/LibraryMonitor.vala"
		return;
#line 6709 "LibraryMonitor.c"
	}
#line 945 "../src/LibraryMonitor.vala"
	known = FALSE;
#line 6713 "LibraryMonitor.c"
	{
		GeeList* _monitor_list = NULL;
		GeeList* _tmp0_;
		gint _monitor_size = 0;
		GeeList* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		gint _monitor_index = 0;
#line 946 "../src/LibraryMonitor.vala"
		_tmp0_ = self->priv->monitors;
#line 946 "../src/LibraryMonitor.vala"
		_monitor_list = _tmp0_;
#line 946 "../src/LibraryMonitor.vala"
		_tmp1_ = _monitor_list;
#line 946 "../src/LibraryMonitor.vala"
		_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 946 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 946 "../src/LibraryMonitor.vala"
		_monitor_size = _tmp3_;
#line 946 "../src/LibraryMonitor.vala"
		_monitor_index = -1;
#line 946 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 6738 "LibraryMonitor.c"
			gint _tmp4_;
			gint _tmp5_;
			MediaMonitor* monitor = NULL;
			GeeList* _tmp6_;
			gpointer _tmp7_;
			MediaMonitor* _tmp8_;
#line 946 "../src/LibraryMonitor.vala"
			_monitor_index = _monitor_index + 1;
#line 946 "../src/LibraryMonitor.vala"
			_tmp4_ = _monitor_index;
#line 946 "../src/LibraryMonitor.vala"
			_tmp5_ = _monitor_size;
#line 946 "../src/LibraryMonitor.vala"
			if (!(_tmp4_ < _tmp5_)) {
#line 946 "../src/LibraryMonitor.vala"
				break;
#line 6755 "LibraryMonitor.c"
			}
#line 946 "../src/LibraryMonitor.vala"
			_tmp6_ = _monitor_list;
#line 946 "../src/LibraryMonitor.vala"
			_tmp7_ = gee_list_get (_tmp6_, _monitor_index);
#line 946 "../src/LibraryMonitor.vala"
			monitor = (MediaMonitor*) _tmp7_;
#line 947 "../src/LibraryMonitor.vala"
			_tmp8_ = monitor;
#line 947 "../src/LibraryMonitor.vala"
			if (media_monitor_notify_file_attributes_altered (_tmp8_, file)) {
#line 948 "../src/LibraryMonitor.vala"
				known = TRUE;
#line 950 "../src/LibraryMonitor.vala"
				_g_object_unref0 (monitor);
#line 950 "../src/LibraryMonitor.vala"
				break;
#line 6773 "LibraryMonitor.c"
			}
#line 946 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitor);
#line 6777 "LibraryMonitor.c"
		}
	}
#line 954 "../src/LibraryMonitor.vala"
	if (!known) {
#line 955 "../src/LibraryMonitor.vala"
		library_monitor_runtime_unknown_file_discovered (self, file);
#line 6784 "LibraryMonitor.c"
	}
#line 957 "../src/LibraryMonitor.vala"
	DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_attributes_altered (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), file);
#line 6788 "LibraryMonitor.c"
}

static void
library_monitor_real_notify_file_alteration_completed (DirectoryMonitor* base,
                                                       GFile* file,
                                                       GFileInfo* info)
{
	LibraryMonitor * self;
	gboolean known = FALSE;
#line 960 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_MONITOR, LibraryMonitor);
#line 960 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 960 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (info, g_file_info_get_type ()));
#line 961 "../src/LibraryMonitor.vala"
	if (library_monitor_is_blacklisted (file)) {
#line 962 "../src/LibraryMonitor.vala"
		DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_alteration_completed (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), file, info);
#line 964 "../src/LibraryMonitor.vala"
		return;
#line 6810 "LibraryMonitor.c"
	}
#line 967 "../src/LibraryMonitor.vala"
	known = FALSE;
#line 6814 "LibraryMonitor.c"
	{
		GeeList* _monitor_list = NULL;
		GeeList* _tmp0_;
		gint _monitor_size = 0;
		GeeList* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		gint _monitor_index = 0;
#line 968 "../src/LibraryMonitor.vala"
		_tmp0_ = self->priv->monitors;
#line 968 "../src/LibraryMonitor.vala"
		_monitor_list = _tmp0_;
#line 968 "../src/LibraryMonitor.vala"
		_tmp1_ = _monitor_list;
#line 968 "../src/LibraryMonitor.vala"
		_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 968 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 968 "../src/LibraryMonitor.vala"
		_monitor_size = _tmp3_;
#line 968 "../src/LibraryMonitor.vala"
		_monitor_index = -1;
#line 968 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 6839 "LibraryMonitor.c"
			gint _tmp4_;
			gint _tmp5_;
			MediaMonitor* monitor = NULL;
			GeeList* _tmp6_;
			gpointer _tmp7_;
			MediaMonitor* _tmp8_;
#line 968 "../src/LibraryMonitor.vala"
			_monitor_index = _monitor_index + 1;
#line 968 "../src/LibraryMonitor.vala"
			_tmp4_ = _monitor_index;
#line 968 "../src/LibraryMonitor.vala"
			_tmp5_ = _monitor_size;
#line 968 "../src/LibraryMonitor.vala"
			if (!(_tmp4_ < _tmp5_)) {
#line 968 "../src/LibraryMonitor.vala"
				break;
#line 6856 "LibraryMonitor.c"
			}
#line 968 "../src/LibraryMonitor.vala"
			_tmp6_ = _monitor_list;
#line 968 "../src/LibraryMonitor.vala"
			_tmp7_ = gee_list_get (_tmp6_, _monitor_index);
#line 968 "../src/LibraryMonitor.vala"
			monitor = (MediaMonitor*) _tmp7_;
#line 969 "../src/LibraryMonitor.vala"
			_tmp8_ = monitor;
#line 969 "../src/LibraryMonitor.vala"
			if (media_monitor_notify_file_alteration_completed (_tmp8_, file, info)) {
#line 970 "../src/LibraryMonitor.vala"
				known = TRUE;
#line 972 "../src/LibraryMonitor.vala"
				_g_object_unref0 (monitor);
#line 972 "../src/LibraryMonitor.vala"
				break;
#line 6874 "LibraryMonitor.c"
			}
#line 968 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitor);
#line 6878 "LibraryMonitor.c"
		}
	}
#line 976 "../src/LibraryMonitor.vala"
	if (!known) {
#line 977 "../src/LibraryMonitor.vala"
		library_monitor_runtime_unknown_file_discovered (self, file);
#line 6885 "LibraryMonitor.c"
	}
#line 979 "../src/LibraryMonitor.vala"
	DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_alteration_completed (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), file, info);
#line 6889 "LibraryMonitor.c"
}

static void
library_monitor_real_notify_file_deleted (DirectoryMonitor* base,
                                          GFile* file)
{
	LibraryMonitor * self;
	gboolean known = FALSE;
#line 982 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, TYPE_LIBRARY_MONITOR, LibraryMonitor);
#line 982 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()));
#line 983 "../src/LibraryMonitor.vala"
	if (library_monitor_is_blacklisted (file)) {
#line 984 "../src/LibraryMonitor.vala"
		DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_deleted (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), file);
#line 986 "../src/LibraryMonitor.vala"
		return;
#line 6908 "LibraryMonitor.c"
	}
#line 989 "../src/LibraryMonitor.vala"
	known = FALSE;
#line 6912 "LibraryMonitor.c"
	{
		GeeList* _monitor_list = NULL;
		GeeList* _tmp0_;
		gint _monitor_size = 0;
		GeeList* _tmp1_;
		gint _tmp2_;
		gint _tmp3_;
		gint _monitor_index = 0;
#line 990 "../src/LibraryMonitor.vala"
		_tmp0_ = self->priv->monitors;
#line 990 "../src/LibraryMonitor.vala"
		_monitor_list = _tmp0_;
#line 990 "../src/LibraryMonitor.vala"
		_tmp1_ = _monitor_list;
#line 990 "../src/LibraryMonitor.vala"
		_tmp2_ = gee_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GEE_TYPE_COLLECTION, GeeCollection));
#line 990 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp2_;
#line 990 "../src/LibraryMonitor.vala"
		_monitor_size = _tmp3_;
#line 990 "../src/LibraryMonitor.vala"
		_monitor_index = -1;
#line 990 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 6937 "LibraryMonitor.c"
			gint _tmp4_;
			gint _tmp5_;
			MediaMonitor* monitor = NULL;
			GeeList* _tmp6_;
			gpointer _tmp7_;
			MediaMonitor* _tmp8_;
#line 990 "../src/LibraryMonitor.vala"
			_monitor_index = _monitor_index + 1;
#line 990 "../src/LibraryMonitor.vala"
			_tmp4_ = _monitor_index;
#line 990 "../src/LibraryMonitor.vala"
			_tmp5_ = _monitor_size;
#line 990 "../src/LibraryMonitor.vala"
			if (!(_tmp4_ < _tmp5_)) {
#line 990 "../src/LibraryMonitor.vala"
				break;
#line 6954 "LibraryMonitor.c"
			}
#line 990 "../src/LibraryMonitor.vala"
			_tmp6_ = _monitor_list;
#line 990 "../src/LibraryMonitor.vala"
			_tmp7_ = gee_list_get (_tmp6_, _monitor_index);
#line 990 "../src/LibraryMonitor.vala"
			monitor = (MediaMonitor*) _tmp7_;
#line 991 "../src/LibraryMonitor.vala"
			_tmp8_ = monitor;
#line 991 "../src/LibraryMonitor.vala"
			if (media_monitor_notify_file_deleted (_tmp8_, file)) {
#line 992 "../src/LibraryMonitor.vala"
				known = TRUE;
#line 994 "../src/LibraryMonitor.vala"
				_g_object_unref0 (monitor);
#line 994 "../src/LibraryMonitor.vala"
				break;
#line 6972 "LibraryMonitor.c"
			}
#line 990 "../src/LibraryMonitor.vala"
			_g_object_unref0 (monitor);
#line 6976 "LibraryMonitor.c"
		}
	}
#line 998 "../src/LibraryMonitor.vala"
	if (!known) {
#line 6981 "LibraryMonitor.c"
		Tombstone* tombstone = NULL;
		TombstoneSourceCollection* _tmp9_;
		Tombstone* _tmp10_;
		Tombstone* _tmp11_;
#line 1000 "../src/LibraryMonitor.vala"
		_tmp9_ = tombstone_global;
#line 1000 "../src/LibraryMonitor.vala"
		_tmp10_ = tombstone_source_collection_locate (_tmp9_, file);
#line 1000 "../src/LibraryMonitor.vala"
		tombstone = _tmp10_;
#line 1001 "../src/LibraryMonitor.vala"
		_tmp11_ = tombstone;
#line 1001 "../src/LibraryMonitor.vala"
		if (_tmp11_ != NULL) {
#line 6996 "LibraryMonitor.c"
			gchar* _tmp12_;
			gchar* _tmp13_;
			TombstoneSourceCollection* _tmp14_;
			Tombstone* _tmp15_;
#line 1002 "../src/LibraryMonitor.vala"
			_tmp12_ = g_file_get_path (file);
#line 1002 "../src/LibraryMonitor.vala"
			_tmp13_ = _tmp12_;
#line 1002 "../src/LibraryMonitor.vala"
			g_debug ("LibraryMonitor.vala:1002: Resurrecting tombstoned file %s", _tmp13_);
#line 1002 "../src/LibraryMonitor.vala"
			_g_free0 (_tmp13_);
#line 1003 "../src/LibraryMonitor.vala"
			_tmp14_ = tombstone_global;
#line 1003 "../src/LibraryMonitor.vala"
			_tmp15_ = tombstone;
#line 1003 "../src/LibraryMonitor.vala"
			tombstone_source_collection_resurrect (_tmp14_, _tmp15_);
#line 7015 "LibraryMonitor.c"
		}
#line 1007 "../src/LibraryMonitor.vala"
		library_monitor_remove_queued_import (self, file);
#line 998 "../src/LibraryMonitor.vala"
		_g_object_unref0 (tombstone);
#line 7021 "LibraryMonitor.c"
	}
#line 1010 "../src/LibraryMonitor.vala"
	DIRECTORY_MONITOR_CLASS (library_monitor_parent_class)->notify_file_deleted (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_DIRECTORY_MONITOR, DirectoryMonitor), file);
#line 7025 "LibraryMonitor.c"
}

static void
g_cclosure_user_marshal_VOID__INT_INT (GClosure * closure,
                                       GValue * return_value,
                                       guint n_param_values,
                                       const GValue * param_values,
                                       gpointer invocation_hint,
                                       gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__INT_INT) (gpointer data1, gint arg_1, gint arg_2, gpointer data2);
	register GMarshalFunc_VOID__INT_INT callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 97 "../src/LibraryMonitor.vala"
	g_return_if_fail (n_param_values == 3);
#line 97 "../src/LibraryMonitor.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 97 "../src/LibraryMonitor.vala"
		data1 = closure->data;
#line 97 "../src/LibraryMonitor.vala"
		data2 = param_values->data[0].v_pointer;
#line 7050 "LibraryMonitor.c"
	} else {
#line 97 "../src/LibraryMonitor.vala"
		data1 = param_values->data[0].v_pointer;
#line 97 "../src/LibraryMonitor.vala"
		data2 = closure->data;
#line 7056 "LibraryMonitor.c"
	}
#line 97 "../src/LibraryMonitor.vala"
	callback = (GMarshalFunc_VOID__INT_INT) (marshal_data ? marshal_data : cc->callback);
#line 97 "../src/LibraryMonitor.vala"
	callback (data1, g_value_get_int (param_values + 1), g_value_get_int (param_values + 2), data2);
#line 7062 "LibraryMonitor.c"
}

static void
g_cclosure_user_marshal_VOID__UINT64_UINT64 (GClosure * closure,
                                             GValue * return_value,
                                             guint n_param_values,
                                             const GValue * param_values,
                                             gpointer invocation_hint,
                                             gpointer marshal_data)
{
	typedef void (*GMarshalFunc_VOID__UINT64_UINT64) (gpointer data1, guint64 arg_1, guint64 arg_2, gpointer data2);
	register GMarshalFunc_VOID__UINT64_UINT64 callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 97 "../src/LibraryMonitor.vala"
	g_return_if_fail (n_param_values == 3);
#line 97 "../src/LibraryMonitor.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 97 "../src/LibraryMonitor.vala"
		data1 = closure->data;
#line 97 "../src/LibraryMonitor.vala"
		data2 = param_values->data[0].v_pointer;
#line 7087 "LibraryMonitor.c"
	} else {
#line 97 "../src/LibraryMonitor.vala"
		data1 = param_values->data[0].v_pointer;
#line 97 "../src/LibraryMonitor.vala"
		data2 = closure->data;
#line 7093 "LibraryMonitor.c"
	}
#line 97 "../src/LibraryMonitor.vala"
	callback = (GMarshalFunc_VOID__UINT64_UINT64) (marshal_data ? marshal_data : cc->callback);
#line 97 "../src/LibraryMonitor.vala"
	callback (data1, g_value_get_uint64 (param_values + 1), g_value_get_uint64 (param_values + 2), data2);
#line 7099 "LibraryMonitor.c"
}

static void
_library_monitor_on_find_move_completed_completion_callback (BackgroundJob* job,
                                                             gpointer self)
{
#line 111 "../src/LibraryMonitor.vala"
	library_monitor_on_find_move_completed ((LibraryMonitor*) self, job);
#line 7108 "LibraryMonitor.c"
}

static void
_library_monitor_on_find_move_cancelled_cancellation_callback (BackgroundJob* job,
                                                               gpointer self)
{
#line 111 "../src/LibraryMonitor.vala"
	library_monitor_on_find_move_cancelled ((LibraryMonitor*) self, job);
#line 7117 "LibraryMonitor.c"
}

static LibraryMonitorFindMoveJob*
library_monitor_find_move_job_construct (GType object_type,
                                         LibraryMonitor* owner,
                                         GFile* file,
                                         GeeCollection* candidates)
{
	LibraryMonitorFindMoveJob* self = NULL;
	GCancellable* _tmp0_;
	GFile* _tmp1_;
	GeeCollection* _tmp2_;
#line 110 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (IS_LIBRARY_MONITOR (owner), NULL);
#line 110 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()), NULL);
#line 110 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (candidates, GEE_TYPE_COLLECTION), NULL);
#line 111 "../src/LibraryMonitor.vala"
	_tmp0_ = owner->priv->cancellable;
#line 111 "../src/LibraryMonitor.vala"
	self = (LibraryMonitorFindMoveJob*) background_job_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (owner, G_TYPE_OBJECT, GObject), _library_monitor_on_find_move_completed_completion_callback, owner, _tmp0_, _library_monitor_on_find_move_cancelled_cancellation_callback, owner, NULL);
#line 113 "../src/LibraryMonitor.vala"
	_tmp1_ = _g_object_ref0 (file);
#line 113 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->file);
#line 113 "../src/LibraryMonitor.vala"
	self->file = _tmp1_;
#line 114 "../src/LibraryMonitor.vala"
	_tmp2_ = _g_object_ref0 (candidates);
#line 114 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->candidates);
#line 114 "../src/LibraryMonitor.vala"
	self->candidates = _tmp2_;
#line 116 "../src/LibraryMonitor.vala"
	background_job_set_completion_priority (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_BACKGROUND_JOB, BackgroundJob), G_PRIORITY_LOW);
#line 110 "../src/LibraryMonitor.vala"
	return self;
#line 7156 "LibraryMonitor.c"
}

static LibraryMonitorFindMoveJob*
library_monitor_find_move_job_new (LibraryMonitor* owner,
                                   GFile* file,
                                   GeeCollection* candidates)
{
#line 110 "../src/LibraryMonitor.vala"
	return library_monitor_find_move_job_construct (LIBRARY_MONITOR_TYPE_FIND_MOVE_JOB, owner, file, candidates);
#line 7166 "LibraryMonitor.c"
}

static gpointer
_g_error_copy0 (gpointer self)
{
#line 135 "../src/LibraryMonitor.vala"
	return self ? g_error_copy (self) : NULL;
#line 7174 "LibraryMonitor.c"
}

static void
library_monitor_find_move_job_real_execute (BackgroundJob* base)
{
	LibraryMonitorFindMoveJob * self;
	GeeIterator* iter = NULL;
	GeeCollection* _tmp0_;
	GeeIterator* _tmp1_;
	GeeCollection* _tmp10_;
	gint _tmp11_;
	gint _tmp12_;
	gchar* md5 = NULL;
	GError* _inner_error0_ = NULL;
#line 119 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_MONITOR_TYPE_FIND_MOVE_JOB, LibraryMonitorFindMoveJob);
#line 121 "../src/LibraryMonitor.vala"
	_tmp0_ = self->candidates;
#line 121 "../src/LibraryMonitor.vala"
	_tmp1_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, GEE_TYPE_ITERABLE, GeeIterable));
#line 121 "../src/LibraryMonitor.vala"
	iter = _tmp1_;
#line 122 "../src/LibraryMonitor.vala"
	while (TRUE) {
#line 7199 "LibraryMonitor.c"
		GeeIterator* _tmp2_;
		GeeIterator* _tmp3_;
		gpointer _tmp4_;
		Monitorable* _tmp5_;
		GFile* _tmp6_;
		GFile* _tmp7_;
		gboolean _tmp8_;
#line 122 "../src/LibraryMonitor.vala"
		_tmp2_ = iter;
#line 122 "../src/LibraryMonitor.vala"
		if (!gee_iterator_next (_tmp2_)) {
#line 122 "../src/LibraryMonitor.vala"
			break;
#line 7213 "LibraryMonitor.c"
		}
#line 123 "../src/LibraryMonitor.vala"
		_tmp3_ = iter;
#line 123 "../src/LibraryMonitor.vala"
		_tmp4_ = gee_iterator_get (_tmp3_);
#line 123 "../src/LibraryMonitor.vala"
		_tmp5_ = (Monitorable*) _tmp4_;
#line 123 "../src/LibraryMonitor.vala"
		_tmp6_ = media_source_get_master_file (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, TYPE_MEDIA_SOURCE, MediaSource));
#line 123 "../src/LibraryMonitor.vala"
		_tmp7_ = _tmp6_;
#line 123 "../src/LibraryMonitor.vala"
		_tmp8_ = g_file_query_exists (_tmp7_, NULL);
#line 123 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_tmp7_);
#line 123 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_tmp5_);
#line 123 "../src/LibraryMonitor.vala"
		if (_tmp8_) {
#line 7233 "LibraryMonitor.c"
			GeeIterator* _tmp9_;
#line 124 "../src/LibraryMonitor.vala"
			_tmp9_ = iter;
#line 124 "../src/LibraryMonitor.vala"
			gee_iterator_remove (_tmp9_);
#line 7239 "LibraryMonitor.c"
		}
	}
#line 128 "../src/LibraryMonitor.vala"
	_tmp10_ = self->candidates;
#line 128 "../src/LibraryMonitor.vala"
	_tmp11_ = gee_collection_get_size (_tmp10_);
#line 128 "../src/LibraryMonitor.vala"
	_tmp12_ = _tmp11_;
#line 128 "../src/LibraryMonitor.vala"
	if (_tmp12_ == 0) {
#line 129 "../src/LibraryMonitor.vala"
		_g_object_unref0 (iter);
#line 129 "../src/LibraryMonitor.vala"
		return;
#line 7254 "LibraryMonitor.c"
	}
#line 131 "../src/LibraryMonitor.vala"
	md5 = NULL;
#line 7258 "LibraryMonitor.c"
	{
		gchar* _tmp13_ = NULL;
		GFile* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
#line 133 "../src/LibraryMonitor.vala"
		_tmp14_ = self->file;
#line 133 "../src/LibraryMonitor.vala"
		_tmp15_ = md5_file (_tmp14_, &_inner_error0_);
#line 133 "../src/LibraryMonitor.vala"
		_tmp13_ = _tmp15_;
#line 133 "../src/LibraryMonitor.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7272 "LibraryMonitor.c"
			goto __catch0_g_error;
		}
#line 133 "../src/LibraryMonitor.vala"
		_tmp16_ = _tmp13_;
#line 133 "../src/LibraryMonitor.vala"
		_tmp13_ = NULL;
#line 133 "../src/LibraryMonitor.vala"
		_g_free0 (md5);
#line 133 "../src/LibraryMonitor.vala"
		md5 = _tmp16_;
#line 132 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp13_);
#line 7285 "LibraryMonitor.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* err = NULL;
		GError* _tmp17_;
		GError* _tmp18_;
#line 132 "../src/LibraryMonitor.vala"
		err = _inner_error0_;
#line 132 "../src/LibraryMonitor.vala"
		_inner_error0_ = NULL;
#line 135 "../src/LibraryMonitor.vala"
		_tmp17_ = err;
#line 135 "../src/LibraryMonitor.vala"
		_tmp18_ = _g_error_copy0 (_tmp17_);
#line 135 "../src/LibraryMonitor.vala"
		_g_error_free0 (self->err);
#line 135 "../src/LibraryMonitor.vala"
		self->err = _tmp18_;
#line 137 "../src/LibraryMonitor.vala"
		_g_error_free0 (err);
#line 137 "../src/LibraryMonitor.vala"
		_g_free0 (md5);
#line 137 "../src/LibraryMonitor.vala"
		_g_object_unref0 (iter);
#line 137 "../src/LibraryMonitor.vala"
		return;
#line 7313 "LibraryMonitor.c"
	}
	__finally0:
#line 132 "../src/LibraryMonitor.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 132 "../src/LibraryMonitor.vala"
		_g_free0 (md5);
#line 132 "../src/LibraryMonitor.vala"
		_g_object_unref0 (iter);
#line 132 "../src/LibraryMonitor.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 132 "../src/LibraryMonitor.vala"
		g_clear_error (&_inner_error0_);
#line 132 "../src/LibraryMonitor.vala"
		return;
#line 7328 "LibraryMonitor.c"
	}
	{
		GeeIterator* _candidate_it = NULL;
		GeeCollection* _tmp19_;
		GeeIterator* _tmp20_;
#line 140 "../src/LibraryMonitor.vala"
		_tmp19_ = self->candidates;
#line 140 "../src/LibraryMonitor.vala"
		_tmp20_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp19_, GEE_TYPE_ITERABLE, GeeIterable));
#line 140 "../src/LibraryMonitor.vala"
		_candidate_it = _tmp20_;
#line 140 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 7342 "LibraryMonitor.c"
			GeeIterator* _tmp21_;
			Monitorable* candidate = NULL;
			GeeIterator* _tmp22_;
			gpointer _tmp23_;
			Monitorable* _tmp24_;
			gchar* _tmp25_;
			gchar* _tmp26_;
			const gchar* _tmp27_;
			gboolean _tmp28_;
			Monitorable* _tmp29_;
			Monitorable* _tmp43_;
			Monitorable* _tmp44_;
#line 140 "../src/LibraryMonitor.vala"
			_tmp21_ = _candidate_it;
#line 140 "../src/LibraryMonitor.vala"
			if (!gee_iterator_next (_tmp21_)) {
#line 140 "../src/LibraryMonitor.vala"
				break;
#line 7361 "LibraryMonitor.c"
			}
#line 140 "../src/LibraryMonitor.vala"
			_tmp22_ = _candidate_it;
#line 140 "../src/LibraryMonitor.vala"
			_tmp23_ = gee_iterator_get (_tmp22_);
#line 140 "../src/LibraryMonitor.vala"
			candidate = (Monitorable*) _tmp23_;
#line 141 "../src/LibraryMonitor.vala"
			_tmp24_ = candidate;
#line 141 "../src/LibraryMonitor.vala"
			_tmp25_ = media_source_get_master_md5 (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, TYPE_MEDIA_SOURCE, MediaSource));
#line 141 "../src/LibraryMonitor.vala"
			_tmp26_ = _tmp25_;
#line 141 "../src/LibraryMonitor.vala"
			_tmp27_ = md5;
#line 141 "../src/LibraryMonitor.vala"
			_tmp28_ = g_strcmp0 (_tmp26_, _tmp27_) != 0;
#line 141 "../src/LibraryMonitor.vala"
			_g_free0 (_tmp26_);
#line 141 "../src/LibraryMonitor.vala"
			if (_tmp28_) {
#line 142 "../src/LibraryMonitor.vala"
				_g_object_unref0 (candidate);
#line 142 "../src/LibraryMonitor.vala"
				continue;
#line 7387 "LibraryMonitor.c"
			}
#line 144 "../src/LibraryMonitor.vala"
			_tmp29_ = self->match;
#line 144 "../src/LibraryMonitor.vala"
			if (_tmp29_ != NULL) {
#line 7393 "LibraryMonitor.c"
				GFile* _tmp30_;
				gchar* _tmp31_;
				gchar* _tmp32_;
				Monitorable* _tmp33_;
				gchar* _tmp34_;
				gchar* _tmp35_;
				Monitorable* _tmp36_;
				gchar* _tmp37_;
				gchar* _tmp38_;
				GeeArrayList* _tmp39_;
				GeeArrayList* _tmp41_;
				Monitorable* _tmp42_;
#line 145 "../src/LibraryMonitor.vala"
				_tmp30_ = self->file;
#line 145 "../src/LibraryMonitor.vala"
				_tmp31_ = g_file_get_path (_tmp30_);
#line 145 "../src/LibraryMonitor.vala"
				_tmp32_ = _tmp31_;
#line 145 "../src/LibraryMonitor.vala"
				_tmp33_ = self->match;
#line 145 "../src/LibraryMonitor.vala"
				_tmp34_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp33_, TYPE_DATA_OBJECT, DataObject));
#line 145 "../src/LibraryMonitor.vala"
				_tmp35_ = _tmp34_;
#line 145 "../src/LibraryMonitor.vala"
				_tmp36_ = candidate;
#line 145 "../src/LibraryMonitor.vala"
				_tmp37_ = data_object_to_string (G_TYPE_CHECK_INSTANCE_CAST (_tmp36_, TYPE_DATA_OBJECT, DataObject));
#line 145 "../src/LibraryMonitor.vala"
				_tmp38_ = _tmp37_;
#line 145 "../src/LibraryMonitor.vala"
				g_warning ("LibraryMonitor.vala:145: Found more than one media match for %s: %s an" \
"d %s", _tmp32_, _tmp35_, _tmp38_);
#line 145 "../src/LibraryMonitor.vala"
				_g_free0 (_tmp38_);
#line 145 "../src/LibraryMonitor.vala"
				_g_free0 (_tmp35_);
#line 145 "../src/LibraryMonitor.vala"
				_g_free0 (_tmp32_);
#line 148 "../src/LibraryMonitor.vala"
				_tmp39_ = self->losers;
#line 148 "../src/LibraryMonitor.vala"
				if (_tmp39_ == NULL) {
#line 7436 "LibraryMonitor.c"
					GeeArrayList* _tmp40_;
#line 149 "../src/LibraryMonitor.vala"
					_tmp40_ = gee_array_list_new (TYPE_MONITORABLE, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 149 "../src/LibraryMonitor.vala"
					_g_object_unref0 (self->losers);
#line 149 "../src/LibraryMonitor.vala"
					self->losers = _tmp40_;
#line 7444 "LibraryMonitor.c"
				}
#line 151 "../src/LibraryMonitor.vala"
				_tmp41_ = self->losers;
#line 151 "../src/LibraryMonitor.vala"
				_tmp42_ = candidate;
#line 151 "../src/LibraryMonitor.vala"
				gee_abstract_collection_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp41_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection), _tmp42_);
#line 153 "../src/LibraryMonitor.vala"
				_g_object_unref0 (candidate);
#line 153 "../src/LibraryMonitor.vala"
				continue;
#line 7456 "LibraryMonitor.c"
			}
#line 156 "../src/LibraryMonitor.vala"
			_tmp43_ = candidate;
#line 156 "../src/LibraryMonitor.vala"
			_tmp44_ = _g_object_ref0 (_tmp43_);
#line 156 "../src/LibraryMonitor.vala"
			_g_object_unref0 (self->match);
#line 156 "../src/LibraryMonitor.vala"
			self->match = _tmp44_;
#line 140 "../src/LibraryMonitor.vala"
			_g_object_unref0 (candidate);
#line 7468 "LibraryMonitor.c"
		}
#line 140 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_candidate_it);
#line 7472 "LibraryMonitor.c"
	}
#line 119 "../src/LibraryMonitor.vala"
	_g_free0 (md5);
#line 119 "../src/LibraryMonitor.vala"
	_g_object_unref0 (iter);
#line 7478 "LibraryMonitor.c"
}

static void
library_monitor_find_move_job_class_init (LibraryMonitorFindMoveJobClass * klass,
                                          gpointer klass_data)
{
#line 103 "../src/LibraryMonitor.vala"
	library_monitor_find_move_job_parent_class = g_type_class_peek_parent (klass);
#line 103 "../src/LibraryMonitor.vala"
	((BackgroundJobClass *) klass)->finalize = library_monitor_find_move_job_finalize;
#line 103 "../src/LibraryMonitor.vala"
	((BackgroundJobClass *) klass)->execute = (void (*) (BackgroundJob*)) library_monitor_find_move_job_real_execute;
#line 7491 "LibraryMonitor.c"
}

static void
library_monitor_find_move_job_instance_init (LibraryMonitorFindMoveJob * self,
                                             gpointer klass)
{
#line 106 "../src/LibraryMonitor.vala"
	self->match = NULL;
#line 107 "../src/LibraryMonitor.vala"
	self->losers = NULL;
#line 108 "../src/LibraryMonitor.vala"
	self->err = NULL;
#line 7504 "LibraryMonitor.c"
}

static void
library_monitor_find_move_job_finalize (BackgroundJob * obj)
{
	LibraryMonitorFindMoveJob * self;
#line 103 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBRARY_MONITOR_TYPE_FIND_MOVE_JOB, LibraryMonitorFindMoveJob);
#line 104 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->file);
#line 105 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->candidates);
#line 106 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->match);
#line 107 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->losers);
#line 108 "../src/LibraryMonitor.vala"
	_g_error_free0 (self->err);
#line 103 "../src/LibraryMonitor.vala"
	BACKGROUND_JOB_CLASS (library_monitor_find_move_job_parent_class)->finalize (obj);
#line 7525 "LibraryMonitor.c"
}

static GType
library_monitor_find_move_job_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (LibraryMonitorFindMoveJobClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_monitor_find_move_job_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryMonitorFindMoveJob), 0, (GInstanceInitFunc) library_monitor_find_move_job_instance_init, NULL };
	GType library_monitor_find_move_job_type_id;
	library_monitor_find_move_job_type_id = g_type_register_static (TYPE_BACKGROUND_JOB, "LibraryMonitorFindMoveJob", &g_define_type_info, 0);
	return library_monitor_find_move_job_type_id;
}

static GType
library_monitor_find_move_job_get_type (void)
{
	static volatile gsize library_monitor_find_move_job_type_id__once = 0;
	if (g_once_init_enter (&library_monitor_find_move_job_type_id__once)) {
		GType library_monitor_find_move_job_type_id;
		library_monitor_find_move_job_type_id = library_monitor_find_move_job_get_type_once ();
		g_once_init_leave (&library_monitor_find_move_job_type_id__once, library_monitor_find_move_job_type_id);
	}
	return library_monitor_find_move_job_type_id__once;
}

static void
_library_monitor_on_runtime_find_move_completed_completion_callback (BackgroundJob* job,
                                                                     gpointer self)
{
#line 168 "../src/LibraryMonitor.vala"
	library_monitor_on_runtime_find_move_completed ((LibraryMonitor*) self, job);
#line 7555 "LibraryMonitor.c"
}

static LibraryMonitorRuntimeFindMoveJob*
library_monitor_runtime_find_move_job_construct (GType object_type,
                                                 LibraryMonitor* owner,
                                                 GFile* file,
                                                 GeeCollection* candidates)
{
	LibraryMonitorRuntimeFindMoveJob* self = NULL;
	GCancellable* _tmp0_;
	GFile* _tmp1_;
	GeeCollection* _tmp2_;
#line 167 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (IS_LIBRARY_MONITOR (owner), NULL);
#line 167 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (file, g_file_get_type ()), NULL);
#line 167 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (candidates, GEE_TYPE_COLLECTION), NULL);
#line 168 "../src/LibraryMonitor.vala"
	_tmp0_ = owner->priv->cancellable;
#line 168 "../src/LibraryMonitor.vala"
	self = (LibraryMonitorRuntimeFindMoveJob*) background_job_construct (object_type, G_TYPE_CHECK_INSTANCE_CAST (owner, G_TYPE_OBJECT, GObject), _library_monitor_on_runtime_find_move_completed_completion_callback, owner, _tmp0_, NULL, NULL, NULL);
#line 170 "../src/LibraryMonitor.vala"
	_tmp1_ = _g_object_ref0 (file);
#line 170 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->file);
#line 170 "../src/LibraryMonitor.vala"
	self->file = _tmp1_;
#line 171 "../src/LibraryMonitor.vala"
	_tmp2_ = _g_object_ref0 (candidates);
#line 171 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->candidates);
#line 171 "../src/LibraryMonitor.vala"
	self->candidates = _tmp2_;
#line 173 "../src/LibraryMonitor.vala"
	background_job_set_completion_priority (G_TYPE_CHECK_INSTANCE_CAST (self, TYPE_BACKGROUND_JOB, BackgroundJob), G_PRIORITY_LOW);
#line 167 "../src/LibraryMonitor.vala"
	return self;
#line 7594 "LibraryMonitor.c"
}

static LibraryMonitorRuntimeFindMoveJob*
library_monitor_runtime_find_move_job_new (LibraryMonitor* owner,
                                           GFile* file,
                                           GeeCollection* candidates)
{
#line 167 "../src/LibraryMonitor.vala"
	return library_monitor_runtime_find_move_job_construct (LIBRARY_MONITOR_TYPE_RUNTIME_FIND_MOVE_JOB, owner, file, candidates);
#line 7604 "LibraryMonitor.c"
}

static void
library_monitor_runtime_find_move_job_real_execute (BackgroundJob* base)
{
	LibraryMonitorRuntimeFindMoveJob * self;
	gchar* md5 = NULL;
	GError* _inner_error0_ = NULL;
#line 176 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, LIBRARY_MONITOR_TYPE_RUNTIME_FIND_MOVE_JOB, LibraryMonitorRuntimeFindMoveJob);
#line 177 "../src/LibraryMonitor.vala"
	md5 = NULL;
#line 7617 "LibraryMonitor.c"
	{
		gchar* _tmp0_ = NULL;
		GFile* _tmp1_;
		gchar* _tmp2_;
		gchar* _tmp3_;
#line 179 "../src/LibraryMonitor.vala"
		_tmp1_ = self->file;
#line 179 "../src/LibraryMonitor.vala"
		_tmp2_ = md5_file (_tmp1_, &_inner_error0_);
#line 179 "../src/LibraryMonitor.vala"
		_tmp0_ = _tmp2_;
#line 179 "../src/LibraryMonitor.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 7631 "LibraryMonitor.c"
			goto __catch0_g_error;
		}
#line 179 "../src/LibraryMonitor.vala"
		_tmp3_ = _tmp0_;
#line 179 "../src/LibraryMonitor.vala"
		_tmp0_ = NULL;
#line 179 "../src/LibraryMonitor.vala"
		_g_free0 (md5);
#line 179 "../src/LibraryMonitor.vala"
		md5 = _tmp3_;
#line 178 "../src/LibraryMonitor.vala"
		_g_free0 (_tmp0_);
#line 7644 "LibraryMonitor.c"
	}
	goto __finally0;
	__catch0_g_error:
	{
		GError* err = NULL;
		GError* _tmp4_;
		GError* _tmp5_;
#line 178 "../src/LibraryMonitor.vala"
		err = _inner_error0_;
#line 178 "../src/LibraryMonitor.vala"
		_inner_error0_ = NULL;
#line 181 "../src/LibraryMonitor.vala"
		_tmp4_ = err;
#line 181 "../src/LibraryMonitor.vala"
		_tmp5_ = _g_error_copy0 (_tmp4_);
#line 181 "../src/LibraryMonitor.vala"
		_g_error_free0 (self->err);
#line 181 "../src/LibraryMonitor.vala"
		self->err = _tmp5_;
#line 183 "../src/LibraryMonitor.vala"
		_g_error_free0 (err);
#line 183 "../src/LibraryMonitor.vala"
		_g_free0 (md5);
#line 183 "../src/LibraryMonitor.vala"
		return;
#line 7670 "LibraryMonitor.c"
	}
	__finally0:
#line 178 "../src/LibraryMonitor.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 178 "../src/LibraryMonitor.vala"
		_g_free0 (md5);
#line 178 "../src/LibraryMonitor.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 178 "../src/LibraryMonitor.vala"
		g_clear_error (&_inner_error0_);
#line 178 "../src/LibraryMonitor.vala"
		return;
#line 7683 "LibraryMonitor.c"
	}
	{
		GeeIterator* _candidate_it = NULL;
		GeeCollection* _tmp6_;
		GeeIterator* _tmp7_;
#line 186 "../src/LibraryMonitor.vala"
		_tmp6_ = self->candidates;
#line 186 "../src/LibraryMonitor.vala"
		_tmp7_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_ITERABLE, GeeIterable));
#line 186 "../src/LibraryMonitor.vala"
		_candidate_it = _tmp7_;
#line 186 "../src/LibraryMonitor.vala"
		while (TRUE) {
#line 7697 "LibraryMonitor.c"
			GeeIterator* _tmp8_;
			Monitorable* candidate = NULL;
			GeeIterator* _tmp9_;
			gpointer _tmp10_;
			Monitorable* _tmp11_;
			gchar* _tmp12_;
			gchar* _tmp13_;
			const gchar* _tmp14_;
			gboolean _tmp15_;
#line 186 "../src/LibraryMonitor.vala"
			_tmp8_ = _candidate_it;
#line 186 "../src/LibraryMonitor.vala"
			if (!gee_iterator_next (_tmp8_)) {
#line 186 "../src/LibraryMonitor.vala"
				break;
#line 7713 "LibraryMonitor.c"
			}
#line 186 "../src/LibraryMonitor.vala"
			_tmp9_ = _candidate_it;
#line 186 "../src/LibraryMonitor.vala"
			_tmp10_ = gee_iterator_get (_tmp9_);
#line 186 "../src/LibraryMonitor.vala"
			candidate = (Monitorable*) _tmp10_;
#line 187 "../src/LibraryMonitor.vala"
			_tmp11_ = candidate;
#line 187 "../src/LibraryMonitor.vala"
			_tmp12_ = media_source_get_master_md5 (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, TYPE_MEDIA_SOURCE, MediaSource));
#line 187 "../src/LibraryMonitor.vala"
			_tmp13_ = _tmp12_;
#line 187 "../src/LibraryMonitor.vala"
			_tmp14_ = md5;
#line 187 "../src/LibraryMonitor.vala"
			_tmp15_ = g_strcmp0 (_tmp13_, _tmp14_) == 0;
#line 187 "../src/LibraryMonitor.vala"
			_g_free0 (_tmp13_);
#line 187 "../src/LibraryMonitor.vala"
			if (_tmp15_) {
#line 7735 "LibraryMonitor.c"
				Monitorable* _tmp16_;
				Monitorable* _tmp17_;
#line 188 "../src/LibraryMonitor.vala"
				_tmp16_ = candidate;
#line 188 "../src/LibraryMonitor.vala"
				_tmp17_ = _g_object_ref0 (_tmp16_);
#line 188 "../src/LibraryMonitor.vala"
				_g_object_unref0 (self->match);
#line 188 "../src/LibraryMonitor.vala"
				self->match = _tmp17_;
#line 190 "../src/LibraryMonitor.vala"
				_g_object_unref0 (candidate);
#line 190 "../src/LibraryMonitor.vala"
				break;
#line 7750 "LibraryMonitor.c"
			}
#line 186 "../src/LibraryMonitor.vala"
			_g_object_unref0 (candidate);
#line 7754 "LibraryMonitor.c"
		}
#line 186 "../src/LibraryMonitor.vala"
		_g_object_unref0 (_candidate_it);
#line 7758 "LibraryMonitor.c"
	}
#line 176 "../src/LibraryMonitor.vala"
	_g_free0 (md5);
#line 7762 "LibraryMonitor.c"
}

static void
library_monitor_runtime_find_move_job_class_init (LibraryMonitorRuntimeFindMoveJobClass * klass,
                                                  gpointer klass_data)
{
#line 161 "../src/LibraryMonitor.vala"
	library_monitor_runtime_find_move_job_parent_class = g_type_class_peek_parent (klass);
#line 161 "../src/LibraryMonitor.vala"
	((BackgroundJobClass *) klass)->finalize = library_monitor_runtime_find_move_job_finalize;
#line 161 "../src/LibraryMonitor.vala"
	((BackgroundJobClass *) klass)->execute = (void (*) (BackgroundJob*)) library_monitor_runtime_find_move_job_real_execute;
#line 7775 "LibraryMonitor.c"
}

static void
library_monitor_runtime_find_move_job_instance_init (LibraryMonitorRuntimeFindMoveJob * self,
                                                     gpointer klass)
{
#line 164 "../src/LibraryMonitor.vala"
	self->match = NULL;
#line 165 "../src/LibraryMonitor.vala"
	self->err = NULL;
#line 7786 "LibraryMonitor.c"
}

static void
library_monitor_runtime_find_move_job_finalize (BackgroundJob * obj)
{
	LibraryMonitorRuntimeFindMoveJob * self;
#line 161 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBRARY_MONITOR_TYPE_RUNTIME_FIND_MOVE_JOB, LibraryMonitorRuntimeFindMoveJob);
#line 162 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->file);
#line 163 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->candidates);
#line 164 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->match);
#line 165 "../src/LibraryMonitor.vala"
	_g_error_free0 (self->err);
#line 161 "../src/LibraryMonitor.vala"
	BACKGROUND_JOB_CLASS (library_monitor_runtime_find_move_job_parent_class)->finalize (obj);
#line 7805 "LibraryMonitor.c"
}

static GType
library_monitor_runtime_find_move_job_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (LibraryMonitorRuntimeFindMoveJobClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_monitor_runtime_find_move_job_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryMonitorRuntimeFindMoveJob), 0, (GInstanceInitFunc) library_monitor_runtime_find_move_job_instance_init, NULL };
	GType library_monitor_runtime_find_move_job_type_id;
	library_monitor_runtime_find_move_job_type_id = g_type_register_static (TYPE_BACKGROUND_JOB, "LibraryMonitorRuntimeFindMoveJob", &g_define_type_info, 0);
	return library_monitor_runtime_find_move_job_type_id;
}

static GType
library_monitor_runtime_find_move_job_get_type (void)
{
	static volatile gsize library_monitor_runtime_find_move_job_type_id__once = 0;
	if (g_once_init_enter (&library_monitor_runtime_find_move_job_type_id__once)) {
		GType library_monitor_runtime_find_move_job_type_id;
		library_monitor_runtime_find_move_job_type_id = library_monitor_runtime_find_move_job_get_type_once ();
		g_once_init_leave (&library_monitor_runtime_find_move_job_type_id__once, library_monitor_runtime_find_move_job_type_id);
	}
	return library_monitor_runtime_find_move_job_type_id__once;
}

static LibraryMonitorVerifyJob*
library_monitor_verify_job_construct (GType object_type,
                                      Monitorable* monitorable,
                                      MediaMonitor* monitor)
{
	LibraryMonitorVerifyJob* self = NULL;
	Monitorable* _tmp0_;
	MediaMonitor* _tmp1_;
#line 200 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (IS_MONITORABLE (monitorable), NULL);
#line 200 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (IS_MEDIA_MONITOR (monitor), NULL);
#line 200 "../src/LibraryMonitor.vala"
	self = (LibraryMonitorVerifyJob*) g_type_create_instance (object_type);
#line 201 "../src/LibraryMonitor.vala"
	_tmp0_ = _g_object_ref0 (monitorable);
#line 201 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->monitorable);
#line 201 "../src/LibraryMonitor.vala"
	self->monitorable = _tmp0_;
#line 202 "../src/LibraryMonitor.vala"
	_tmp1_ = _g_object_ref0 (monitor);
#line 202 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->monitor);
#line 202 "../src/LibraryMonitor.vala"
	self->monitor = _tmp1_;
#line 200 "../src/LibraryMonitor.vala"
	return self;
#line 7857 "LibraryMonitor.c"
}

static LibraryMonitorVerifyJob*
library_monitor_verify_job_new (Monitorable* monitorable,
                                MediaMonitor* monitor)
{
#line 200 "../src/LibraryMonitor.vala"
	return library_monitor_verify_job_construct (LIBRARY_MONITOR_TYPE_VERIFY_JOB, monitorable, monitor);
#line 7866 "LibraryMonitor.c"
}

static void
library_monitor_value_verify_job_init (GValue* value)
{
#line 196 "../src/LibraryMonitor.vala"
	value->data[0].v_pointer = NULL;
#line 7874 "LibraryMonitor.c"
}

static void
library_monitor_value_verify_job_free_value (GValue* value)
{
#line 196 "../src/LibraryMonitor.vala"
	if (value->data[0].v_pointer) {
#line 196 "../src/LibraryMonitor.vala"
		library_monitor_verify_job_unref (value->data[0].v_pointer);
#line 7884 "LibraryMonitor.c"
	}
}

static void
library_monitor_value_verify_job_copy_value (const GValue* src_value,
                                             GValue* dest_value)
{
#line 196 "../src/LibraryMonitor.vala"
	if (src_value->data[0].v_pointer) {
#line 196 "../src/LibraryMonitor.vala"
		dest_value->data[0].v_pointer = library_monitor_verify_job_ref (src_value->data[0].v_pointer);
#line 7896 "LibraryMonitor.c"
	} else {
#line 196 "../src/LibraryMonitor.vala"
		dest_value->data[0].v_pointer = NULL;
#line 7900 "LibraryMonitor.c"
	}
}

static gpointer
library_monitor_value_verify_job_peek_pointer (const GValue* value)
{
#line 196 "../src/LibraryMonitor.vala"
	return value->data[0].v_pointer;
#line 7909 "LibraryMonitor.c"
}

static gchar*
library_monitor_value_verify_job_collect_value (GValue* value,
                                                guint n_collect_values,
                                                GTypeCValue* collect_values,
                                                guint collect_flags)
{
#line 196 "../src/LibraryMonitor.vala"
	if (collect_values[0].v_pointer) {
#line 7920 "LibraryMonitor.c"
		LibraryMonitorVerifyJob * object;
		object = collect_values[0].v_pointer;
#line 196 "../src/LibraryMonitor.vala"
		if (object->parent_instance.g_class == NULL) {
#line 196 "../src/LibraryMonitor.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 7927 "LibraryMonitor.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 196 "../src/LibraryMonitor.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 7931 "LibraryMonitor.c"
		}
#line 196 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = library_monitor_verify_job_ref (object);
#line 7935 "LibraryMonitor.c"
	} else {
#line 196 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = NULL;
#line 7939 "LibraryMonitor.c"
	}
#line 196 "../src/LibraryMonitor.vala"
	return NULL;
#line 7943 "LibraryMonitor.c"
}

static gchar*
library_monitor_value_verify_job_lcopy_value (const GValue* value,
                                              guint n_collect_values,
                                              GTypeCValue* collect_values,
                                              guint collect_flags)
{
	LibraryMonitorVerifyJob ** object_p;
	object_p = collect_values[0].v_pointer;
#line 196 "../src/LibraryMonitor.vala"
	if (!object_p) {
#line 196 "../src/LibraryMonitor.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 7958 "LibraryMonitor.c"
	}
#line 196 "../src/LibraryMonitor.vala"
	if (!value->data[0].v_pointer) {
#line 196 "../src/LibraryMonitor.vala"
		*object_p = NULL;
#line 7964 "LibraryMonitor.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 196 "../src/LibraryMonitor.vala"
		*object_p = value->data[0].v_pointer;
#line 7968 "LibraryMonitor.c"
	} else {
#line 196 "../src/LibraryMonitor.vala"
		*object_p = library_monitor_verify_job_ref (value->data[0].v_pointer);
#line 7972 "LibraryMonitor.c"
	}
#line 196 "../src/LibraryMonitor.vala"
	return NULL;
#line 7976 "LibraryMonitor.c"
}

static GParamSpec*
library_monitor_param_spec_verify_job (const gchar* name,
                                       const gchar* nick,
                                       const gchar* blurb,
                                       GType object_type,
                                       GParamFlags flags)
{
	LibraryMonitorParamSpecVerifyJob* spec;
#line 196 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (g_type_is_a (object_type, LIBRARY_MONITOR_TYPE_VERIFY_JOB), NULL);
#line 196 "../src/LibraryMonitor.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 196 "../src/LibraryMonitor.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 196 "../src/LibraryMonitor.vala"
	return G_PARAM_SPEC (spec);
#line 7995 "LibraryMonitor.c"
}

static gpointer
library_monitor_value_get_verify_job (const GValue* value)
{
#line 196 "../src/LibraryMonitor.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, LIBRARY_MONITOR_TYPE_VERIFY_JOB), NULL);
#line 196 "../src/LibraryMonitor.vala"
	return value->data[0].v_pointer;
#line 8005 "LibraryMonitor.c"
}

static void
library_monitor_value_set_verify_job (GValue* value,
                                      gpointer v_object)
{
	LibraryMonitorVerifyJob * old;
#line 196 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, LIBRARY_MONITOR_TYPE_VERIFY_JOB));
#line 196 "../src/LibraryMonitor.vala"
	old = value->data[0].v_pointer;
#line 196 "../src/LibraryMonitor.vala"
	if (v_object) {
#line 196 "../src/LibraryMonitor.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, LIBRARY_MONITOR_TYPE_VERIFY_JOB));
#line 196 "../src/LibraryMonitor.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 196 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = v_object;
#line 196 "../src/LibraryMonitor.vala"
		library_monitor_verify_job_ref (value->data[0].v_pointer);
#line 8027 "LibraryMonitor.c"
	} else {
#line 196 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = NULL;
#line 8031 "LibraryMonitor.c"
	}
#line 196 "../src/LibraryMonitor.vala"
	if (old) {
#line 196 "../src/LibraryMonitor.vala"
		library_monitor_verify_job_unref (old);
#line 8037 "LibraryMonitor.c"
	}
}

static void
library_monitor_value_take_verify_job (GValue* value,
                                       gpointer v_object)
{
	LibraryMonitorVerifyJob * old;
#line 196 "../src/LibraryMonitor.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, LIBRARY_MONITOR_TYPE_VERIFY_JOB));
#line 196 "../src/LibraryMonitor.vala"
	old = value->data[0].v_pointer;
#line 196 "../src/LibraryMonitor.vala"
	if (v_object) {
#line 196 "../src/LibraryMonitor.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, LIBRARY_MONITOR_TYPE_VERIFY_JOB));
#line 196 "../src/LibraryMonitor.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 196 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = v_object;
#line 8058 "LibraryMonitor.c"
	} else {
#line 196 "../src/LibraryMonitor.vala"
		value->data[0].v_pointer = NULL;
#line 8062 "LibraryMonitor.c"
	}
#line 196 "../src/LibraryMonitor.vala"
	if (old) {
#line 196 "../src/LibraryMonitor.vala"
		library_monitor_verify_job_unref (old);
#line 8068 "LibraryMonitor.c"
	}
}

static void
library_monitor_verify_job_class_init (LibraryMonitorVerifyJobClass * klass,
                                       gpointer klass_data)
{
#line 196 "../src/LibraryMonitor.vala"
	library_monitor_verify_job_parent_class = g_type_class_peek_parent (klass);
#line 196 "../src/LibraryMonitor.vala"
	((LibraryMonitorVerifyJobClass *) klass)->finalize = library_monitor_verify_job_finalize;
#line 8080 "LibraryMonitor.c"
}

static void
library_monitor_verify_job_instance_init (LibraryMonitorVerifyJob * self,
                                          gpointer klass)
{
#line 196 "../src/LibraryMonitor.vala"
	self->ref_count = 1;
#line 8089 "LibraryMonitor.c"
}

static void
library_monitor_verify_job_finalize (LibraryMonitorVerifyJob * obj)
{
	LibraryMonitorVerifyJob * self;
#line 196 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, LIBRARY_MONITOR_TYPE_VERIFY_JOB, LibraryMonitorVerifyJob);
#line 196 "../src/LibraryMonitor.vala"
	g_signal_handlers_destroy (self);
#line 197 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->monitorable);
#line 198 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->monitor);
#line 8104 "LibraryMonitor.c"
}

static GType
library_monitor_verify_job_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { library_monitor_value_verify_job_init, library_monitor_value_verify_job_free_value, library_monitor_value_verify_job_copy_value, library_monitor_value_verify_job_peek_pointer, "p", library_monitor_value_verify_job_collect_value, "p", library_monitor_value_verify_job_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (LibraryMonitorVerifyJobClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_monitor_verify_job_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryMonitorVerifyJob), 0, (GInstanceInitFunc) library_monitor_verify_job_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType library_monitor_verify_job_type_id;
	library_monitor_verify_job_type_id = g_type_register_fundamental (g_type_fundamental_next (), "LibraryMonitorVerifyJob", &g_define_type_info, &g_define_type_fundamental_info, 0);
	return library_monitor_verify_job_type_id;
}

static GType
library_monitor_verify_job_get_type (void)
{
	static volatile gsize library_monitor_verify_job_type_id__once = 0;
	if (g_once_init_enter (&library_monitor_verify_job_type_id__once)) {
		GType library_monitor_verify_job_type_id;
		library_monitor_verify_job_type_id = library_monitor_verify_job_get_type_once ();
		g_once_init_leave (&library_monitor_verify_job_type_id__once, library_monitor_verify_job_type_id);
	}
	return library_monitor_verify_job_type_id__once;
}

static gpointer
library_monitor_verify_job_ref (gpointer instance)
{
	LibraryMonitorVerifyJob * self;
	self = instance;
#line 196 "../src/LibraryMonitor.vala"
	g_atomic_int_inc (&self->ref_count);
#line 196 "../src/LibraryMonitor.vala"
	return instance;
#line 8139 "LibraryMonitor.c"
}

static void
library_monitor_verify_job_unref (gpointer instance)
{
	LibraryMonitorVerifyJob * self;
	self = instance;
#line 196 "../src/LibraryMonitor.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 196 "../src/LibraryMonitor.vala"
		LIBRARY_MONITOR_VERIFY_JOB_GET_CLASS (self)->finalize (self);
#line 196 "../src/LibraryMonitor.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 8153 "LibraryMonitor.c"
	}
}

static void
library_monitor_class_init (LibraryMonitorClass * klass,
                            gpointer klass_data)
{
	GeeHashSet* _tmp0_;
	HashTimedQueue* _tmp1_;
#line 97 "../src/LibraryMonitor.vala"
	library_monitor_parent_class = g_type_class_peek_parent (klass);
#line 97 "../src/LibraryMonitor.vala"
	g_type_class_adjust_private_offset (klass, &LibraryMonitor_private_offset);
#line 97 "../src/LibraryMonitor.vala"
	((DirectoryMonitorClass *) klass)->close = (void (*) (DirectoryMonitor*)) library_monitor_real_close;
#line 97 "../src/LibraryMonitor.vala"
	((DirectoryMonitorClass *) klass)->discovery_started = (void (*) (DirectoryMonitor*)) library_monitor_real_discovery_started;
#line 97 "../src/LibraryMonitor.vala"
	((DirectoryMonitorClass *) klass)->file_discovered = (void (*) (DirectoryMonitor*, GFile*, GFileInfo*)) library_monitor_real_file_discovered;
#line 97 "../src/LibraryMonitor.vala"
	((DirectoryMonitorClass *) klass)->discovery_completed = (void (*) (DirectoryMonitor*)) library_monitor_real_discovery_completed;
#line 97 "../src/LibraryMonitor.vala"
	((DirectoryMonitorClass *) klass)->notify_file_created = (void (*) (DirectoryMonitor*, GFile*, GFileInfo*)) library_monitor_real_notify_file_created;
#line 97 "../src/LibraryMonitor.vala"
	((DirectoryMonitorClass *) klass)->notify_file_moved = (void (*) (DirectoryMonitor*, GFile*, GFile*, GFileInfo*)) library_monitor_real_notify_file_moved;
#line 97 "../src/LibraryMonitor.vala"
	((DirectoryMonitorClass *) klass)->notify_file_altered = (void (*) (DirectoryMonitor*, GFile*)) library_monitor_real_notify_file_altered;
#line 97 "../src/LibraryMonitor.vala"
	((DirectoryMonitorClass *) klass)->notify_file_attributes_altered = (void (*) (DirectoryMonitor*, GFile*)) library_monitor_real_notify_file_attributes_altered;
#line 97 "../src/LibraryMonitor.vala"
	((DirectoryMonitorClass *) klass)->notify_file_alteration_completed = (void (*) (DirectoryMonitor*, GFile*, GFileInfo*)) library_monitor_real_notify_file_alteration_completed;
#line 97 "../src/LibraryMonitor.vala"
	((DirectoryMonitorClass *) klass)->notify_file_deleted = (void (*) (DirectoryMonitor*, GFile*)) library_monitor_real_notify_file_deleted;
#line 97 "../src/LibraryMonitor.vala"
	G_OBJECT_CLASS (klass)->finalize = library_monitor_finalize;
#line 97 "../src/LibraryMonitor.vala"
	library_monitor_signals[LIBRARY_MONITOR_AUTO_UPDATE_PROGRESS_SIGNAL] = g_signal_new ("auto-update-progress", TYPE_LIBRARY_MONITOR, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__INT_INT, G_TYPE_NONE, 2, G_TYPE_INT, G_TYPE_INT);
#line 97 "../src/LibraryMonitor.vala"
	library_monitor_signals[LIBRARY_MONITOR_AUTO_IMPORT_PREPARING_SIGNAL] = g_signal_new ("auto-import-preparing", TYPE_LIBRARY_MONITOR, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 97 "../src/LibraryMonitor.vala"
	library_monitor_signals[LIBRARY_MONITOR_AUTO_IMPORT_PROGRESS_SIGNAL] = g_signal_new ("auto-import-progress", TYPE_LIBRARY_MONITOR, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__UINT64_UINT64, G_TYPE_NONE, 2, G_TYPE_UINT64, G_TYPE_UINT64);
#line 206 "../src/LibraryMonitor.vala"
	g_rec_mutex_init (&__lock_library_monitor_library_monitor_blacklist);
#line 206 "../src/LibraryMonitor.vala"
	_tmp0_ = gee_hash_set_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL);
#line 206 "../src/LibraryMonitor.vala"
	library_monitor_blacklist = _tmp0_;
#line 207 "../src/LibraryMonitor.vala"
	_tmp1_ = hash_timed_queue_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, (guint) LIBRARY_MONITOR_MIN_BLACKLIST_DURATION_MSEC, _library_monitor_on_unblacklist_file_dequeued_callback, NULL, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL, G_PRIORITY_LOW);
#line 207 "../src/LibraryMonitor.vala"
	library_monitor_to_unblacklist = _tmp1_;
#line 8205 "LibraryMonitor.c"
}

static void
library_monitor_instance_init (LibraryMonitor * self,
                               gpointer klass)
{
	Workers* _tmp0_;
	GCancellable* _tmp1_;
	GeeArrayList* _tmp2_;
	GeeHashSet* _tmp3_;
	GeeHashSet* _tmp4_;
	GeeArrayList* _tmp5_;
	GeeLinkedList* _tmp6_;
#line 97 "../src/LibraryMonitor.vala"
	self->priv = library_monitor_get_instance_private (self);
#line 210 "../src/LibraryMonitor.vala"
	_tmp0_ = workers_new (workers_thread_per_cpu_minus_one (), FALSE);
#line 210 "../src/LibraryMonitor.vala"
	self->priv->workers = _tmp0_;
#line 211 "../src/LibraryMonitor.vala"
	_tmp1_ = g_cancellable_new ();
#line 211 "../src/LibraryMonitor.vala"
	self->priv->cancellable = _tmp1_;
#line 212 "../src/LibraryMonitor.vala"
	self->priv->auto_import = FALSE;
#line 213 "../src/LibraryMonitor.vala"
	self->priv->unknown_files = NULL;
#line 214 "../src/LibraryMonitor.vala"
	_tmp2_ = gee_array_list_new (TYPE_MEDIA_MONITOR, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 214 "../src/LibraryMonitor.vala"
	self->priv->monitors = G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GEE_TYPE_LIST, GeeList);
#line 215 "../src/LibraryMonitor.vala"
	self->priv->discovered = NULL;
#line 216 "../src/LibraryMonitor.vala"
	_tmp3_ = gee_hash_set_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL);
#line 216 "../src/LibraryMonitor.vala"
	self->priv->import_queue = _tmp3_;
#line 217 "../src/LibraryMonitor.vala"
	_tmp4_ = gee_hash_set_new (g_file_get_type (), (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, _file_hash_gee_hash_data_func, NULL, NULL, _file_equal_gee_equal_data_func, NULL, NULL);
#line 217 "../src/LibraryMonitor.vala"
	self->priv->pending_imports = _tmp4_;
#line 218 "../src/LibraryMonitor.vala"
	_tmp5_ = gee_array_list_new (TYPE_BATCH_IMPORT, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 218 "../src/LibraryMonitor.vala"
	self->priv->batch_import_queue = _tmp5_;
#line 219 "../src/LibraryMonitor.vala"
	self->priv->current_import_roll = NULL;
#line 220 "../src/LibraryMonitor.vala"
	self->priv->last_import_roll_use = (gint64) 0;
#line 221 "../src/LibraryMonitor.vala"
	self->priv->current_batch_import = NULL;
#line 222 "../src/LibraryMonitor.vala"
	self->priv->checksums_completed = 0;
#line 223 "../src/LibraryMonitor.vala"
	self->priv->checksums_total = 0;
#line 224 "../src/LibraryMonitor.vala"
	self->priv->import_queue_timer_id = (guint) 0;
#line 225 "../src/LibraryMonitor.vala"
	_tmp6_ = gee_linked_list_new (LIBRARY_MONITOR_TYPE_VERIFY_JOB, (GBoxedCopyFunc) library_monitor_verify_job_ref, (GDestroyNotify) library_monitor_verify_job_unref, NULL, NULL, NULL);
#line 225 "../src/LibraryMonitor.vala"
	self->priv->verify_queue = G_TYPE_CHECK_INSTANCE_CAST (_tmp6_, GEE_TYPE_QUEUE, GeeQueue);
#line 226 "../src/LibraryMonitor.vala"
	self->priv->outstanding_verify_jobs = 0;
#line 227 "../src/LibraryMonitor.vala"
	self->priv->completed_monitorable_verifies = 0;
#line 228 "../src/LibraryMonitor.vala"
	self->priv->total_monitorable_verifies = 0;
#line 8273 "LibraryMonitor.c"
}

static void
library_monitor_finalize (GObject * obj)
{
	LibraryMonitor * self;
	ConfigFacade* _tmp0_;
	ConfigFacade* _tmp1_;
	guint _tmp2_;
#line 97 "../src/LibraryMonitor.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_LIBRARY_MONITOR, LibraryMonitor);
#line 247 "../src/LibraryMonitor.vala"
	_tmp0_ = config_facade_get_instance ();
#line 247 "../src/LibraryMonitor.vala"
	_tmp1_ = _tmp0_;
#line 247 "../src/LibraryMonitor.vala"
	g_signal_parse_name ("auto-import-from-library-changed", TYPE_CONFIGURATION_FACADE, &_tmp2_, NULL, FALSE);
#line 247 "../src/LibraryMonitor.vala"
	g_signal_handlers_disconnect_matched (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), G_SIGNAL_MATCH_ID | G_SIGNAL_MATCH_FUNC | G_SIGNAL_MATCH_DATA, _tmp2_, 0, NULL, (GCallback) _library_monitor_on_config_changed_configuration_facade_auto_import_from_library_changed, self);
#line 247 "../src/LibraryMonitor.vala"
	_g_object_unref0 (_tmp1_);
#line 210 "../src/LibraryMonitor.vala"
	_workers_unref0 (self->priv->workers);
#line 211 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->cancellable);
#line 213 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->unknown_files);
#line 214 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->monitors);
#line 215 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->discovered);
#line 216 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->import_queue);
#line 217 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->pending_imports);
#line 218 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->batch_import_queue);
#line 219 "../src/LibraryMonitor.vala"
	_batch_import_roll_unref0 (self->priv->current_import_roll);
#line 221 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->current_batch_import);
#line 225 "../src/LibraryMonitor.vala"
	_g_object_unref0 (self->priv->verify_queue);
#line 97 "../src/LibraryMonitor.vala"
	G_OBJECT_CLASS (library_monitor_parent_class)->finalize (obj);
#line 8319 "LibraryMonitor.c"
}

static GType
library_monitor_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (LibraryMonitorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) library_monitor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (LibraryMonitor), 0, (GInstanceInitFunc) library_monitor_instance_init, NULL };
	GType library_monitor_type_id;
	library_monitor_type_id = g_type_register_static (TYPE_DIRECTORY_MONITOR, "LibraryMonitor", &g_define_type_info, 0);
	LibraryMonitor_private_offset = g_type_add_instance_private (library_monitor_type_id, sizeof (LibraryMonitorPrivate));
	return library_monitor_type_id;
}

GType
library_monitor_get_type (void)
{
	static volatile gsize library_monitor_type_id__once = 0;
	if (g_once_init_enter (&library_monitor_type_id__once)) {
		GType library_monitor_type_id;
		library_monitor_type_id = library_monitor_get_type_once ();
		g_once_init_leave (&library_monitor_type_id__once, library_monitor_type_id);
	}
	return library_monitor_type_id__once;
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static inline gpointer
_vala_memdup2 (gconstpointer mem,
               gsize byte_size)
{
	gpointer new_mem;
	if (mem && byte_size != 0) {
		new_mem = g_malloc (byte_size);
		memcpy (new_mem, mem, byte_size);
	} else {
		new_mem = NULL;
	}
	return new_mem;
}

